@@ -22,11 +22,6 @@
 (in-package :maxima)
 ($put 'pdiff "1.3" 'version)
 
-;; This code modifies mactex's tex-mexpt function; to keep this modification
-;; from being overwritten when mactex is loaded, first load mactex.  
-
-($load "mactex")
-
 ;; When use_pdiff is true, use positional derivatives for unknown
 ;; non-subscripted functions. By unknown  function, I  mean a function 
 ;; that is not bound to a formula and that has a derivative that is not 
@@ -220,21 +215,11 @@
 	 
    ;;-------- end pdiff stuff --------------------------
 
-   #+cl
    ((functionp fn)
     (apply fn args))
-   #-cl
-   ((eq (car fn) 'lambda) (apply fn args))
-   #+(and lispm (not cl))
-   ((memq (car fn)
-	  '(named-lambda si:digested-lambda)) (apply fn args))
-   #-cl
-   ((and (eq (caar fn) 'mfile)
-	 (setq fn (eval (dskget (cadr fn) (caddr fn) 'value nil)))
-	 nil))
    ((eq (caar fn) 'lambda) (mlambda fn args fnname t form))
    ((eq (caar fn) 'mquote) (cons (cdr fn) args))
-   ((and aryp (memq (caar fn) '(mlist $matrix)))
+   ((and aryp (member (caar fn) '(mlist $matrix) :test #'eq))
     (if (not (or (= (length args) 1)
 		 (and (eq (caar fn) '$matrix) (= (length args) 2))))
 	(merror "wrong number of indices:~%~:M" (cons '(mlist) args)))
@@ -245,7 +230,7 @@
 	(if evarrp (throw 'evarrp 'notexist))
 	(merror "subscript must be an integer:~%~:M" (car args1)))))
    (aryp (cons '(mqapply array) (cons fn args)))
-   ((memq 'array (cdar fn)) (cons '(mqapply) (cons fn args)))
+   ((member 'array (cdar fn) :test #'eq) (cons '(mqapply) (cons fn args)))
    (t (badfunchk fnname fn t))))
 
 (defun pderivop (f x n)
@@ -271,7 +256,7 @@
 
 	  ;; ---- start pdiff stuff-----------------------------
 
-	  ((and $use_pdiff (eq fun 'mqapply) (eq (caaadr e) '%PDERIVOP))
+	  ((and $use_pdiff (eq fun 'mqapply) (eq (caaadr e) '%pderivop))
 	   (setq args (cddr e))
 	   (setq fun (cadadr e))
 	   (let ((de 0)
@@ -336,7 +321,7 @@
 (defmvar $tex_uses_prime_for_derivatives nil)
 (defmvar $tex_prime_limit 3)
 (defmvar $tex_uses_named_subscripts_for_derivatives nil)
-(defmvar $tex_diff_var_names (list '(mlist) '|$x| '|$y| '|$z|))
+(defmvar $tex_diff_var_names (list '(mlist) '$x '$y '$z))
 
 (setf (get '%pderivop 'tex) 'tex-pderivop)
 
@@ -395,11 +380,6 @@
 ;;  (c15) tex(diff(f(x,y),x,0,y,1));
 ;;            $$f_{\left(0,1\right)}(x,y)$$
 
-(defmvar $tex_uses_prime_for_derivatives t)
-(defmvar $tex_prime_limit 3)
-(defmvar $tex_uses_named_subscripts_for_derivatives t)
-(defmvar $tex_diff_var_names (list '(mlist) '$x '$y '$z))
-
 (defun tex-pderivop (x l r)
   ;(print `(lop = ,lop rop = ,rop x = ,x r = ,r l = ,l))
   (cond ((and $tex_uses_prime_for_derivatives (eq 3 (length x)))
@@ -443,7 +423,7 @@
 ;; The itensor package has a function that generates dummy variables; instead 
 ;; of loading itensor to access this function, we duplicate it here.
 
-(defmvar $dummy_char '$%\x)
+(defmvar $dummy_char '$%x)
 (defmvar $dummy_index -1)
 
 (defun $dummy_var ( )
@@ -509,8 +489,8 @@
 		 (expon (caddr x)) ;; this is the exponent
 		 (doit (and
 			f ; there is such a function
-			(memq (getchar f 1) '(% $)) ;; insist it is a % or $ function
-			(not (memq f '(%sum %product %derivative %integral %at %pderivop))) ;; what else? what a hack...
+			(member (getchar f 1) '(% $) :test #'eq) ;; insist it is a % or $ function
+			(not (member f '(%sum %product %derivative %integral %at %pderivop) :test #'eq)) ;; what else? what a hack...
 			(or (and (atom expon) (not (numberp expon))) ; f(x)^y is ok
 			    (and (atom expon) (numberp expon) (> expon 0))))))
 					; f(x)^3 is ok, but not f(x)^-1, which could
