@@ -20,23 +20,23 @@
 
 (declare-top (special symtypes $symmetries $allsym csign smlist $idummyx))
 
-(setq symtypes '($SYM $ANTI $CYC) $symmetries '((MLIST SIMP)))
+(setq symtypes '($sym $anti $cyc) $symmetries '((mlist simp)))
 
 ;$SYMMETRIES is a list of indexed objects with declared symmetries
 ;$ALLSYM if non-nil means that all indexed objects are assumed symmetric
 
-(defun $DECSYM (name ncov ncontr covl contrl)               ;DEClare SYMmetries
+(defun $decsym (name ncov ncontr covl contrl)               ;DEClare SYMmetries
        (prog (tensor)
-	     (cond ((not (eq (ml-typep name) 'SYMBOL))
+	     (cond ((not (eq (ml-typep name) 'symbol))
 		    (merror "First argument must be a possible tensor name"))
-		   ((not (and (eq (ml-typep ncov) 'FIXNUM)
-			      (eq (ml-typep ncontr) 'FIXNUM)
+		   ((not (and (eq (ml-typep ncov) 'fixnum)
+			      (eq (ml-typep ncontr) 'fixnum)
 			      (signp ge ncov)
 			      (signp ge ncontr)))
 	            (merror
 		     "2nd and 3rd arguments must be non-negative integers"))
-		   ((not (and (eq (caar covl) 'MLIST)
-			      (eq (caar contrl) 'MLIST)))
+		   ((not (and (eq (caar covl) 'mlist)
+			      (eq (caar contrl) 'mlist)))
 		    (merror "4th and 5th arguments must be lists"))
 		   ((and (< ncov 2) (< ncontr 2))
 		    (merror "This object can have no symmetry properties"))
@@ -49,10 +49,10 @@
 					  (exploden ncontr))))
 	     (do ((covl (cdr covl) (cdr covl)) (carl) (arglist) (prop))
 		 ((null covl))
-		 (cond ((not (zl-member (setq prop (caar (setq carl (car covl))))
-				     symtypes))
+		 (cond ((not (member (setq prop (caar (setq carl (car covl))))
+				     symtypes :test #'equal))
 			(merror "Invalid symmetry operator: ~M" carl))
-		       ((and (null (cddr carl)) (eq (cadr carl) '$ALL))
+		       ((and (null (cddr carl)) (eq (cadr carl) '$all))
 			(setq arglist (interval 1 ncov)))
 		       (t (setq arglist (check-symargs (cdr carl) (1+ ncov)))))
 		 (setq carl (zl-get tensor prop))
@@ -60,40 +60,40 @@
 			  prop))
 	     (do ((contl (cdr contrl) (cdr contl)) (carl) (arglist) (prop))
 		 ((null contl))
-		 (cond ((not (zl-member (setq prop (caar (setq carl (car contl))))
-				     symtypes))
+		 (cond ((not (member (setq prop (caar (setq carl (car contl))))
+				     symtypes :test #'equal))
 			(merror "Invalid symmetry operator: ~M" carl))
-		       ((and (null (cddr carl)) (eq (cadr carl) '$ALL))
+		       ((and (null (cddr carl)) (eq (cadr carl) '$all))
 			(setq arglist (interval 1 ncontr)))
 		       ((setq arglist (check-symargs (cdr carl) (1+ ncontr)))))
 		 (setq carl (zl-get tensor prop))
 		 (putprop tensor (cons (car carl) (cons arglist (cdr carl)))
 			  prop))
 	     (add2lnc tensor $symmetries)
-	     (return '$DONE)))
-
-;(defun INTERVAL (i j)     ;INTERVAL returns the list of integers from I thru J.
+	     (return '$done)))
+
+;(defun interval (i j)     ;INTERVAL returns the list of integers from I thru J.
 ;       (do ((n i (1+ n)) (ans))             ;Thus (INTERVAL 3 5) yields (3 4 5)
 ;           ((> n j) (nreverse ans))
 ;           (setq ans (cons n ans))))
 
-(defun CHECK-SYMARGS (ll n)            ;Returns an ascending list of the unique
+(defun check-symargs (ll n)            ;Returns an ascending list of the unique
 				       ;elements of LL and checks that they are
        (do ((l ll (cdr l)) (c) (ans))  ;integers between 0 and N
 	   ((null l) (cond ((null (cdr ans))
 			    (merror "Only one distinct index in symmetry property declaration"))
 			   (t (sort ans '<))))
 	   (setq c (car l))
-	   (cond ((not (and (eq (ml-typep c) 'FIXNUM) (> c 0) (< c n)))
+	   (cond ((not (and (eq (ml-typep c) 'fixnum) (> c 0) (< c n)))
 		  (merror "Bad argument encountered for symmetry operator"))
-		 ((not (zl-member c ans)) (setq ans (cons c ans))))))
+		 ((not (member c ans :test #'equal)) (setq ans (cons c ans))))))
 
-(defun $DISPSYM (name ncov ncontr)                          ;DISPlay SYMmetries
+(defun $dispsym (name ncov ncontr)                          ;DISPlay SYMmetries
        (prog (tensor)
              (setq tensor (implode (nconc (exploden name) (ncons 45)
 				          (exploden ncov) (ncons 45)
 					  (exploden ncontr))))
-	     (cond ((not (zl-member tensor (cdr $symmetries)))
+	     (cond ((not (member tensor (cdr $symmetries) :test #'equal))
 		    (return (ncons smlist))))
 	     (return
 	      (do ((q symtypes (cdr q)) (l) (prop))
@@ -109,124 +109,127 @@
 				    (consmlist (mapcar 'consmlist (cdr prop))))
 ))))))))))
 
-(defun $REMSYM (name ncov ncontr)
-  ;;Zl-remove SYMmetries
+(defun $remsym (name ncov ncontr)
   (prog (tensor)
     (setq tensor (implode (nconc (exploden name) (ncons 45)
 				 (exploden ncov) (ncons 45)
 				 (exploden ncontr))))
-    (cond ((not (zl-member tensor (cdr $symmetries)))
+    (cond ((not (member tensor (cdr $symmetries) :test #'equal))
 	   (mtell "~&No symmetries have been declared for this tensor.~%"))
-	  (t (zl-delete tensor $symmetries)
-	   (zl-remprop tensor '$SYM) (zl-remprop tensor '$ANTI)
-	   (zl-remprop tensor '$CYC)))
-    (return '$DONE)))
-
-(defun $CANFORM (e)                              ;Convert E into CANonical FORM
+	  (t (setq $symmetries (delete tensor $symmetries :test #'equal))
+	   (zl-remprop tensor '$sym)
+	   (zl-remprop tensor '$anti)
+	   (zl-remprop tensor '$cyc)))
+    (return '$done)))
+
+(defun $canform (e)                              ;Convert E into CANonical FORM
        (cond ((atom e) e)
-	     ((eq (caar e) 'MEQUAL)
+	     ((eq (caar e) 'mequal)
 	      (mysubst0 (list (car e) ($canform (cadr e)) ($canform (caddr e)))
 			e))
-	     ((eq (caar e) 'MPLUS)
-	      (mysubst0 (simplus (cons '(MPLUS) (mapcar '$canform (cdr e)))
+	     ((eq (caar e) 'mplus)
+	      (mysubst0 (simplus (cons '(mplus) (mapcar '$canform (cdr e)))
 				 1 nil) e))
-	     ((eq (caar e) 'MTIMES) (mysubst0 (simplifya (canprod e) nil) e))
+	     ((eq (caar e) 'mtimes) (mysubst0 (simplifya (canprod e) nil) e))
 	     ((rpobj e) (canten e t))
 	     (t (mysubst0 (simplifya (cons (ncons (caar e))
 					   (mapcar '$canform (cdr e))) t) e))))
 
-(defun CANTEN (e nfprpobjs)                                   ;CANonical TENsor
-       (prog (cov contr deriv tensor)
-	     ((lambda (dummy) (and nfprpobjs dummy (setq e (rename1 e dummy))))
-	      (NONUMBER (cdaddr ($indices e)))) ;NFPRPOBJS is Not From Product
-	     (setq cov (copy (cdadr e))          ;of RP (indexed) OBJects
-		   contr (copy (cdaddr e))
-		   deriv (copy (cdddr e))
-		   tensor (implode (nconc (exploden (caar e)) (ncons 45)
-					  (exploden (length cov)) (ncons 45)
-					  (exploden (length contr))))
-		   csign nil)       ;Set when reordering antisymmetric indices.
-                                    ;Indicates whether overall sign of
-                                    ;expression needs changing.
-	     (cond
-		   ((OR (OR (eq (caar e) '$Levi_Civita) (eq (caar e) '%Levi_Civita)) (OR (eq (caar e) '$KDELTA) (eq (caar e) '%KDELTA))) (setq cov (ANTISORT cov) contr (ANTISORT contr)))
-		   ((OR $allsym (eq (caar e) '$KDELS) (eq (caar e) '%KDELS)) (setq cov (itensor-sort cov) contr (itensor-sort contr)))
-		   ((zl-member ($VERBIFY tensor) (cdr $symmetries))
-		    (do ((q symtypes (cdr q)) (type))
-			((null q))
-			(setq type (car q))
-			(do ((props (car (zl-get ($VERBIFY tensor) type)) (cdr props)) (p))
-			    ((null props))
-			    (setq p (car props)
-				  cov (inserts (symsort (extract-elements p cov) type)
-					       cov p)))
-			(do ((props (cdr (zl-get ($VERBIFY tensor) type)) (cdr props)) (p))
-			    ((null props))
-			    (setq p (car props)
-				    contr (inserts (symsort (extract-elements p contr)
-							    type)
-						   contr p))))))
-	     (setq tensor (mysubst0 (append (list (car e)
-						  (consmlist cov)
-						  (consmlist contr))
-(cond ($iframe_flag deriv) (t   (itensor-sort deriv) ))
-) e))
-	     (cond (csign (setq tensor (neg tensor))))
-	     (return tensor)))
-
-(defun RENAME1 (e dummy)          ;Renames dummy indices in a consistent manner
+(defun canten (e nfprpobjs)		;CANonical TENsor
+  (prog (cov contr deriv tensor)
+     ((lambda (dummy) (and nfprpobjs dummy (setq e (rename1 e dummy))))
+      (nonumber (cdaddr ($indices e)))) ;NFPRPOBJS is Not From Product
+     (setq cov (copy-tree (cdadr e))	;of RP (indexed) OBJects
+	   contr (copy-tree (cdaddr e))
+	   deriv (copy-tree (cdddr e))
+	   tensor (implode (nconc (exploden (caar e)) (ncons 45)
+				  (exploden (length cov)) (ncons 45)
+				  (exploden (length contr))))
+	   csign nil)	   ;Set when reordering antisymmetric indices.
+					;Indicates whether overall sign of
+					;expression needs changing.
+     (cond ((or (or (eq (caar e) '$levi_civita) (eq (caar e) '%levi_civita))
+		(or (eq (caar e) '$kdelta) (eq (caar e) '%kdelta)))
+	    (setq cov (antisort cov) contr (antisort contr)))
+	   ((or $allsym (eq (caar e) '$kdels) (eq (caar e) '%kdels))
+	    (setq cov (itensor-sort cov) contr (itensor-sort contr)))
+	   ((member ($verbify tensor) (cdr $symmetries) :test #'equal)
+	    (do ((q symtypes (cdr q)) (type))
+		((null q))
+	      (setq type (car q))
+	      (do ((props (car (zl-get ($verbify tensor) type)) (cdr props)) (p))
+		  ((null props))
+		(setq p (car props)
+		      cov (inserts (symsort (extract-elements p cov) type)
+				   cov p)))
+	      (do ((props (cdr (zl-get ($verbify tensor) type)) (cdr props)) (p))
+		  ((null props))
+		(setq p (car props)
+		      contr (inserts (symsort (extract-elements p contr)
+					      type)
+				     contr p))))))
+     (setq tensor (mysubst0 (append (list (car e)
+					  (consmlist cov)
+					  (consmlist contr))
+				    (cond ($iframe_flag deriv)
+					  (t (itensor-sort deriv) ))
+				    ) e))
+     (cond (csign (setq tensor (neg tensor))))
+     (return tensor)))
+
+(defun rename1 (e dummy)          ;Renames dummy indices in a consistent manner
        (sublis (cleanup0 dummy) e))
 
-(defun CLEANUP0 (a)
+(defun cleanup0 (a)
        (do ((b a (cdr b)) (n 1 (1+ n)) (l) (dumx))
 	   ((null b) l)
 	   (setq dumx (concat $idummyx n))
 	   (cond ((not (eq dumx (car b)))
 		  (setq l (cons (cons (car b) dumx) l))))))
 
-(defun EXTRACT-elements (a b)  ;Extracts the elements from B specified by the indices in
+(defun extract-elements (a b)  ;Extracts the elements from B specified by the indices in
                       ;i.e. (EXTRACT-elements '(2 5) '(A B C D E F)) yields (B E)
        (do ((a a) (b b (cdr b)) (n 1 (1+ n)) (l))
 	   ((null a) (nreverse l))
 	   (cond ((equal (car a) n)
 		  (setq l (cons (car b) l) a (cdr a))))))
 
-(defun INSERTS (a b c)          ;Substitutes A into B with respect to the index
+(defun inserts (a b c)          ;Substitutes A into B with respect to the index
        (do ((a a) (b b (cdr b)) (c c) (n 1 (1+ n)) (l))        ;specification C
 	   ((null a) (nreconc l b))
 	   (cond ((equal (car c) n)
 		  (setq l (cons (car a) l) a (cdr a) c (cdr c)))
 		 (t (setq l (cons (car b) l))))))
 
-(defun SYMSORT (l type)
-       (cond ((eq type '$SYM) (sort l 'less))           ;SORT SYMmetric indices
-	     ((eq type '$ANTI) (antisort l))
+(defun symsort (l type)
+       (cond ((eq type '$sym) (sort l #'less))           ;SORT SYMmetric indices
+	     ((eq type '$anti) (antisort l))
 	     (t (cycsort l))))
 
-(defun ANTISORT (l)         ;SORT ANTIsymmetric indices and set CSIGN as needed
-       ((lambda (q) (cond ((equal ($Levi_Civita (consmlist (mapcar 'cdr q))) -1)
+(defun antisort (l)         ;SORT ANTIsymmetric indices and set CSIGN as needed
+       ((lambda (q) (cond ((equal ($levi_civita (consmlist (mapcar 'cdr q))) -1)
 		           (setq csign (not csign))))
 		    (mapcar 'car q))
-	(sortcar (index l) 'less)))
+	(sort (index l) #'less :key #'car)))
 
-(defun INDEX (l)             ;(INDEX '(A B C)) yields ((A . 1) (B . 2) (C . 3))
+(defun index (l)             ;(INDEX '(A B C)) yields ((A . 1) (B . 2) (C . 3))
        (do ((l l (cdr l)) (n 1 (1+ n)) (q))
 	   ((null l) (nreverse q))
 	   (setq q (cons (cons (car l) n) q))))
 
-(defun CYCSORT (l)                                         ;SORT CYClic indices
+(defun cycsort (l)                                         ;SORT CYClic indices
        ((lambda (n) (cond ((equal n 0) l)
 			  (t (append (nthcdr n l)
 				     (reverse (nthcdr (f- (length l) n)
 						      (reverse l)))))))
 	(1- (cdr (least l)))))
 
-(defun LEAST (l)   ;Returns a dotted pair containing the alphanumerically least
+(defun least (l)   ;Returns a dotted pair containing the alphanumerically least
                    ;element in L in the car and its index in L in the cdr
        (do ((l (cdr l) (cdr l)) (a (cons (car l) 1)) (n 2 (1+ n)))
 	   ((null l) a)
 	   (cond ((less (car l) (car a)) (setq a (cons (car l) n))))))
-
+
 (declare-top (special free-indices))
 
 (defun canprod (e)
@@ -276,12 +279,12 @@
                 )
                 (mapcar
                   #'cdr
-                  (sortcar
+                  (sort
                     (progn
                       (setq free-indices (nonumber (cdadr ($indices e))))
                       (mapcar 'describe-tensor indexed)
                     )
-                    #'tensorpred
+                    #'tensorpred :key #'car
                   )
                 )
               )
@@ -293,21 +296,21 @@
   )
 )
 
-(defun TENSORPRED (x y)
+(defun tensorpred (x y)
        (do ((x x (cdr x)) (y y (cdr y)) (a) (b))
 	   ((null x))
 	   (setq a (car x) b (car y))
 	   (and (not (equal a b)) (return
-				   (cond ((eq (ml-typep a) 'FIXNUM) (< a b))
+				   (cond ((eq (ml-typep a) 'fixnum) (< a b))
 					 ((and (listp a) (listp b)) (tensorpred a b))
 					 ((null a) t)
 					 ((null b) nil)
 					 (t (alphalessp a b)))))))
 
-(defun DESCRIBE-TENSOR (f)
+(defun describe-tensor (f)
        (cons (tdescript f) f))
 
-(defun TDESCRIPT (f)
+(defun tdescript (f)
        (prog (name indices lcov lcontr lderiv)
 	     (setq name (caar f)
 		   indices (append (cdadr f) (cdaddr f) (cdddr f))
