@@ -9,38 +9,38 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (in-package :maxima)
+
 (macsyma-module ezgcd)
 
-(declare-top(special varlist genvar lcprod svals svars oldsvars oldsvals
-		     valflag $gcd pl0 d0 degd0 subvar subval var
-		     many*  tempprime ovarlist valist modulus klim
-		     zl *prime plim nn* ne nn*-1 blist1 dlp *alpha
-		     ez1skip svalsl nsvals errrjfflag $algebraic
-		     lc1 oldlc df1 df2 res limk *ab* *alpha
-		     *sharpa *sharpb fact1 fact2 hmodulus $ratfac)
-	    (*expr ith)
-	    (genprefix ezg))
+(declare-top (special varlist genvar lcprod svals svars oldsvars oldsvals
+		      valflag $gcd pl0 d0 degd0 subvar subval var
+		      many*  tempprime ovarlist valist modulus klim
+		      zl *prime plim nn* ne nn*-1 blist1 dlp *alpha
+		      ez1skip svalsl nsvals errrjfflag $algebraic
+		      lc1 oldlc df1 df2 res limk *ab* *alpha
+		      *sharpa *sharpb fact1 fact2 hmodulus $ratfac))
 
 (load-macsyma-macros ratmac)
 
-(defun ezgcd2 (f g) (prog (allvars)
-		       (setq allvars (union* (listovars f) (listovars g)))
-		       (cond ((greaterp 2 (length allvars)) 
-			      (setq allvars (newgcd f g modulus))
-			      (cond ((cdr allvars) (return allvars))
-				    (t (return (list (setq allvars (car allvars))
-						     (pquotient f allvars)
-						     (pquotient g allvars)))))))
-		       (setq allvars (sort allvars 'pointergp))
-		       (return (ezgcd (list f g) allvars modulus))
-		       ))
+(defun ezgcd2 (f g)
+  (prog (allvars)
+     (setq allvars (union* (listovars f) (listovars g)))
+     (cond ((> 2 (length allvars))
+	    (setq allvars (newgcd f g modulus))
+	    (cond ((cdr allvars) (return allvars))
+		  (t (return (list (setq allvars (car allvars))
+				   (pquotient f allvars)
+				   (pquotient g allvars)))))))
+     (setq allvars (sort allvars #'pointergp))
+     (return (ezgcd (list f g) allvars modulus))))
 
-(defun newgcdcall (p q) (car (newgcd p q modulus)))
+(defun newgcdcall (p q)
+  (car (newgcd p q modulus)))
 
 (defun gcdl (pl)
   (do ((d (car pl) (pgcd d (car l)))
        (l (cdr pl) (cdr l)))
-      ((or (null l) (equal d 1)) d)))
+      ((or (null l) (eql d 1)) d)))
 
 (defun newgcdl (pl)
   (let (($gcd '$mod))
@@ -52,12 +52,13 @@
 
 (defun oldgcdcall (pfl)
   (let ((a (oldgcdl (car pfl) (cdr pfl))))
-    (cons a (mapcar (function (lambda (h) (pquotient h a))) pfl))))
+    (cons a (mapcar #'(lambda (h) (pquotient h a)) pfl))))
 
 (defun non0rand (modulus)
-  (do ((r)) ((not (zerop (setq r (cmod (random 1000))))) r)))
+  (do ((r))
+      ((not (zerop (setq r (cmod (random 1000))))) r)))
 
-(declare-top(special tempprime))
+(declare-top (special tempprime))
 
 (defun getgoodvals (varl lcp)
   (mapcar #'(lambda (v) (do ((val 0 (non0rand tempprime)) (temp))
@@ -70,98 +71,47 @@
      (cond ((equal nsvals (length svalsl)) (return nil)))
      (cond (valflag (go newvals)))
      (setq vals (getgoodvals svars lcprod))
-     again(cond ((zl-member vals svalsl)
+     again (cond ((member vals svalsl :test #'equal)
 		 (setq vals (rand (length svars) tempprime))
 		 (go again)))
      (setq valflag t svalsl (cons vals svalsl))
      (go end)
      newvals
      (setq pl0 (rand (length svars) tempprime))
-     (cond ((zl-member pl0 svalsl) (go newvals))
+     (cond ((member pl0 svalsl :test #'equal) (go newvals))
 	   (t (setq vals pl0 svalsl (cons vals svalsl))))
-     (cond ((equal 0. (pcsub lcprod vals svars))
+     (cond ((equal 0 (pcsub lcprod vals svars))
 	    (cond ((equal nsvals (length svalsl))
 		   (return nil))
 		  (t (go newvals)))))
      ;;	     END  (GETD0 PL(SETQ VALS(SUBST 1. 0.  VALS))) WHAT WAS SUBST FOR?
      end  (getd0 pl vals)
      (return (list vals pl0 d0))))
-
-(defun degodr (a b) (cond ((numberp a) nil)
-			  ((numberp b) t)
-			  (t (greaterp (cadr a) (cadr b)))))
+
+(defun degodr (a b)
+  (cond ((numberp a) nil)
+	((numberp b) t)
+	(t (> (cadr a) (cadr b)))))
 
 (defun evtildegless (pl)
   (prog (evout npl0 nd0 ndeg)
-   again(setq evout (evmap svals pl))
+   again (setq evout (evmap svals pl))
    (cond (evout (setq npl0 (cadr evout) nd0 (caddr evout)))
 	 (t (return nil)))
-   (cond ((numberp nd0) (setq ndeg 0.)) (t (setq ndeg (cadr nd0))))
-   (cond ((or (equal degd0 ndeg) (greaterp ndeg degd0)) (go again)))
+   (cond ((numberp nd0) (setq ndeg 0)) (t (setq ndeg (cadr nd0))))
+   (when (or (= degd0 ndeg) (> ndeg degd0)) (go again))
    (return (setq degd0 ndeg pl0 npl0 d0 nd0 svals (car evout)))))
 
 (defun ptimesmerge (pl1 pl2)
-  (cond (pl1 (cons (ptimes (car pl1) (car pl2)) 
+  (cond (pl1 (cons (ptimes (car pl1) (car pl2))
 		   (ptimesmerge (cdr pl1) (cdr pl2))))
 	(t nil)))
 
-;;(DEFUN RESTORELCZ (P INVLC LC)
-;;  (LET ((VAR) (DEG))
-;;       (COND ((EQUAL 1 INVLC)
-;;	      (SETQ P (PMOD (OLDREP P)))
-;;	      (SETQ VAR (CAR P)))
-;;	     (T (SETQ VAR (CAR P))
-;;		(SETQ DEG (CADR P))
-;;		(SETQ P (PTIMES INVLC (PSIMP VAR (CDDDR P))))
-;;		(SETQ P (PPLUS (LIST VAR DEG LC)
-;;			       (PMOD (OLDREP (DROPTERMS P)))))))
-;;       (LET ((MODULUS))
-;;	    (CADR (FASTCONT P)))))
-
-;;(DEFUN RPLALC (POLY NEWLC)
-;;       (APPEND (LIST (CAR POLY) (CADR POLY) NEWLC) (CDDDR POLY)))
-
-
-;;(DEFUN EZ1 (POLY FACT1 FACT2) 
-;;   (PROG (RES HSTEPS STEPS KTERM A B C D *AB* M DF1 DF2 DLR STEP *SHARPA *SHARPB) 
-;;      (LET ((MODULUS) (HMODULUS))
-;;	   (SETQMODULUS *PRIME)
-;;	   (SETQ *SHARPB (FACT20 FACT1 FACT2 LIMK)))
-;;      (SETQ *SHARPA (CAR *SHARPB))
-;;      (SETQ *SHARPB (CADR *SHARPB))
-;;      (SETQ *AB* (LIST (LIST 0 *SHARPA *SHARPB)))
-;;      (SETQ STEPS (APPLY 'MAX (MAPCAR (FUNCTION MULTIDEG) (CDR (ODDELM POLY)))))
-;;      (SETQ HSTEPS (QUOTIENT STEPS 2.))
-;;      (SETQ STEP 0)
-;;      (SETQ DF1 (RPLALC FACT1 (PMOD (NEWREP LC1))))
-;;      (SETQ DF2 (RPLALC FACT2 (PMOD (NEWREP OLDLC))))
-;;      (SETQ RES (PDIFFERENCE (PTIMES DF1 DF2) (PMOD POLY)))
-;;      (SETQ POLY NIL)
-;; LOOP (COND ((EQUAL RES 0) (GO OUT))) 
-;;   BK (SETQ STEP (ADD1 STEP)) 
-;;      (COND ((GREATERP STEP STEPS) (GO OUT))) 
-;;      (COND ((EQ (CAR RES) VAR)(SETQ C (CDR RES)))
-;;	    (T (SETQ C (LIST 0 RES))))
-;;      (SETQ A 0 B 0)
-;;NEXTM (COND ((NULL C)(Z2 A B STEP HSTEPS)(GO LOOP)))
-;;      (SETQ M (CAR C))
-;;      (SETQ DLR (CADR C))
-;;      (SETQ C (CDDR C))
-;;      (SETQ KTERM (KTERMS DLR STEP))
-;;      (SETQ DLR NIL)
-;;      (COND ((EQUAL 0 KTERM) (GO NEXTM))) 
-;;      (SETQ D (OBTAINABM M))
-;;      (SETQ B (PPLUS B (PTIMES (CAR D) KTERM)))
-;;      (SETQ A (PPLUS A (PTIMES (CADR D) KTERM)))
-;;      (SETQ KTERM NIL)
-;;      (GO NEXTM)
-;;  OUT (RETURN (LIST DF1 DF2)))) 
-
 (defun ez1call (builder factrs lc1 valist ovarlist)
   (prog (*prime plim nn* ne nn*-1 zl zfactr oldlc lcd0
 	 blist1 dlp limk genvar subvar subval mult)
      (setq oldlc (caddr builder))
-     (cond ((not (equal 1 lc1)) 
+     (cond ((not (equal 1 lc1))
 	    (setq builder (ptimes builder lc1))))
      (setq genvar (append ovarlist (list (car builder))))
      (cond (modulus
@@ -170,25 +120,22 @@
 	   (t (setq *prime (max (norm builder)
 				(maxcoefficient (car factrs))
 				(maxcoefficient (cadr factrs))))))
-     (cond ((greaterp *prime *alpha) 
-	    (prog (newmodulus) 
-	       (setq newmodulus (times *alpha *alpha)
+     (cond ((> *prime *alpha)
+	    (prog (newmodulus)
+	       (setq newmodulus (* *alpha *alpha)
 		     limk 0)
-	       again(cond ((greaterp newmodulus *prime) 
+	       again(cond ((> newmodulus *prime)
 			   (setq *prime *alpha plim newmodulus))
-			  (t (setq limk (add1 limk) newmodulus (times newmodulus newmodulus))
+			  (t (setq limk (1+ limk) newmodulus (* newmodulus newmodulus))
 			     (go again)))))
 	   (t (setq limk -1 *prime *alpha plim *alpha)))
-     mod  (setq nn* (add1 (setq ne (setq nn*-1 (length ovarlist)))))
+     mod  (setq nn* (1+ (setq ne (setq nn*-1 (length ovarlist)))))
      (setq zl (completevector nil 1 nn* 0))
      (fixvl valist ovarlist)
      (cond ((equal 1 lc1)
 	    (setq modulus plim builder (newrep builder))
-	    (setq dlp #+nil (loop for x in (cdr (oddelm builder))
-				   maximize (multideg x))
-		  #-nil (apply 'max
-			       (mapcar (function multideg) 
-				       (cdr (oddelm builder)))))
+	    (setq dlp  (loop for x in (cdr (oddelm builder))
+			  maximize (multideg x)))
 	    (setq zfactr (z1 builder (car factrs)(cadr factrs)))
 	    (setq zfactr (restorelc zfactr (caddr builder)))
 	    (return (oldrep(cadr zfactr)))))
@@ -198,23 +145,22 @@
      (setq factrs (list (ptimes mult (car factrs))
 			(ptimes lcd0 (cadr factrs))))
      (setq builder (newrep builder))
-     (setq dlp #+nil (loop for x in (cdr (oddelm builder))
-			    maximize (multideg x))
-	   #-nil (apply 'max (mapcar (function multideg) 
-				     (cdr (oddelm builder)))))
+     (setq dlp (loop for x in (cdr (oddelm builder))
+		  maximize (multideg x)))
      (setq zfactr (z1 builder (car factrs) (cadr factrs)))
      (setq zfactr (pmod (oldrep (car zfactr))))
      (return (cadr ((lambda (modulus) (fastcont zfactr)) nil)))))
 
-(defun getd0 (tpl tvals) (prog (c)
-			    (setq d0 (pcsub (car tpl) tvals svars) 
-				  pl0 (list d0) tpl (cdr tpl))
-			    loop (cond ((null tpl) (return d0)))
-			    (setq c (pcsub (car tpl) tvals svars)
-				  d0 (newgcdcall d0 c))
-			    (cond ((numberp d0) (return (setq d0 1))))
-			    (setq pl0 (append pl0 (list c)) tpl (cdr tpl))
-			    (go loop)))
+(defun getd0 (tpl tvals)
+  (prog (c)
+     (setq d0 (pcsub (car tpl) tvals svars)
+	   pl0 (list d0) tpl (cdr tpl))
+     loop (cond ((null tpl) (return d0)))
+     (setq c (pcsub (car tpl) tvals svars)
+	   d0 (newgcdcall d0 c))
+     (cond ((numberp d0) (return (setq d0 1))))
+     (setq pl0 (append pl0 (list c)) tpl (cdr tpl))
+     (go loop)))
 
 (defun numberinlistp (l)
   (do ((l l (cdr l))) ((null l))
@@ -226,57 +172,54 @@
 	 pl0 d0 d degd0 degd0n d0n pl0n temp tryagain cofact0
 	 pcofactl ith builder var termcont tcontl $algebraic)
      (cond ((setq temp (numberinlistp pfl))
-	    (cond ((or (zl-member 1 pfl)(zl-member -1 pfl))
+	    (cond ((or (member 1 pfl) (member -1 pfl))
 		   (return (cons 1 pfl))))
-	    (setq temp (oldgcdl temp (zl-remove temp pfl))
-		  pl (mapcar (function (lambda(h) (pquotient h temp))) pfl))
+	    (setq temp (oldgcdl temp (remove temp pfl :test #'equal))
+		  pl (mapcar #'(lambda(h) (pquotient h temp)) pfl))
 	    (return (cons temp pl))))
      (setq svars (cdr vl) var (car vl))
      (cond (svars (setq many* t))
 	   (t (return (cons (setq d (newgcdl pfl))
-			    (mapcar (function (lambda(h) (pquotient h d))) pfl)))))
+			    (mapcar #'(lambda(h) (pquotient h d)) pfl)))))
      (cond (modulus (setq tempprime modulus))
 	   (t (setq tempprime 13.)))
-     (setq tcontl (mapcar (function ptermcont) pfl)
-	   pfl (mapcar (function cadr) tcontl)
-	   tcontl (mapcar (function car) tcontl))
+     (setq tcontl (mapcar #'ptermcont pfl)
+	   pfl (mapcar #'cadr tcontl)
+	   tcontl (mapcar #'car tcontl))
      (setq termcont (oldgcdcall tcontl)
 	   tcontl (cdr termcont)
 	   termcont (car termcont))
      (cond ((setq temp (numberinlistp pfl))
-	    (setq d (oldgcdl temp (zl-remove temp pfl))
+	    (setq d (oldgcdl temp (remove temp pfl :test #'equal))
 		  pcofactl
-		  (mapcar (function (lambda(h) (pquotient h d))) pfl))
+		  (mapcar #'(lambda(h) (pquotient h d)) pfl))
 	    (setq contgcd termcont contcofactl tcontl)
 	    (go out)))
-     (setq pfcontl 
-	   (mapcar (function (lambda(h) 
-		     (cond ((eq var (car h)) (fastcont h))
-			   (t (list h 1)))))
-		   pfl))
-     (setq pfl
-	   (mapcar (function cadr) pfcontl)
-	   pfcontl
-	   (mapcar (function car) pfcontl))
+     (setq pfcontl (mapcar #'(lambda(h) (if (eq var (car h))
+					    (fastcont h)
+					    (list h 1)))
+			   pfl))
+     (setq pfl (mapcar #'cadr pfcontl)
+	   pfcontl (mapcar #'car pfcontl))
      (setq contgcd (ezgcd pfcontl svars modulus) pfcontl nil
 	   contcofactl (ptimesmerge tcontl (cdr contgcd))
 	   contgcd (ptimes termcont (car contgcd)))
      (cond ((numberinlistp pfl)
-	    (setq d 1. pcofactl pfl)(go out)))
+	    (setq d 1 pcofactl pfl) (go out)))
      (setq temp (listovarsl pfl))
-     (cond ((setq temp (intersect svars temp)) nil)
+     (cond ((setq temp (intersection svars temp :test #'equal)) nil)
 	   (t (setq d (newgcdl pfl)) (go end)))
-     (setq pl (bbsort pfl (quote degodr)))
+     (setq pl (bbsort pfl #'degodr))
      (setq nsvars (length svars))
-     (do ((i nsvars (sub1 i))) ((zerop i)) (setq svals (cons 0. svals)))
-     (setq lcprod 1 svalsl (list svals) 
+     (do ((i nsvars (1- i)))
+	 ((zerop i))
+       (push 0 svals))
+     (setq lcprod 1 svalsl (list svals)
 	   nsvals (expt tempprime (length svars)))
-     (do ((l
-	   (mapcar (function caddr) pl)
-	   (cdr l)))
+     (do ((l (mapcar #'caddr pl) (cdr l)))
 	 ((null l))
        (setq lcprod (ptimes lcprod (car l))))
-     (cond ((equal 0. (pcsub lcprod svals svars))
+     (cond ((equal 0 (pcsub lcprod svals svars))
 	    (setq evmapout (evmap svals pl))
 	    (cond (evmapout (setq svals (car evmapout)
 				  pl0 (cadr evmapout)
@@ -287,8 +230,8 @@
      (cond ((numberp d0) (setq degd0 0))
 	   (t (setq degd0 (cadr d0))))
      testd0
-     (cond ((equal 1. d0) (setq d 1.) 
-	    (setq d 1. pcofactl pfl) (go out)))
+     (cond ((equal 1 d0) (setq d 1)
+	    (setq d 1 pcofactl pfl) (go out)))
      (cond (degd0n (go testcofact)))
      anothersvals
      (setq evmapout (evmap svals pl))
@@ -297,16 +240,16 @@
 			   evmapout (car evmapout)))
 	   (t (desetq (d . pcofactl) (oldgcdcall pfl))
 	      (go out)))
-     (cond ((numberp d0n) (setq degd0n 0.))
+     (cond ((numberp d0n) (setq degd0n 0))
 	   (t (setq degd0n (cadr d0n))))
-     (cond ((greaterp degd0 degd0n)
+     (cond ((> degd0 degd0n)
 	    (setq degd0 degd0n pl0 pl0n d0 d0n svals evmapout)
 	    (go anothersvals)))
      (cond ((equal degd0 degd0n) (go testd0)) (t (go anothersvals)))
      testcofact
      (cond ((equal degd0 (cadar pl0)) nil) (t (go testgcd)))
      (setq d (car pl) temp pfl pcofactl nil)
-     loop (cond (temp (setq d0n (eztestdivide (car temp) d))) 
+     loop (cond (temp (setq d0n (eztestdivide (car temp) d)))
 		(t (setq ez1skip t) (go out)))
      (cond (d0n (setq pcofactl (append pcofactl (list d0n)))
 		(setq temp (cdr temp)) (go loop))
@@ -316,7 +259,7 @@
 		       (go out)))))
      testgcd
      (setq ith 1. temp pl0)
-     next (cond (temp nil)   
+     next (cond (temp nil)
 		(t (cond (tryagain  (setq d (nonsqfrcase pfl vl)
 					  pcofactl (cdr d)
 					  d (car d))
@@ -328,14 +271,14 @@
      (setq cofact0 (pquotient (car temp) d0))
      (cond ((numberp (newgcdcall d0 cofact0))
 	    (setq builder (ith pl ith))
-	    (cond ((intersect (listovars builder) svars)
+	    (cond ((intersection (listovars builder) svars :test #'equal)
 		   (go callez1)))))
-     (setq temp (cdr temp) ith (add1 ith)) (go next)
+     (setq temp (cdr temp) ith (1+ ith)) (go next)
      callez1
-     (setq lcpl (mapcar (function caddr) pl)
+     (setq lcpl (mapcar #'caddr pl)
 	   gcdlcs (car (ezgcd lcpl svars modulus))
 	   lcpl nil)
-     (setq d (ez1call builder 
+     (setq d (ez1call builder
 		      (list d0 cofact0) gcdlcs
 		      (reverse svals)
 		      (reverse svars)))
@@ -354,18 +297,22 @@
      (return (cons (ptimes contgcd d)
 		   (ptimesmerge contcofactl pcofactl)))))
 
-(defun listovarsl (plist) (prog (allvarsl allvars)
-			     (setq allvarsl (mapcar (function listovars) plist))
-			     (setq allvars (car allvarsl))
-			     (do ((l (cdr allvarsl) (cdr l))) ((null l))
-			       (setq allvars (union* allvars (car l))))
-			     (return allvars)))
+(defun listovarsl (plist)
+  (prog (allvarsl allvars)
+     (setq allvarsl (mapcar #'listovars plist))
+     (setq allvars (car allvarsl))
+     (do ((l (cdr allvarsl) (cdr l)))
+	 ((null l))
+       (setq allvars (union* allvars (car l))))
+     (return allvars)))
 
 (defmfun $ezgcd nargs
   (prog (pfl allvars presult flag genvar denom pfl2)
-					;need if genvar doesn't shrink
+     ;;need if genvar doesn't shrink
      (if (= nargs 0) (wna-err '$ezgcd))
-     (do ((i nargs (f1- i))) ((= i 0)) (if ($ratp (arg i)) (return (setq flag t))))
+     (do ((i nargs (1- i)))
+	 ((= i 0))
+       (if ($ratp (arg i)) (return (setq flag t))))
      (setq pfl (mapcar #'(lambda (h) (cdr (ratf h))) (listify nargs)))
      (setq pfl2 (list 1))
      (do ((lcm (cdar pfl))
@@ -390,17 +337,18 @@
      (return (if flag presult ($totaldisrep presult)))))
 
 (defun insrt (nth elt l)
-  (cond ((equal nth 1) (cons elt l))
-	(t (cons (car l) (insrt (f1- nth) elt (cdr l))))))
+  (if (eql nth 1)
+      (cons elt l)
+      (cons (car l) (insrt (1- nth) elt (cdr l)))))
 
 (defun nonsqfrcase(pl vl)
   (prog (d f ptr)
      (do ((dl pl (cdr dl))
-	  (pt 1 (f1+ pt)))
-	 ((intersect (cdr vl) (listovars (car dl)))
+	  (pt 1 (1+ pt)))
+	 ((intersection (cdr vl) (listovars (car dl)) :test #'equal)
 	  (setq f (car dl) ptr pt)))
      (setq d (ezgcd (list f (pderivative f (car f))) vl modulus)
-	   pl (ezgcd (cons (cadr d) (zl-remove f pl)) vl modulus)
+	   pl (ezgcd (cons (cadr d) (remove f pl :test #'equal)) vl modulus)
 	   pl (cons (car pl) (cons (car d) (cddr pl)))
 	   d (car pl))
      loop  (setq pl (ezgcd pl vl modulus))
@@ -408,7 +356,7 @@
 	    (return (cons d (insrt ptr (pquotient f d) (cdddr pl))))))
      (setq d (ptimes (car pl) d)
 	   pl (cons (car pl) (cddr pl)))
-     (go loop))) 
+     (go loop)))
 
 (defun eztestdivide (x y)
   (let ((errrjfflag t))
@@ -418,7 +366,7 @@
 
 (defun noterms (p)
   (cond ((pcoefp p) 1)
-	(t (do ((nt (noterms (caddr p)) (f+ nt (noterms (cadr p))))
+	(t (do ((nt (noterms (caddr p)) (+ nt (noterms (cadr p))))
 		(p (cdddr p) (cddr p)))
 	       ((null p) nt)))))
 
@@ -427,63 +375,62 @@
      (cond ((univar (cdr p)) (return (oldcontent p)))
 	   (t (setq oldgenvar genvar)
 	      (setq var (car p))
-	      (setq genvar (zl-remove var (intersect (cdr genvar) (listovars p))))))
+	      (setq genvar (remove var (intersection (cdr genvar) (listovars p) :test #'equal)
+				   :test #'equal))))
      (cond ((pminusp p) (setq p (pminus p) minus? t)))
      (setq tppl (oddelm (cddr p)))
      (cond ((null (cdr tppl))
 	    (setq tcont 1)
 	    (setq ans (car tppl))
 	    (go out)))
-     (setq tcontl (mapcar (function pmindegvec) tppl))
-     (setq tppl (mapcar (function (lambda(x y) (pquotient x (degvecdisrep y))))
+     (setq tcontl (mapcar #'pmindegvec tppl))
+     (setq tppl (mapcar #'(lambda(x y) (pquotient x (degvecdisrep y)))
 			tppl tcontl))
      (setq tcont (car tcontl))
      (do ((l (cdr tcontl) (cdr l))) ((null l))
-       (setq tcont (mapcar (function (lambda (x y) (min x y)))
+       (setq tcont (mapcar #'(lambda (x y) (min x y))
 			   tcont (car l))))
      (setq tcontl nil)
      (setq tcont (degvecdisrep tcont))
      (setq genvar oldgenvar)
      (cond ((setq temp (numberinlistp tppl))
-	    (cond ((or (zl-member 1 tppl)(zl-member -1 tppl))
+	    (cond ((or (member 1 tppl) (member -1 tppl))
 		   (setq ans 1))
-		  (t (setq ans (oldgcdl temp (zl-delete temp tppl)))))
+		  (t (setq ans (oldgcdl temp (delete temp tppl :test #'equal)))))
 	    (go out)))
-     (cond ((greaterp 4 (length tppl))
-	    (setq tppl (bbsort tppl 
-			       (function (lambda(a b) (greaterp (length a) (length b))))))
+     (cond ((> 4 (length tppl))
+	    (setq tppl (bbsort tppl #'(lambda(a b) (> (length a) (length b)))))
 	    (go skip)))
-     (setq coefvarl (mapcar (function listovars) tppl))
+     (setq coefvarl (mapcar #'listovars tppl))
      (setq temp (car coefvarl))
      (setq coefvarl (cdr coefvarl))
      loop (cond ((null coefvarl) nil)
-		(t (cond ((null (setq temp (intersect temp (car coefvarl)))) 
+		(t (cond ((null (setq temp (intersection temp (car coefvarl) :test #'equal)))
 			  (setq ans 1) (go out))
 			 (t (setq coefvarl (cdr coefvarl)) (go loop)))))
-     (setq temp (mapcar (function noterms) tppl))
-     (setq tppl (mapcar (function (lambda (x y) (list x y)))
+     (setq temp (mapcar #'noterms tppl))
+     (setq tppl (mapcar #'(lambda (x y) (list x y))
 			temp tppl))
-     (setq tppl (bbsort tppl (quote (lambda(x y) (greaterp (car x) (car y))))))
-     (setq tppl (mapcar (function cadr) tppl))
+     (setq tppl (bbsort tppl (quote (lambda(x y) (> (car x) (car y))))))
+     (setq tppl (mapcar #'cadr tppl))
      skip (setq small1 (car tppl))
      (setq small2 (cadr tppl))
      (setq ans (pgcd small1 small2))
-     (cond ((equal 1 ans) (go out))
-	   ((equal -1 ans) (setq ans 1) (go out)))
+     (cond ((eql 1 ans) (go out))
+	   ((eql -1 ans) (setq ans 1) (go out)))
      (cond ((cddr tppl) (setq ans (cons ans (cddr tppl))))
 	   (t (go out)))
-     (setq temp (sort (listovarsl ans) (function pointergp)))
+     (setq temp (sort (listovarsl ans) #'pointergp))
      (setq ans (car (ezgcd ans temp modulus)))
      out (setq tcont (ptimes tcont ans))
      (setq p (pquotient p tcont))
      (cond (minus? (setq tcont (pminus tcont))))
      (return (list tcont p))))
 
-#-nil
-(declare-top(unspecial lcprod svals svars oldsvars oldsvals
-		       valflag pl0 d0 degd0 subvar subval var
-		       many* tempprime ovarlist valist klim
-		       zl *prime plim nn* ne nn*-1 blist1 dlp
-		       ez1skip svalsl nsvals
-		       lc1 oldlc df1 df2 res limk *ab*
-		       *sharpa *sharpb fact1 fact2))
+(declare-top (unspecial lcprod svals svars oldsvars oldsvals
+			valflag pl0 d0 degd0 subvar subval var
+			many* tempprime ovarlist valist klim
+			zl *prime plim nn* ne nn*-1 blist1 dlp
+			ez1skip svalsl nsvals
+			lc1 oldlc df1 df2 res limk *ab*
+			*sharpa *sharpb fact1 fact2))
