@@ -12,54 +12,33 @@
 
 (macsyma-module grind)
 
-(declare-top (genprefix gri)
-	     (special lop rop *grind-charlist* chrps $aliases aliaslist linel)
-	     (fixnum (chrct))
-	     (*expr lbp rbp))
+(declare-top (special lop rop *grind-charlist* chrps $aliases aliaslist linel))
 
-(defun chrct () (f- linel chrps))
+(defun chrct () (- linel chrps))
 
-(defun chrct* () (f- linel chrps))
-
-(defvar alphabet '(#\% #\_))
+(defun chrct* () (- linel chrps))
 
 (defvar fortranp nil)
 
-;;(DEFMSPEC $GRIND (X) (SETQ X (CDR X))
-;;  (LET (Y)
-;;    (IF (NOT (ZEROP (CHARPOS T))) (MTERPRI))
-;;    (COND ((OR (NULL X) (CDR X)) (WNA-ERR '$GRIND))
-;;	  ((ATOM (SETQ X (STRMEVAL (CAR X))))
-;;	   (SETQ X ($VERBIFY X))
-;;	   (COND ((SETQ Y (MGET X 'MEXPR))
-;;		  (MGRIND (LIST '(MDEFINE) (CONS (LIST X) (CDADR Y)) (CADDR Y)) NIL))
-;;		 ((SETQ Y (MGET X 'MMACRO))
-;;		  (MGRIND (LIST '(MDEFMACRO) (CONS (LIST X) (CDADR Y)) (CADDR Y)) NIL))
-;;		 ((SETQ Y (MGET X 'AEXPR))
-;;		  (MGRIND (LIST '(MDEFINE) (CONS (LIST X 'ARRAY) (CDADR Y)) (CADDR Y)) NIL))
-;;		 (T (MGRIND X NIL)))
-;;	   (TYO #/$ NIL))
-;;	  (T (MGRIND X NIL) (TYO #/$ NIL)))
-;;    '$DONE))
-;;Update from F302 --gsb
-
-(defmspec $grind (x) (setq x (cdr x))
-	  (let (y)
-	    #+nocp(fresh-line)
-	    #-nocp(if (not (zerop (charpos t))) (mterpri))
-	    (cond ((or (null x) (cdr x)) (wna-err '$grind))
-		  ((symbolp (setq x (strmeval (car x))))
-		   (unless (mstringp x) (setq x ($verbify x)))
-		   (cond ((setq y (mget x 'mexpr))
-			  (mgrind (list '(mdefine) (cons (list x) (cdadr y)) (caddr y)) nil))
-			 ((setq y (mget x 'mmacro))
-			  (mgrind (list '(mdefmacro) (cons (list x) (cdadr y)) (caddr y)) nil))
-			 ((setq y (mget x 'aexpr))
-			  (mgrind (list '(mdefine) (cons (list x 'array) (cdadr y)) (caddr y)) nil))
-			 (t (mgrind x nil)))
-		   (tyo #\$ nil) (tyo #\Newline nil))
-		  (t (mgrind x nil) (tyo #\$ nil) (tyo #\Newline nil)))
-	    '$done))
+(defmspec $grind (x)
+  (setq x (cdr x))
+  (let (y)
+    (fresh-line)
+    (cond
+      ((null x))
+      ((cdr x) (mapc #'(lambda (xx) (funcall (get '$grind 'mfexpr*) `(($grind) ,xx))) x))
+      ((symbolp (setq x (strmeval (car x))))
+       (unless (mstringp x) (setq x ($verbify x)))
+       (cond ((setq y (mget x 'mexpr))
+	      (mgrind (list '(mdefine) (cons (list x) (cdadr y)) (caddr y)) nil))
+	     ((setq y (mget x 'mmacro))
+	      (mgrind (list '(mdefmacro) (cons (list x) (cdadr y)) (caddr y)) nil))
+	     ((setq y (mget x 'aexpr))
+	      (mgrind (list '(mdefine) (cons (list x 'array) (cdadr y)) (caddr y)) nil))
+	     (t (mgrind x nil)))
+       (write-char #\$ nil) (write-char #\Newline nil))
+      (t (mgrind x nil) (write-char #\$ nil) (write-char #\Newline nil)))
+    '$done))
 
 (defun show-msize (lis)
   (format t "~%Length is ~A" (car lis))
@@ -83,8 +62,7 @@
 
 (defun i-$grind (x)
   (let (y)
-    #+nocp(fresh-line)
-    #-nocp(if (not (zerop (charpos t))) (mterpri))
+    (fresh-line)
     (cond  ((symbolp (setq x (strmeval  x)))
 	    (setq x ($verbify x))
 	    (cond ((setq y (mget x 'mexpr))
@@ -94,10 +72,10 @@
 		  ((setq y (mget x 'aexpr))
 		   (mgrind (list '(mdefine) (cons (list x 'array) (cdadr y)) (caddr y)) nil))
 		  (t (mgrind x nil)))
-	    (tyo #\$ nil))
-	   (t (mgrind x nil) (tyo #\$ nil)))
+	    (write-char #\$ nil))
+	   (t (mgrind x nil) (write-char #\$ nil)))
     '$done))
-  
+
 
 (defun mgrind (x out)
   (setq chrps 0)
@@ -105,7 +83,7 @@
 
 (defun mprint (x out)
   (cond ((characterp x)
-	 (setq chrps (f1+ chrps)) (tyo x out))
+	 (setq chrps (1+ chrps)) (write-char x out))
 	((< (car x) (chrct*)) (mapc #'(lambda (l) (mprint l out)) (cdr x)))
 	(t (prog (i) (setq i chrps)
 		 (mprint (cadr x) out)
@@ -115,7 +93,7 @@
 				 (atom (caddr x)) (< (caaddr x) (chrct*))))
 			(setq i chrps)
 			(mprint (caddr x) out))
-		       (t (setq i (f1+ i)) (setq chrps 0) (terpri out)
+		       (t (setq i (1+ i)) (setq chrps 0) (terpri out)
 			  (mtyotbsp i out) (mprint (caddr x) out)))
 		 (do ((l (cdddr x) (cdr l))) ((null l))
 		   (cond
@@ -124,9 +102,9 @@
 		   (mprint (car l) out))))))
 
 (defun mtyotbsp (n out) (declare (fixnum n))
-       (setq chrps (f+ n chrps))
-       (do () ((< n 8)) (tyo #\tab out) (setq n (f- n 8)))
-       (do () ((< n 1)) (tyo #\space out) (setq n (f1- n))))
+       (setq chrps (+ n chrps))
+       (do () ((< n 8)) (write-char #\tab out) (setq n (- n 8)))
+       (do () ((< n 1)) (write-char #\space out) (setq n (1- n))))
 
 (defun strgrind (x)
   (let (*grind-charlist* (chrps 0))
@@ -145,7 +123,7 @@
 			      (atom (caddr x)) (< (caaddr x) (chrct*))))
 		     (setq i chrps)
 		     (strprint (caddr x)))
-		    (t (setq i (f1+ i)) (setq chrps 0) (sterpri)
+		    (t (setq i (1+ i)) (setq chrps 0) (sterpri)
 		       (styotbsp i) (strprint (caddr x))))
 	      (do ((l (cdddr x) (cdr l))) ((null l))
 		(cond
@@ -153,13 +131,13 @@
 		  (t (setq chrps 0) (sterpri) (styotbsp i)))
 		(strprint (car l)))))))
 
-(defun styo (x) (setq *grind-charlist* (cons x *grind-charlist*) chrps (f1+ chrps)))
+(defun styo (x) (setq *grind-charlist* (cons x *grind-charlist*) chrps (1+ chrps)))
 
 (defun sterpri () (setq *grind-charlist* (cons #\newline *grind-charlist*) chrps 0))
 
 (defun styotbsp (n) (declare (fixnum n)) (setq chrps n)
-       (do () ((< n 8)) (setq *grind-charlist* (cons #\tab *grind-charlist*) n (f- n 8)))
-       (do () ((< n 1)) (setq *grind-charlist* (cons #\space *grind-charlist*) n (f1- n))))
+       (do () ((< n 8)) (setq *grind-charlist* (cons #\tab *grind-charlist*) n (- n 8)))
+       (do () ((< n 1)) (setq *grind-charlist* (cons #\space *grind-charlist*) n (1- n))))
 
 (defmfun mstring (x)
   (nreverse (string1 (msize x nil nil 'mparen 'mparen) nil)))
@@ -176,7 +154,7 @@
   (cond ((atom x) (if fortranp (msz (makestring x) l r) (msize-atom x l r)))
 	((or (<= (lbp (caar x)) (rbp lop)) (> (lbp rop) (rbp (caar x))))
 	 (msize-paren x l r))
-	((memq 'array (cdar x)) (msize-array x l r))
+	((member 'array (cdar x) :test #'eq) (msize-array x l r))
 	((safe-get (caar x) 'grind)
 	 (the (values t) (funcall (get (caar x) 'grind) x l r)))
 	(t (msize-function x l r nil))))
@@ -185,25 +163,20 @@
   (prog (y)
      (cond ((numberp x) (setq y (exploden x)))
 	   ((and (setq y (safe-get x 'reversealias))
-		 (not (and (memq x $aliases) (get x 'noun))))
+		 (not (and (member x $aliases :test #'eq) (get x 'noun))))
 	    (setq y (exploden y)))
-	   ((setq y (assqr x aliaslist)) (return (msize (car y) l r lop rop)))
+	   ((setq y (rassoc x aliaslist :test #'eq)) (return (msize (car y) l r lop rop)))
        ((null (setq y (exploden x))))
        ((safe-get x 'noun) (return (msize-atom (get x 'noun) l r)))
 	   ((char= #\$ (car y)) (setq y (slash (cdr y))))
 	   ((char= #\& (car y))
 	    (do ((l (cdr y) (cdr l))) ((null l))
-	      (cond ((or (zl-member (car l)
-				    '(#. double-quote-char
-				      #. back-slash-char
-				      #. semi-colon-char #\$))
+	      (cond ((or (member (car l) '(#\" #\\ #\; #\$) :test #'equal)
 			 (and (char< (car l) #\space)
-			      (not (char= (car l) #\return ;13
-					  ))))
+			      (not (char= (car l) #\return))))
 		     (rplacd l (cons (car l) (cdr l)))
-		     (rplaca l #. back-slash-char) (setq l (cdr l)))))
-	    (setq y (cons #.double-quote-char
-			  (nconc (cdr y) (list #.double-quote-char)))))
+		     (rplaca l #\\) (setq l (cdr l)))))
+	    (setq y (cons #\" (nconc (cdr y) (list #\")))))
 	   (t (setq y (cons #\? (slash y)))))
      (return (msz y l r))))
 
@@ -211,21 +184,20 @@
 
 (defun slash (x)
   (do ((l (cdr x) (cdr l))) ((null l))
-    (if (or (alphanumericp (car l))
-	    (eql (car l) #\%)
-	    (eql (car l) #\_))
+    ; Following test is the same (except backslash is not included,
+    ; so backslash is preceded by backslash) as in SCAN-TOKEN (src/nparse.lisp).
+    (if (or (ascii-numberp (car l)) (alphabetp (car l)))
 	nil
 	(progn (rplacd l (cons (car l) (cdr l)))
-	       (rplaca l #. back-slash-char) (setq l (cdr l)))))
-  (if (alphabetp (car x)) x (cons #. back-slash-char x)))
+	       (rplaca l #\\) (setq l (cdr l)))))
+  (if (alphabetp (car x)) x (cons #\\ x)))
 
 ;;#-cl
 ;;(DEFUN ALPHANUMP (N) (DECLARE (FIXNUM N))
 ;;  (OR (ASCII-NUMBERP N) (ALPHABETP N)))
 
 (defun msize-paren (x l r)
-  (msize x (cons #.left-parentheses-char l)
-	 (cons #.right-parentheses-char r) 'mparen 'mparen))
+  (msize x (cons #\( l) (cons #\) r) 'mparen 'mparen))
 
 ;; The variables LB and RB are not uses here syntactically, but for
 ;; communication.  The FORTRAN program rebinds them to #/( and #/) since
@@ -237,45 +209,46 @@
 (defun msize-array (x l r &aux f)
   (if (eq (caar x) 'mqapply) (setq f (cadr x) x (cdr x)) (setq f (caar x)))
   (cond ((and (symbolp (caar x)) (get (caar x) 'verb) (get (caar x) 'alias))
-	 (setq l (reconc '(#\' #\') l)))
+	 (setq l (revappend '(#\' #\') l)))
 	((and (symbolp (caar x))
 	      (get (caar x) 'noun)
-	      (not (memq (caar x) (cdr $aliases)))
+	      (not (member (caar x) (cdr $aliases) :test #'eq))
 	      (not (get (caar x) 'reversealias)))
 	 (setq l (cons #\' l))))
   (setq l (msize f l (list lb) lop 'mfunction)
 	r (msize-list (cdr x) nil (cons rb r)))
-  (cons (f+ (car l) (car r)) (cons l (cdr r))))
+  (cons (+ (car l) (car r)) (cons l (cdr r))))
 
 (defun msize-function (x l r op)
   (cond ((not (symbolp (caar x))))
 	((and (get (caar x) 'verb) (get (caar x) 'alias))
-	 (setq l (reconc '(#\' #\') l)))
-	((and (get (caar x) 'noun) (not (memq (caar x) (cdr $aliases)))
+	 (setq l (revappend '(#\' #\') l)))
+	((and (get (caar x) 'noun) (not (member (caar x) (cdr $aliases) :test #'eq))
 	      (not (get (caar x) 'reversealias)))
 	 (setq l (cons #\' l))))
-  (setq l (msize (if op (getop (caar x)) (caar x)) l (ncons #. left-parentheses-char ) 'mparen 'mparen)
-	r (msize-list (cdr x) nil (cons #. right-parentheses-char r)))
-  (cons (f+ (car l) (car r)) (cons l (cdr r))))
+  (setq l (msize (if op (getop (caar x)) (caar x)) l (ncons #\( ) 'mparen 'mparen)
+	r (msize-list (cdr x) nil (cons #\) r)))
+  (cons (+ (car l) (car r)) (cons l (cdr r))))
 
 (defun msize-list (x l r)
   (if (null x) (msz nil l r)
       (do ((nl) (w 0))
 	  ((null (cdr x))
 	   (setq nl (cons (msize (car x) l r 'mparen 'mparen) nl))
-	   (cons (f+ w (caar nl)) (nreverse nl)))
+	   (cons (+ w (caar nl)) (nreverse nl)))
 	(declare (fixnum w))
 	(setq nl (cons (msize (car x) l (list #\,) 'mparen 'mparen) nl)
-	      w (f+ w (caar nl)) x (cdr x) l nil))))
+	      w (+ w (caar nl)) x (cdr x) l nil))))
 
 (defun msize-prefix (x l r)
-  (msize (cadr x) (reconc (strsym (caar x)) l) r (caar x) rop))
+  (msize (cadr x) (revappend (strsym (caar x)) l) r (caar x) rop))
 
 (defun msize-infix (x l r)
-  (if (or (null (cddr x)) (cdddr x)) (wna-err (caar x)))
+  (if (not (= (length (cdr x)) 2))
+    (return-from msize-infix (msize-function x l r t)))
   (setq l (msize (cadr x) l nil lop (caar x))
 	r (msize (caddr x) (reverse (strsym (caar x))) r (caar x) rop))
-  (list (f+ (car l) (car r)) l r))
+  (list (+ (car l) (car r)) l r))
 
 (defun msize-postfix (x l r)
   (msize (cadr x) l (append (strsym (caar x)) r) lop (caar x)))
@@ -289,7 +262,7 @@
 	l (cons (length l) l)
 	r (append (cdr (strsym (caar x))) r)
 	x (msize-list (cdr x) nil r))
-  (cons (f+ (car l) (car x)) (cons l (cdr x))))
+  (cons (+ (car l) (car x)) (cons l (cdr x))))
 
 (defun msznary (x l r dissym)
   (cond ((null (cddr x)) (msize-function x l r t))
@@ -297,11 +270,11 @@
 	   (do ((ol (cddr x) (cdr ol)) (nl (list l)) (w (car l)))
 	       ((null (cdr ol))
 		(setq r (msize (car ol) (reverse dissym) r (caar x) rop))
-		(cons (f+ (car r) w) (nreverse (cons r nl))))
+		(cons (+ (car r) w) (nreverse (cons r nl))))
 	     (declare (fixnum w))
 	     (setq nl (cons (msize (car ol) (reverse dissym) nil (caar x) (caar x))
 			    nl)
-		   w (f+ (caar nl) w))))))
+		   w (+ (caar nl) w))))))
 
 (defun strsym (x) (or (get x 'strsym) (get x 'dissym)))
 
@@ -316,10 +289,21 @@
 (defprop mqapply msz-mqapply grind)
 
 (defun msz-mqapply (x l r)
-  (setq l (msize (cadr x) l (list #. left-parentheses-char ) lop 'mfunction)
-	r (msize-list (cddr x) nil (cons #. right-parentheses-char r)))
-  (cons (f+ (car l) (car r)) (cons l (cdr r))))
+  (setq l (msize (cadr x) l (list #\( ) lop 'mfunction)
+	r (msize-list (cddr x) nil (cons #\) r)))
+  (cons (+ (car l) (car r)) (cons l (cdr r))))
 
+; SPACEOUT appears solely in trace output. See mtrace.lisp.
+
+(defprop spaceout msize-spaceout grind)
+
+(defun msize-spaceout (x ll r)
+  (declare (ignore ll r))
+  (let ((n (cadr x))
+	l)
+    (dotimes (i n)
+      (push #\space l))
+    (cons n l)))
 
 (defprop mquote msize-prefix grind)
 (defprop msetq msize-infix grind)
@@ -345,14 +329,14 @@
 (defprop mdefmacro 20. rbp)
 
 (defun msz-mdef (x l r)
-  (setq l (msize (cadr x) l (copy-top-level (strsym (caar x))) lop (caar x))
+  (setq l (msize (cadr x) l (copy-list (strsym (caar x))) lop (caar x))
 	r (msize (caddr x) nil r (caar x) rop))
-  (setq x (cons (f- (car l) (caadr l)) (cddr l)))
+  (setq x (cons (- (car l) (caadr l)) (cddr l)))
   (if (and (not (atom (cadr r))) (not (atom (caddr r)))
-	   (< (f+ (car l) (caadr r) (caaddr r)) linel))
+	   (< (+ (car l) (caadr r) (caaddr r)) linel))
       (setq x (nconc x (list (cadr r) (caddr r)))
 	    r (cons (car r) (cdddr r))))
-  (cons (f+ (car l) (car r)) (cons (cadr l) (cons x (cdr r)))))
+  (cons (+ (car l) (car r)) (cons (cadr l) (cons x (cdr r)))))
 
 
 (defprop mfactorial msize-postfix grind)
@@ -367,7 +351,7 @@
 	r (if (mmminusp (setq x (nformat (caddr x))))
 	      (msize (cadr x) (reverse '(#\^ #\-)) r 'mexpt rop)
 	      (msize x (list #\^) r 'mexpt rop)))
-  (list (f+ (car l) (car r)) l r))
+  (list (+ (car l) (car r)) l r))
 
 
 (defprop mncexpt msize-infix grind)
@@ -387,7 +371,7 @@
 
 (defprop mquotient msize-infix grind)
 (defprop mquotient 120. lbp)
-(defprop mquotient 120. rbp) 
+(defprop mquotient 120. rbp)
 (defprop rat msize-infix grind)
 (defprop rat 120. lbp)
 (defprop rat 120. rbp)
@@ -407,12 +391,12 @@
 		(if (mmminusp (car x)) (setq l (cadar x) dissym (list #\-))
 		    (setq l (car x) dissym (list #\+)))
 		(setq r (msize l dissym r 'mplus rop))
-		(cons (f+ (car r) w) (nreverse (cons r nl))))
+		(cons (+ (car r) w) (nreverse (cons r nl))))
 	     (declare (fixnum w))
 	     (if (mmminusp (car x)) (setq l (cadar x) dissym (list #\-))
 		 (setq l (car x) dissym (list #\+)))
 	     (setq nl (cons (msize l dissym nil 'mplus 'mplus) nl)
-		   w (f+ (caar nl) w)
+		   w (+ (caar nl) w)
 		   x (cdr x))))))
 
 (defprop mminus msize-prefix grind)
@@ -466,65 +450,62 @@
 ;; See comments above DIM-MCOND in displa.lisp concerning MCOND parsing and formatting.
 
 (defun msz-mcond (x l r)
-  (setq if (nreconc l '(#\i #\f #\space))
-        if (cons (length if) if)
-        l (msize (cadr x) nil nil 'mcond 'mparen))
+  (let ((if (nreconc l '(#\i #\f #\space))))
+    (setq if (cons (length if) if)
+	  l (msize (cadr x) nil nil 'mcond 'mparen))
 
-    (let
-      ((args (cdddr x))
-       (if-literal (reverse (exploden "if ")))
-       (else-literal (reverse (exploden " else ")))
-       (elseif-literal (reverse (exploden " elseif ")))
-       (then-literal (reverse (exploden " then ")))
-       (parts)
-       (part))
+
+    (let ((args (cdddr x))
+	  (else-literal (reverse (exploden " else ")))
+	  (elseif-literal (reverse (exploden " elseif ")))
+	  (then-literal (reverse (exploden " then ")))
+	  (parts)
+	  (part))
 
       (let ((sgra (reverse args)))
-        (if (and (or (eq (car sgra) nil) (eq (car sgra) '$false)) (eq (cadr sgra) t))
-          (setq args (reverse (cddr sgra)))))
+	(if (and (or (eq (car sgra) nil) (eq (car sgra) '$false)) (eq (cadr sgra) t))
+	    (setq args (reverse (cddr sgra)))))
 
       (setq parts (list if l))
 
-      (setq part
-            (cond
-              ((= (length args) 0)
-               `(,(msize (caddr x) (copy then-literal) r 'mcond rop)))
-              (t
-                `(,(msize (caddr x) (copy then-literal) nil 'mcond 'mparen))))
+      (setq part (cond ((= (length args) 0)
+			`(,(msize (caddr x) (copy-tree then-literal) r 'mcond rop)))
+		       (t
+			`(,(msize (caddr x) (copy-tree then-literal) nil 'mcond 'mparen))))
+
+	    parts (append parts part))
 
-            parts (append parts part))
-      
       (loop while (>= (length args) 2) do
-        (let ((maybe-elseif (car args)) (else-or-then (cadr args)))
-          (cond
-            ((= (length args) 2)
-             (cond
-               ((eq maybe-elseif t)
-                (let ((else-arg else-or-then))
-                  (setq
-                    part `(,(msize else-arg (copy else-literal) r 'mcond rop))
-                    parts (append parts part))))
-               (t
-                 (let ((elseif-arg maybe-elseif) (then-arg else-or-then))
-                   (setq
-                     part `(,(msize elseif-arg (copy elseif-literal) nil 'mcond 'mparen)
-                             ,(msize then-arg (copy then-literal) r 'mcond rop))
-                     parts (append parts part))))))
-            (t
-              (let ((elseif-arg maybe-elseif) (then-arg else-or-then))
-                (setq
-                  part `(,(msize elseif-arg (copy elseif-literal) nil 'mcond 'mparen)
-                          ,(msize then-arg (copy then-literal) nil 'mcond 'mparen))
-                  parts (append parts part))))))
+	   (let ((maybe-elseif (car args)) (else-or-then (cadr args)))
+	     (cond
+	       ((= (length args) 2)
+		(cond
+		  ((eq maybe-elseif t)
+		   (let ((else-arg else-or-then))
+		     (setq
+		      part `(,(msize else-arg (copy-tree else-literal) r 'mcond rop))
+		      parts (append parts part))))
+		  (t
+		   (let ((elseif-arg maybe-elseif) (then-arg else-or-then))
+		     (setq
+		      part `(,(msize elseif-arg (copy-tree elseif-literal) nil 'mcond 'mparen)
+			      ,(msize then-arg (copy-tree then-literal) r 'mcond rop))
+		      parts (append parts part))))))
+	       (t
+		(let ((elseif-arg maybe-elseif) (then-arg else-or-then))
+		  (setq
+		   part `(,(msize elseif-arg (copy-tree elseif-literal) nil 'mcond 'mparen)
+			   ,(msize then-arg (copy-tree then-literal) nil 'mcond 'mparen))
+		   parts (append parts part))))))
 
-        (setq args (cddr args)))
+	   (setq args (cddr args)))
 
-      (cons (apply '\+ (mapcar 'car parts)) parts)))
+      (cons (apply '\+ (mapcar #'car parts)) parts))))
 
 (defprop text-string msize-text-string grind)
 
-(defun msize-text-string (x l r)
-  (declare (ignore r))
+(defun msize-text-string (x ll r)
+  (declare (ignore ll r))
   (cons (length (cdr x)) (cdr x)))
 
 (defprop mdo msz-mdo grind)
@@ -571,6 +552,3 @@
 		`($while ,(cadr (seventh x))))
 	       (t `($unless ,(seventh x))))
 	 `($do ,(eighth x))))
-
-
-
