@@ -1,8 +1,8 @@
 ;;********************************************************
-;; file:        init-cl.lisp                              
-;; description: Initialize Maxima                         
-;; date:        Wed Jan 13 1999 - 20:27                   
-;; author:      Liam Healy <Liam.Healy@nrl.navy.mil>      
+;; file:        init-cl.lisp
+;; description: Initialize Maxima
+;; date:        Wed Jan 13 1999 - 20:27
+;; author:      Liam Healy <Liam.Healy@nrl.navy.mil>
 ;;********************************************************
 
 (in-package :maxima)
@@ -15,6 +15,7 @@
 ;;; redundant. It is kept for consistency with the same variables in
 ;;; shell scripts, batch scripts and environment variables.
 ;;; jfa 02/07/04
+
 (defvar *maxima-prefix*)
 (defvar *maxima-imagesdir*)
 (defvar *maxima-sharedir*)
@@ -74,8 +75,6 @@
 	#+openmcl "openmcl"
 	#-(or clisp cmu scl sbcl gcl allegro openmcl) "unknownlisp")
 
-
-
 (defvar $file_search_lisp nil
   "Directories to search for Lisp source code.")
 
@@ -92,7 +91,6 @@
 
 (defvar $chemin nil)
 
-
 (defun maxima-parse-dirstring (str)
   (let ((sep "/"))
     (if (position (character "\\") str)
@@ -104,13 +102,10 @@
 		       (setf dev (first dev)))
 		   (if (and dev (not (eq dev :unspecific))
 			    (not (string= dev "")))
-		       (concatenate 'string
-				    (string-right-trim 
-				     ":" dev) ":")
+		       (concatenate 'string (string-right-trim ":" dev) ":")
 		       ""))
 		 "/"
-		 (combine-path
-		  (rest (pathname-directory str))))))
+		 (combine-path (rest (pathname-directory str))))))
 
 (defun set-pathnames-with-autoconf (maxima-prefix-env)
   (let ((libdir)
@@ -119,7 +114,7 @@
 	(infodir)
 	(package-version (combine-path (list *autoconf-package*
 					     *autoconf-version*)))
-	(binary-subdirectory (concatenate 'string 
+	(binary-subdirectory (concatenate 'string
 					  "binary-" *maxima-lispname*)))
     (if maxima-prefix-env
 	(progn
@@ -153,10 +148,10 @@
 	  (combine-path (list libexecdir package-version)))))
 
 (defun set-pathnames-without-autoconf (maxima-prefix-env)
-  (let ((maxima-prefix (if maxima-prefix-env 
+  (let ((maxima-prefix (if maxima-prefix-env
 			   maxima-prefix-env
 			   (maxima-parse-dirstring *autoconf-prefix*)))
-	(binary-subdirectory (concatenate 'string 
+	(binary-subdirectory (concatenate 'string
 					  "binary-" *maxima-lispname*)))
 
     (setq *maxima-imagesdir*
@@ -180,10 +175,10 @@
 (defun default-userdir ()
   (let ((home-env (maxima-getenv "HOME"))
 	(base-dir "")
-	(maxima-dir (if (string= *autoconf-win32* "true") 
-			"maxima" 
+	(maxima-dir (if (string= *autoconf-win32* "true")
+			"maxima"
 			".maxima")))
-    (setf base-dir 
+    (setf base-dir
 	  (if (and home-env (string/= home-env ""))
 	      ;; use home-env...
 	      (if (string= home-env "c:\\")
@@ -200,7 +195,7 @@
 (defun default-tempdir ()
   (let ((home-env (maxima-getenv "HOME"))
 	(base-dir ""))
-    (setf base-dir 
+    (setf base-dir
 	  (if (and home-env (string/= home-env ""))
 	      (if (string= home-env "c:\\")
 		  "c:\\user\\"
@@ -212,52 +207,44 @@
 
 (defun set-locale ()
   (let (locale language territory codeset)
-    (setq cl-info::*index-name* "index")
+    ;; Determine *maxima-lang-subdir*
+    ;;   1. from MAXIMA_LANG_SUBDIR environment variable
+    ;;   2. if 1. isn't set from user locale
     (unless  (setq *maxima-lang-subdir* (maxima-getenv "MAXIMA_LANG_SUBDIR"))
-	(setq locale (or (maxima-getenv "LC_ALL")
-                         (maxima-getenv "LC_MESSAGES")
-                         (maxima-getenv "LANG")))
-	(cond
-	    ((null locale) 
-		(setq *maxima-lang-subdir* nil))
-	    ((zl-member locale '("C" "POSIX" "c" "posix")) 		 
-		(setq *maxima-lang-subdir* nil))
-	    (t  (when (eql (position #\. locale) 5)
+      (setq locale
+	    (or
+	      (let ((x (maxima-getenv "LC_ALL"))) (if (and x (not (equal x ""))) x))
+	      (let ((x (maxima-getenv "LC_MESSAGES"))) (if (and x (not (equal x ""))) x))
+	      (let ((x (maxima-getenv "LANG"))) (if (and x (not (equal x ""))) x))))
+	(cond ((or (null locale) (equal locale ""))
+	       (setq *maxima-lang-subdir* nil))
+	      ((member locale '("C" "POSIX" "c" "posix") :test #'equal)
+	       (setq *maxima-lang-subdir* nil))
+	      (t  (when (eql (position #\. locale) 5)
 		    (setq codeset (string-downcase (subseq locale 6))))
-		(when (eql (position #\_ locale) 2)
+		  (when (eql (position #\_ locale) 2)
 		    (setq territory (string-downcase (subseq locale 3 5))))
-		(setq language (string-downcase (subseq locale 0 2)))
-		;; Set *maxima-lang-subdir* only for known languages.
-		;; Extend procedure below as soon as new translation
-		;; is available. 
-		(cond
-		    ;; English
-		    ((equal language "en")
-			(setq *maxima-lang-subdir* nil))
-		    ;; Latin-1 aka iso-8859-1 languages 
-		    ((zl-member language '("es" "pt"))
-		      (if (zl-member codeset '("utf-8" "utf8"))
-		    	    (setq *maxima-lang-subdir* (concatenate 'string language ".utf8"))
-		    	    (setq *maxima-lang-subdir* language)))
-		    (t  (setq *maxima-lang-subdir* nil)))
-		;; Translation of the word "Index" to match node "Fuction and Variable Index"
-		(cond
-		    ((equal language "es")
-			(setq cl-info::*index-name* (format nil "~andice" (code-char #xCD))))
-		    ((equal language "pt")
-			(setq cl-info::*index-name* (format nil "~andice" (code-char #xCD)))) 
-		)
-		;; Additional language-dependent pattern to match nodes such as 
-		;;  -- Function: foo (x)
-		;; or
-		;;  -- Option variable: bar
-		(cond 
-		    ;; This pattern is suitable for all Latin-1 (aka ISO-8859-1) langages
-		    ((zl-member language '("es" "pt"))
-		        (setq cl-info::*extra-chars* (format nil "~a-~a" (code-char #xC0) (code-char #xFF))))
-		)
-	    )))
-   (setq cl-info::*lang-subdir* *maxima-lang-subdir*)))    
+		  (setq language (string-downcase (subseq locale 0 2)))
+		  ;; Set *maxima-lang-subdir* only for known languages.
+		  ;; Extend procedure below as soon as new translation
+		  ;; is available.
+		  (cond ((equal language "en") ;; English
+			 (setq *maxima-lang-subdir* nil))
+			;; Latin-1 aka iso-8859-1 languages
+			((member language '("es" "pt" "fr" "de" "it") :test #'equal)
+			 (if (and (string= language "pt") (string= territory "br"))
+			     (setq *maxima-lang-subdir* (concatenate 'string language "_BR"))
+			     (setq *maxima-lang-subdir* language))
+			 (if (member codeset '("utf-8" "utf8") :test #'equal)
+			     (setq *maxima-lang-subdir* (concatenate 'string *maxima-lang-subdir* ".utf8"))))
+			;; Russian. Default codepage cp1251
+			((string= language "ru")
+			 (setq *maxima-lang-subdir* language)
+			 (cond ((member codeset '("utf-8" "utf8") :test #'equal)
+				(setq *maxima-lang-subdir* (concatenate 'string *maxima-lang-subdir* ".utf8")))
+			       ((member codeset '("koi8-r" "koi8r") :test #'equal)
+				(setq *maxima-lang-subdir* (concatenate 'string *maxima-lang-subdir* ".koi8r")))))
+			(t  (setq *maxima-lang-subdir* nil))))))))
 
 (defun set-pathnames ()
   (let ((maxima-prefix-env (maxima-getenv "MAXIMA_PREFIX"))
@@ -290,7 +277,7 @@
     (setf (gethash '$maxima_userdir *variable-initial-values*) *maxima-userdir*)
     (setq $maxima_tempdir *maxima-tempdir*)
     (setf (gethash '$maxima_tempdir *variable-initial-values*) *maxima-tempdir*))
-  
+
   (let* ((ext #+gcl "o"
 	      #+(or cmu scl) (c::backend-fasl-file-type c::*target-backend*)
 	      #+sbcl "fasl"
@@ -300,7 +287,7 @@
 	      #+(and openmcl linuxppc-target) "pfsl"
 	      #-(or gcl cmu scl sbcl clisp allegro openmcl)
 	      "")
-	 (lisp-patterns (concatenate 
+	 (lisp-patterns (concatenate
 			 'string "###.{"
 			 (concatenate 'string ext ",lisp,lsp}")))
 	 (maxima-patterns "###.{mac,mc}")
@@ -308,55 +295,62 @@
 	 (usage-patterns "##.{usg,texi}")
 	 (share-subdirs-list
        '("affine"
-         "algebra"
-         "algebra/charsets"
-         "algebra/solver"
-         "calculus"
-         "combinatorics"
-         "contrib"
-         "contrib/boolsimp"
-         "contrib/descriptive"
-         "contrib/diffequations"
-         "contrib/diffequations/tests"
-         "contrib/distrib"
-         "contrib/ezunits"
-         "contrib/format"
-         "contrib/gentran"
-         "contrib/gentran/test"
-         "contrib/Grobner"
-         "contrib/lurkmathml"
-         "contrib/maximaMathML"
-         "contrib/mcclim"
-         "contrib/numericalio"
-         "contrib/pdiff"
-         "contrib/prim"
-         "contrib/rand"
-         "contrib/sarag"
-         "contrib/simplex"
-         "contrib/simplex/Tests"
-         "contrib/solve_rec"
-         "contrib/state"
-         "contrib/stringproc"
-         "contrib/unit"
-         "contrib/Zeilberger"
-         "diffequations"
-         "lbfgs"
-         "linearalgebra"
-         "integequations"
-         "integration"
-         "macro"
-         "matrix"
-         "misc"
-         "numeric"
-         "orthopoly"
-         "physics"
-         "simplification"
-         "sym"
-         "tensor"
-         "tensor/tests"
-         "trigonometry"
-         "utils"
-         "vector"))
+	 "algebra"
+	 "algebra/charsets"
+	 "algebra/solver"
+	 "calculus"
+	 "combinatorics"
+	 "contrib"
+	 "contrib/boolsimp"
+	 "contrib/descriptive"
+	 "contrib/diffequations"
+	 "contrib/diffequations/tests"
+	 "contrib/distrib"
+	 "contrib/ezunits"
+	 "contrib/format"
+	 "contrib/fractals"
+	 "contrib/gentran"
+	 "contrib/gentran/test"
+	 "contrib/Grobner"
+     "contrib/levin"
+	 "contrib/lurkmathml"
+	 "contrib/maximaMathML"
+	 "contrib/mcclim"
+	 "contrib/numericalio"
+	 "contrib/pdiff"
+	 "contrib/prim"
+	 "contrib/rand"
+	 "contrib/sarag"
+	 "contrib/simplex"
+	 "contrib/simplex/Tests"
+	 "contrib/solve_rec"
+	 "contrib/state"
+	 "contrib/stats"
+	 "contrib/stringproc"
+	 "contrib/unit"
+	 "contrib/Zeilberger"
+	 "diff_form"
+	 "diffequations"
+	 "dynamics"
+	 "draw"
+	 "lapack"
+	 "lbfgs"
+	 "linearalgebra"
+	 "integequations"
+	 "integration"
+	 "macro"
+	 "matrix"
+	 "misc"
+	 "numeric"
+	 "orthopoly"
+	 "physics"
+	 "simplification"
+	 "sym"
+	 "tensor"
+	 "tensor/tests"
+	 "trigonometry"
+	 "utils"
+	 "vector"))
      ; Smash the list of share subdirs into a string of the form "{affine,algebra,...,vector}" .
 	 (share-subdirs (format nil "{~{~A~^,~}}" share-subdirs-list)))
 
@@ -367,23 +361,23 @@
 		;; lisp code. jfa 04/11/02
 		(combine-path (list *maxima-userdir* lisp-patterns))
 		(combine-path (list *maxima-sharedir* lisp-patterns))
-		(combine-path (list *maxima-sharedir* share-subdirs 
+		(combine-path (list *maxima-sharedir* share-subdirs
 				    lisp-patterns))
 		(combine-path (list *maxima-srcdir* lisp-patterns))))
     (setq $file_search_maxima
 	  (list '(mlist)
 		(combine-path (list *maxima-userdir* maxima-patterns))
 		(combine-path (list *maxima-sharedir* maxima-patterns))
-		(combine-path (list *maxima-sharedir* share-subdirs 
+		(combine-path (list *maxima-sharedir* share-subdirs
 				    maxima-patterns))))
     (setq $file_search_demo
 	  (list '(mlist)
 		(combine-path (list *maxima-sharedir* demo-patterns))
-		(combine-path (list *maxima-sharedir* share-subdirs 
+		(combine-path (list *maxima-sharedir* share-subdirs
 				    demo-patterns))
 		(combine-path (list *maxima-demodir* demo-patterns))))
     (setq $file_search_usage
-	  (list '(mlist) 
+	  (list '(mlist)
 		(combine-path (list *maxima-sharedir* usage-patterns))
 		(combine-path (list *maxima-sharedir* share-subdirs
 				    usage-patterns))
@@ -394,19 +388,19 @@
 	  (list '(mlist)
 		(combine-path (list *maxima-symdir* lisp-patterns))
 		(combine-path (list *maxima-symdir* maxima-patterns))))
-    (setq cl-info::*info-paths* (list (concatenate 'string *maxima-infodir* "/")))
-    ;; Share subdirs are not required here since all .info files are installed
-    ;; in one directory *maxima-infodir* -- there is no info files in share.
-    ;; vvzhy Jan 2, 2006
-    ;(setq L (mapcar #'(lambda (x) (concatenate 'string *maxima-sharedir* "/" x "/")) share-subdirs-list))
-    ;(setq cl-info::*info-paths* (append cl-info::*info-paths* L))
-
-    ; Look for "foo.info" in share directory "foo".
-    (loop for d in share-subdirs-list do
-      (let ((name (if (find #\/ d) (unix-like-basename d) d)))
-        (when (cl-info::file-search name cl-info::*info-paths* '("info") nil)
-          #+debug (format t "SET-PATHNAMES: found an info file for share directory ~S~%" name)
-          (nconc cl-info::*default-info-files* `(,(concatenate 'string name ".info"))))))))
+    ;; If *maxima-lang-subdir* is not nil test whether corresponding info directory
+    ;; with some data really exists.  If not this probably means that required
+    ;; language pack wasn't installed and we reset *maxima-lang-subdir* to nil.
+    (when (and *maxima-lang-subdir*
+	       (not (probe-file (concatenate 'string *maxima-infodir*
+						     "/" *maxima-lang-subdir*
+						     "/maxima-index.lisp"))))
+       (setq *maxima-lang-subdir* nil))
+    ;; Autoload for Maxima documantation index file
+    (let
+      ((subdir-bit (if (null *maxima-lang-subdir*) "" (concatenate 'string "/" *maxima-lang-subdir*))))
+      (autof 'cl-info::cause-maxima-index-to-load
+	     (concatenate 'string *maxima-infodir* subdir-bit "/maxima-index.lisp")))))
 
 (defun get-dirs (path)
   #+(or :clisp :sbcl)
@@ -420,7 +414,8 @@
     (if (equal (subseq pathstring (- len 1) len) "/")
 	(progn (setf len (- len 1))
 	       (setf pathstring (subseq pathstring 0 len))))
-    (subseq pathstring (+ (or (position #\/ pathstring :from-end t) (position #\\ pathstring :from-end t)) 1) len)))
+    (subseq pathstring (1+ (or (position #\/ pathstring :from-end t)
+			      (position #\\ pathstring :from-end t))) len)))
 
 (defun unix-like-dirname (path)
   (let* ((pathstring (namestring path))
@@ -428,22 +423,22 @@
     (if (equal (subseq pathstring (- len 1) len) "/")
 	(progn (setf len (- len 1))
 	       (setf pathstring (subseq pathstring 0 len))))
-    (subseq pathstring 0 (or (position #\/ pathstring :from-end t) (position #\\ pathstring :from-end t)))))
+    (subseq pathstring 0 (or (position #\/ pathstring :from-end t)
+			     (position #\\ pathstring :from-end t)))))
 
 (defun list-avail-action ()
   (let* ((maxima-verpkglibdir (if (maxima-getenv "MAXIMA-VERPKGLIBDIR")
 				  (maxima-getenv "MAXIMA-VERPKGLIBDIR")
 				  (if (maxima-getenv "MAXIMA_PREFIX")
-				      (concatenate 
+				      (concatenate
 				       'string (maxima-getenv "MAXIMA_PREFIX")
 				       "/lib/" *autoconf-package* "/"
 				       *autoconf-version*)
-				      (concatenate 
-				       'string (maxima-parse-dirstring 
-						*autoconf-libdir*) 
-				       "/"
-				       *autoconf-package* "/"
-				       *autoconf-version*))))
+				      (concatenate 'string
+						   (maxima-parse-dirstring *autoconf-libdir*)
+						   "/"
+						   *autoconf-package* "/"
+						   *autoconf-version*))))
 	 (len (length maxima-verpkglibdir))
 	 (base-dir nil)
 	 (versions nil)
@@ -452,7 +447,7 @@
 	 (lisp-string nil))
     (format t "Available versions:~%")
     (if (not (equal (subseq maxima-verpkglibdir (- len 1) len) "/"))
-	(setf maxima-verpkglibdir (concatenate 
+	(setf maxima-verpkglibdir (concatenate
 				   'string maxima-verpkglibdir "/")))
     (setf base-dir (unix-like-dirname maxima-verpkglibdir))
     (setf versions (get-dirs base-dir))
@@ -462,7 +457,7 @@
       (dolist (lisp lisps)
 	(setf lisp-string (unix-like-basename lisp))
 	(when (search "binary-" lisp-string)
-	  (setf lisp-string (subseq lisp-string (length "binary-") 
+	  (setf lisp-string (subseq lisp-string (length "binary-")
 				    (length lisp-string)))
 	  (format t "version ~a, lisp ~a~%" version-string lisp-string))))
     (bye)))
@@ -473,31 +468,13 @@
   ;;    (terpri)
   (let ((maxima-options nil))
     (setf maxima-options
-	  (list 
-	   (make-cl-option :names '("-h" "--help")
-			   :action #'(lambda () 
-				       (format t "usage: maxima [options]~%")
-				       (list-cl-options maxima-options)
-				       (bye))
-			   :help-string "Display this usage message.")
-	   (make-cl-option :names '("-l" "--lisp")
-			   :argument "<lisp>"
-			   :action nil
-			   :help-string "Use lisp implementation <lisp>.")
-	   (make-cl-option :names '("-u" "--use-version")
-			   :argument "<version>"
-			   :action nil
-			   :help-string "Use maxima version <version>.")
-	   (make-cl-option :names '("--list-avail")
-			   :action 'list-avail-action
-			   :help-string 
-			   "List the installed version/lisp combinations.")
+	  (list
 	   (make-cl-option :names '("-b" "--batch")
 			   :argument "<file>"
 			   :action #'(lambda (file)
 				       (setf input-stream
 					     (make-string-input-stream
-					      (format nil "batch(\"~a\");" 
+					      (format nil "batch(\"~a\");"
 						      file)))
 				       (setf batch-flag :batch))
 			   :help-string
@@ -507,67 +484,89 @@
 			   :action #'(lambda (file)
 				       (setf input-stream
 					     (make-string-input-stream
-					      (format nil
-						      ":lisp (load \"~a\");"
-						      file)))
+					      #-sbcl (format nil ":lisp (load \"~a\");" file)
+					      #+sbcl (format nil ":lisp (with-compilation-unit nil (load \"~a\"));" file)))
 				       (setf batch-flag :batch))
-			   :help-string 
+			   :help-string
 			   "Process lisp file <file> in batch mode.")
 	   (make-cl-option :names '("--batch-string")
 			   :argument "<string>"
 			   :action #'(lambda (string)
-				       (setf input-stream 
+				       (setf input-stream
 					     (make-string-input-stream string))
 				       (setf batch-flag :batch))
-			   :help-string 
+			   :help-string
 			   "Process maxima command(s) <string> in batch mode.")
+	   (make-cl-option :names '("-d" "--directories")
+			   :action 'print-directories
+			   :help-string
+			   "Display maxima internal directory information.")
+	   (make-cl-option :names '("--disable-readline")
+			   :action #'(lambda ()
+				       #+gcl
+				       (if (find :readline *features*)
+					   (si::readline-off)))
+			   :help-string "Disable readline support.")
+	   (make-cl-option :names '("-g" "--enable-lisp-debugger")
+			   :action #'(lambda ()
+				       (setf *debugger-hook* nil))
+			   :help-string
+			   "Enable underlying lisp debugger.")
+	   (make-cl-option :names '("-h" "--help")
+			   :action #'(lambda ()
+				       (format t "usage: maxima [options]~%")
+				       (list-cl-options maxima-options)
+				       (bye))
+			   :help-string "Display this usage message.")
+	   (make-cl-option :names '("-l" "--lisp")
+			   :argument "<lisp>"
+			   :action nil
+			   :help-string "Use lisp implementation <lisp>.")
+	   (make-cl-option :names '("--list-avail")
+			   :action 'list-avail-action
+			   :help-string
+			   "List the installed version/lisp combinations.")
+	   (make-cl-option :names '("-p" "--preload-lisp")
+			   :argument "<lisp-file>"
+			   :action #'(lambda (file)
+				       #-sbcl (load file) #+sbcl (with-compilation-unit nil (load file)))
+			   :help-string "Preload <lisp-file>.")
+       (make-cl-option :names '("-q" "--quiet")
+	       :action #'(lambda () (declare (special *maxima-quiet*)) (setq *maxima-quiet* t))
+	       :help-string "Suppress Maxima start-up message.")
 	   (make-cl-option :names '("-r" "--run-string")
 			   :argument "<string>"
 			   :action #'(lambda (string)
 				       (setf input-stream
 					     (make-string-input-stream string))
 				       (setf batch-flag nil))
-			   :help-string 
+			   :help-string
 			   "Process maxima command(s) <string> in interactive mode.")
-	   (make-cl-option :names '("-p" "--preload-lisp")
-			   :argument "<lisp-file>"
-			   :action #'(lambda (file)
-				       (load file))
-			   :help-string "Preload <lisp-file>.")
-       (make-cl-option :names '("-q" "--quiet")
-               :action #'(lambda () (declare (special *maxima-quiet*)) (setq *maxima-quiet* t))
-               :help-string "Suppress Maxima start-up message.")
-	   (make-cl-option :names '("--disable-readline")
-			   :action #'(lambda ()
-				       #+gcl
-				       (si::readline-off))
-			   :help-string "Disable readline support.")
 	   (make-cl-option :names '("-s" "--server")
 			   :argument "<port>"
 			   :action #'(lambda (port-string)
-				       (start-server (parse-integer 
+				       (start-server (parse-integer
 						      port-string)))
 			   :help-string "Start maxima server on <port>.")
-	   (make-cl-option :names '("-d" "--directories")
-			   :action 'print-directories
-			   :help-string
-			   "Display maxima internal directory information.")
-	   (make-cl-option :names '("-g" "--enable-lisp-debugger")
-			   :action #'(lambda ()
-				       (setf *debugger-hook* nil))
-			   :help-string
-			   "Enable underlying lisp debugger.")
+	   (make-cl-option :names '("-u" "--use-version")
+			   :argument "<version>"
+			   :action nil
+			   :help-string "Use maxima version <version>.")
 	   (make-cl-option :names '("-v" "--verbose")
 			   :action nil
-			   :help-string 
+			   :help-string
 			   "Display lisp invocation in maxima wrapper script.")
 	   (make-cl-option :names '("--version")
 			   :action #'(lambda ()
-				       (format t "Maxima ~a~%" 
+				       (format t "Maxima ~a~%"
 					       *autoconf-version*)
 				       ($quit))
-			   :help-string 
-			   "Display the default installed version.")))
+			   :help-string
+			   "Display the default installed version.")
+       (make-cl-option :names '("--very-quiet")
+	       :action #'(lambda () (declare (special *maxima-quiet* *display-labels-p*))
+			   (setq *maxima-quiet* t *display-labels-p* nil))
+	       :help-string "Suppress expression labels and Maxima start-up message.")))
     (process-args (get-application-args) maxima-options))
   (values input-stream batch-flag))
 
@@ -582,14 +581,15 @@
     (progn
       (set-readtable-for-macsyma)
       (setf *read-default-float-format* 'lisp::double-float))
-    
+
     (catch 'to-lisp
-      (set-pathnames)
+      (initialize-real-and-run-time)
       (set-locale)
-      (setf (values input-stream batch-flag) 
+      (set-pathnames)
+      (setf (values input-stream batch-flag)
 	    (process-maxima-args input-stream batch-flag))
       (progn
-	(loop 
+	(loop
 	 (with-simple-restart (macsyma-quit "Maxima top-level")
 	     (macsyma-top-level input-stream batch-flag)))))))
 
@@ -602,8 +602,7 @@
       (unwind-protect
 	   (maxima-read-eval-print-loop)
 	(setf *debugger-hook* old-debugger-hook)
-	(format t "Returning to Maxima~%"))))
-  )
+	(format t "Returning to Maxima~%")))))
 
 (defun to-maxima ()
   (throw 'to-maxima t))
@@ -612,7 +611,7 @@
   (setf *debugger-hook* #'maxima-lisp-debugger-repl)
   (loop
    (catch 'to-maxima-repl
-     (format t "~a~%~a> ~a" *prompt-prefix* 
+     (format t "~a~%~a> ~a" *prompt-prefix*
 	     (package-name *package*) *prompt-suffix*)
      (finish-output)
      (let ((form (read)))
@@ -626,8 +625,8 @@
 
 (defvar $help "type `describe(topic);' or `example(topic);' or `? topic'")
 
-(defun $help (&rest args)
-  (declare (ignore args))
+(defun $help (&rest dummy)
+  (declare (ignore dummy))
   $help)
 
 ;;; Now that all of maxima has been loaded, define the various lists
@@ -640,9 +639,9 @@
 (let ((problematic-symbols '($%gamma $%phi $global $%pi $%e)))
   (do-symbols (s (find-package :maxima))
     (when (and (eql (symbol-package s) (find-package :maxima))
-	       (memq (getchar s 1) '($ % &)))
+	       (member (getchar s 1) '($ % &) :test #'eq))
       (push s *builtin-symbols*)
-      (when (not (memq s problematic-symbols))
+      (when (not (member s problematic-symbols :test #'eq))
 	(setf (gethash s *builtin-symbol-props*)
 	      (copy-tree (symbol-plist s)))))))
 
