@@ -70,7 +70,7 @@
   $dotconstrules $dotdistrib $dotexptsimp $dotident $dotscrules
   $dskgc $erfflag $errexp $error $error_size $error_syms $expon
   $exponentialize $expop $exptdispflag $exptisolate $exptsubst
-  $facexpand $factorflag $features $file_search $file_string_print
+  $facexpand $factorflag $features $file_search
   $file_types $float $float2bf $floatformat $floatfrac $floatint
   $floatoptions $floatprec $floatwidth $fortfloat $fortindent
   $fortspaces $fpprec $fpprintprec $fptrunc $functions $gammalim $gcd
@@ -91,8 +91,7 @@
   $poislim $powerdisp $prederror $programmode $props
   $radexpand $ratalgdenom $ratdenomdivide $ratepsilon $ratexpand
   $ratfac $ratmx $ratprint $ratsimpexpons $ratvars $ratweights
-  $ratwtlvl $realonly $refcheck $resultant $rmxchar $rombergabs
-  $rombergit $rombergit_used $rombergmin $rombergtol $rootsconmode
+  $ratwtlvl $realonly $refcheck $resultant $rmxchar $rootsconmode
   $rules $savedef $savefactors $scalarmatrixp $setcheck
   $setcheckbreak $setval $showtime $signbfloat $simp $simpsum
   $solvedecomposes $solveexplicit $solvefactors $solvenullwarn
@@ -120,7 +119,7 @@
   *transl-debug* *transl-file-debug* *warned-fexprs*
   *warned-mode-vars* *warned-un-declared-vars* *zexptsimp? |-1//2|
   -sqrt2//2 -sqrt3//2 |1//2| adn* aexprp algfac* algnotexact
-  aliaslist alpha alphabet arrays aryp assigns atp atvars baktrcl
+  aliaslist alpha *alphabet* arrays aryp assigns atp atvars baktrcl
   bfhalf bfmhalf bigfloat%e bigfloat%pi bigfloatone bigfloatzero
   bigprimes bindlist bvars *mdebug*
   declares defined_variables defintdebug derivflag derivlist
@@ -139,7 +138,7 @@
   plusflag preserve-direction prods putl radcanp radpe rd*
   real-infinities realonlyratnum refchkl return-mode returns rulefcnl
   rulesw scanmapp sfindex sign-imag-errp simplimplus-problems
-  smallprimes specials sqrt2//2 sqrt3//2 state-pdl stringdisp substp
+  smallprimes specials sqrt2//2 sqrt3//2 state-pdl $stringdisp substp
   sums tellratlist timesinp timesp tr-abort tr-progret tr-unique
   tramp1$ tramp2$ tramp3$ transl-file translate-time-evalables transp
   tstack typel user-mesfile user-timesofar varlist wflag ^dmsg-off
