@@ -130,27 +130,14 @@
 ;; versions of maxima have a builtin info retrieval mechanism.
 
 (defmspec $describe (x)
-  (setq x ($sconcat (cadr x)))
-  (let ((cl-info::*prompt-prefix* *prompt-prefix*)
-	(cl-info::*prompt-suffix* *prompt-suffix*)
-	(cl-info::*lang-subdir* *maxima-lang-subdir*))
-    #-gcl
-    (cl-info:info x)
-    ;; Optimization: GCL's built-in info is much faster than our info
-    ;; implementation. However, GCL's info won't respect out *prompt-
-    ;; variables. Compromise by only calling our info when the prompts
-    ;; are not empty. --jfa 07/25/04
-    ;; We have to use Maxima info for GCL, at least temorarily, since 
-    ;; GCL's info is not quite compatible (GCL 2.6.6) with recent
-    ;; texinfo releases. -- ZW 01-Apr-05
-    #+gcl
-    (cl-info:info x)
-    #+nil
-    (if (and (string= *prompt-prefix* "") (string= *prompt-suffix* ""))
-	(progn
-	  (setf system::*info-paths* cl-info:*info-paths*)
-	  (system::info x '("maxima.info")))
-	(cl-info:info x))))
+  (let
+    ((topic ($sconcat (cadr x)))
+     (exact-p (or (null (caddr x)) (eq (caddr x) '$exact)))
+     (cl-info::*prompt-prefix* *prompt-prefix*)
+     (cl-info::*prompt-suffix* *prompt-suffix*))
+    (if exact-p
+      (cl-info::info-exact topic)
+      (cl-info::info topic))))
 
 (defun $apropos ( s ) 
   (cons '(mlist) (apropos-list s :maxima)))
