@@ -1,5 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
-;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:18:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-12 (19D)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
@@ -34,14 +34,13 @@
       (first$ nil))
   (declare (type f2cl-lib:logical first$)
            (type (simple-array double-float (19)) bj0cs)
-           (type double-float xsml)
-           (type f2cl-lib:integer4 ntj0))
+           (type (double-float) xsml)
+           (type (integer) ntj0))
   (setq first$ f2cl-lib:%true%)
   (defun dbesj0 (x)
-    (declare (type double-float x))
-    (prog ((ampl 0.0) (theta 0.0) (y 0.0) (dbesj0 0.0) (abs$ 0.0f0))
-      (declare (type single-float abs$)
-               (type double-float dbesj0 y theta ampl))
+    (declare (type (double-float) x))
+    (prog ((ampl 0.0) (theta 0.0) (y 0.0) (dbesj0 0.0))
+      (declare (type (double-float) dbesj0 y theta ampl))
       (cond
         (first$
          (setf ntj0
@@ -49,7 +48,7 @@
                   (* 0.1f0 (f2cl-lib:freal (f2cl-lib:d1mach 3)))))
          (setf xsml (f2cl-lib:fsqrt (* 8.0 (f2cl-lib:d1mach 3))))))
       (setf first$ f2cl-lib:%false%)
-      (setf y (coerce (abs x) 'double-float))
+      (setf y (abs x))
       (if (> y 4.0) (go label20))
       (setf dbesj0 1.0)
       (if (> y xsml) (setf dbesj0 (dcsevl (- (* 0.125 y y) 1.0) bj0cs ntj0)))
@@ -65,3 +64,15 @@
      end_label
       (return (values dbesj0 nil)))))
 
+(in-package #-gcl #:cl-user #+gcl "CL-USER")
+#+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
+(eval-when (:load-toplevel :compile-toplevel :execute)
+  (setf (gethash 'fortran-to-lisp::dbesj0
+                 fortran-to-lisp::*f2cl-function-info*)
+          (fortran-to-lisp::make-f2cl-finfo :arg-types '((double-float))
+                                            :return-values '(nil)
+                                            :calls '(fortran-to-lisp::d9b0mp
+                                                     fortran-to-lisp::dcsevl
+                                                     fortran-to-lisp::initds
+                                                     fortran-to-lisp::d1mach))))
+
