@@ -1,5 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
-;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:18:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-12 (19D)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
@@ -32,13 +32,13 @@
       (first$ nil))
   (declare (type f2cl-lib:logical first$)
            (type (simple-array double-float (16)) bk0cs)
-           (type double-float xmax xsml)
-           (type f2cl-lib:integer4 ntk0))
+           (type (double-float) xmax xsml)
+           (type (integer) ntk0))
   (setq first$ f2cl-lib:%true%)
   (defun dbesk0 (x)
-    (declare (type double-float x))
+    (declare (type (double-float) x))
     (prog ((xmaxt 0.0) (y 0.0) (dbesk0 0.0))
-      (declare (type double-float dbesk0 y xmaxt))
+      (declare (type (double-float) dbesk0 y xmaxt))
       (cond
         (first$
          (setf ntk0
@@ -67,3 +67,17 @@
      end_label
       (return (values dbesk0 nil)))))
 
+(in-package #-gcl #:cl-user #+gcl "CL-USER")
+#+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
+(eval-when (:load-toplevel :compile-toplevel :execute)
+  (setf (gethash 'fortran-to-lisp::dbesk0
+                 fortran-to-lisp::*f2cl-function-info*)
+          (fortran-to-lisp::make-f2cl-finfo :arg-types '((double-float))
+                                            :return-values '(nil)
+                                            :calls '(fortran-to-lisp::dbsk0e
+                                                     fortran-to-lisp::dcsevl
+                                                     fortran-to-lisp::dbesi0
+                                                     fortran-to-lisp::xermsg
+                                                     fortran-to-lisp::initds
+                                                     fortran-to-lisp::d1mach))))
+
