@@ -1,5 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
-;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:18:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-12 (19D)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
@@ -38,13 +38,13 @@
       (first$ nil))
   (declare (type f2cl-lib:logical first$)
            (type (simple-array double-float (20)) by1cs)
-           (type double-float twodpi xsml xmin)
-           (type f2cl-lib:integer4 nty1))
+           (type (double-float) twodpi xsml xmin)
+           (type (integer) nty1))
   (setq first$ f2cl-lib:%true%)
   (defun dbesy1 (x)
-    (declare (type double-float x))
+    (declare (type (double-float) x))
     (prog ((ampl 0.0) (theta 0.0) (y 0.0) (dbesy1 0.0))
-      (declare (type double-float dbesy1 y theta ampl))
+      (declare (type (double-float) dbesy1 y theta ampl))
       (cond
         (first$
          (setf nty1
@@ -79,3 +79,17 @@
      end_label
       (return (values dbesy1 nil)))))
 
+(in-package #-gcl #:cl-user #+gcl "CL-USER")
+#+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
+(eval-when (:load-toplevel :compile-toplevel :execute)
+  (setf (gethash 'fortran-to-lisp::dbesy1
+                 fortran-to-lisp::*f2cl-function-info*)
+          (fortran-to-lisp::make-f2cl-finfo :arg-types '((double-float))
+                                            :return-values '(nil)
+                                            :calls '(fortran-to-lisp::d9b1mp
+                                                     fortran-to-lisp::dcsevl
+                                                     fortran-to-lisp::dbesj1
+                                                     fortran-to-lisp::xermsg
+                                                     fortran-to-lisp::initds
+                                                     fortran-to-lisp::d1mach))))
+
