@@ -1,5 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
-;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:18:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-12 (19D)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
@@ -159,13 +159,13 @@
            (type (simple-array double-float (69)) ai12cs)
            (type (simple-array double-float (46)) ai1cs)
            (type (simple-array double-float (17)) bi1cs)
-           (type double-float xsml xmin)
-           (type f2cl-lib:integer4 ntai12 ntai1 nti1))
+           (type (double-float) xsml xmin)
+           (type (integer) ntai12 ntai1 nti1))
   (setq first$ f2cl-lib:%true%)
   (defun dbsi1e (x)
-    (declare (type double-float x))
-    (prog ((y 0.0) (dbsi1e 0.0) (sqrt$ 0.0f0) (abs$ 0.0f0) (eta 0.0f0))
-      (declare (type single-float eta abs$ sqrt$) (type double-float dbsi1e y))
+    (declare (type (double-float) x))
+    (prog ((y 0.0) (dbsi1e 0.0) (sqrt$ 0.0f0) (eta 0.0f0))
+      (declare (type (single-float) eta sqrt$) (type (double-float) dbsi1e y))
       (cond
         (first$
          (setf eta (* 0.1f0 (f2cl-lib:freal (f2cl-lib:d1mach 3))))
@@ -175,7 +175,7 @@
          (setf xmin (* 2.0 (f2cl-lib:d1mach 1)))
          (setf xsml (f2cl-lib:fsqrt (* 4.5 (f2cl-lib:d1mach 3))))))
       (setf first$ f2cl-lib:%false%)
-      (setf y (coerce (abs x) 'double-float))
+      (setf y (abs x))
       (if (> y 3.0) (go label20))
       (setf dbsi1e 0.0)
       (if (= y 0.0) (go end_label))
@@ -201,3 +201,15 @@
      end_label
       (return (values dbsi1e nil)))))
 
+(in-package #-gcl #:cl-user #+gcl "CL-USER")
+#+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
+(eval-when (:load-toplevel :compile-toplevel :execute)
+  (setf (gethash 'fortran-to-lisp::dbsi1e
+                 fortran-to-lisp::*f2cl-function-info*)
+          (fortran-to-lisp::make-f2cl-finfo :arg-types '((double-float))
+                                            :return-values '(nil)
+                                            :calls '(fortran-to-lisp::dcsevl
+                                                     fortran-to-lisp::xermsg
+                                                     fortran-to-lisp::initds
+                                                     fortran-to-lisp::d1mach))))
+
