@@ -1,5 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
-;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:18:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-12 (19D)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
@@ -14,14 +14,14 @@
         lenw iwork work)
   (declare (type (array double-float (*)) work)
            (type (array f2cl-lib:integer4 (*)) iwork)
-           (type f2cl-lib:integer4 lenw maxp1 leniw lst limlst ier neval
-                                   integr)
-           (type double-float abserr result epsabs omega a))
+           (type (f2cl-lib:integer4) lenw maxp1 leniw lst limlst ier neval
+                                     integr)
+           (type (double-float) abserr result epsabs omega a))
   (f2cl-lib:with-multi-array-data
       ((iwork f2cl-lib:integer4 iwork-%data% iwork-%offset%)
        (work double-float work-%data% work-%offset%))
     (prog ((limit 0) (ll2 0) (lvl 0) (l1 0) (l2 0) (l3 0) (l4 0) (l5 0) (l6 0))
-      (declare (type f2cl-lib:integer4 l6 l5 l4 l3 l2 l1 lvl ll2 limit))
+      (declare (type (f2cl-lib:integer4) l6 l5 l4 l3 l2 l1 lvl ll2 limit))
       (setf ier 6)
       (setf neval 0)
       (setf result 0.0)
@@ -90,3 +90,23 @@
                nil
                nil)))))
 
+(in-package #-gcl #:cl-user #+gcl "CL-USER")
+#+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
+(eval-when (:load-toplevel :compile-toplevel :execute)
+  (setf (gethash 'fortran-to-lisp::dqawf fortran-to-lisp::*f2cl-function-info*)
+          (fortran-to-lisp::make-f2cl-finfo
+           :arg-types '(t (double-float) (double-float)
+                        (fortran-to-lisp::integer4) (double-float)
+                        (double-float) (double-float)
+                        (fortran-to-lisp::integer4) (fortran-to-lisp::integer4)
+                        (fortran-to-lisp::integer4) (fortran-to-lisp::integer4)
+                        (fortran-to-lisp::integer4) (fortran-to-lisp::integer4)
+                        (fortran-to-lisp::integer4)
+                        (array fortran-to-lisp::integer4 (*))
+                        (array double-float (*)))
+           :return-values '(nil nil nil fortran-to-lisp::integr nil
+                            fortran-to-lisp::result fortran-to-lisp::abserr
+                            fortran-to-lisp::neval fortran-to-lisp::ier nil
+                            fortran-to-lisp::lst nil nil nil nil nil)
+           :calls '(fortran-to-lisp::xermsg fortran-to-lisp::dqawfe))))
+
