@@ -1,5 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
-;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:18:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-12 (19D)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
@@ -14,9 +14,9 @@
         ier last$ alist blist rlist elist iord nnlog momcom chebmo)
   (declare (type (array f2cl-lib:integer4 (*)) nnlog iord)
            (type (array double-float (*)) chebmo elist rlist blist alist)
-           (type f2cl-lib:integer4 momcom last$ ier neval maxp1 icall limit
-                                   integr)
-           (type double-float abserr result epsrel epsabs omega b a))
+           (type (f2cl-lib:integer4) momcom last$ ier neval maxp1 icall limit
+                                     integr)
+           (type (double-float) abserr result epsrel epsabs omega b a))
   (f2cl-lib:with-multi-array-data
       ((alist double-float alist-%data% alist-%offset%)
        (blist double-float blist-%data% blist-%offset%)
@@ -35,18 +35,17 @@
            (domega 0.0) (dres 0.0) (epmach 0.0) (erlarg 0.0) (erlast 0.0)
            (errbnd 0.0) (errmax 0.0) (error1 0.0) (erro12 0.0) (error2 0.0)
            (errsum 0.0) (ertest 0.0) (oflow 0.0) (resabs 0.0) (reseps 0.0)
-           (small 0.0) (uflow 0.0) (width 0.0) (abs$ 0.0f0))
-      (declare (type single-float abs$)
-               (type (array double-float (52)) rlist2)
+           (small 0.0) (uflow 0.0) (width 0.0))
+      (declare (type (array double-float (52)) rlist2)
                (type (array double-float (3)) res3la)
-               (type double-float width uflow small reseps resabs oflow ertest
-                                  errsum error2 erro12 error1 errmax errbnd
-                                  erlast erlarg epmach dres domega defabs
-                                  defab2 defab1 correc b2 b1 a2 a1 area2 area12
-                                  area1 area abseps)
-               (type f2cl-lib:integer4 numrl2 nrmom nrmax nres nev maxerr ktmin
-                                       ksgn k jupbnd iroff3 iroff2 iroff1 ierro
-                                       id)
+               (type (double-float) width uflow small reseps resabs oflow
+                                    ertest errsum error2 erro12 error1 errmax
+                                    errbnd erlast erlarg epmach dres domega
+                                    defabs defab2 defab1 correc b2 b1 a2 a1
+                                    area2 area12 area1 area abseps)
+               (type (f2cl-lib:integer4) numrl2 nrmom nrmax nres nev maxerr
+                                         ktmin ksgn k jupbnd iroff3 iroff2
+                                         iroff1 ierro id)
                (type f2cl-lib:logical extall noext extrap))
       (setf epmach (f2cl-lib:d1mach 4))
       (setf ier 0)
@@ -54,22 +53,20 @@
       (setf last$ 0)
       (setf result 0.0)
       (setf abserr 0.0)
-      (f2cl-lib:fset (f2cl-lib:fref alist-%data% (1) ((1 *)) alist-%offset%) a)
-      (f2cl-lib:fset (f2cl-lib:fref blist-%data% (1) ((1 *)) blist-%offset%) b)
-      (f2cl-lib:fset (f2cl-lib:fref rlist-%data% (1) ((1 *)) rlist-%offset%)
-                     0.0)
-      (f2cl-lib:fset (f2cl-lib:fref elist-%data% (1) ((1 *)) elist-%offset%)
-                     0.0)
-      (f2cl-lib:fset (f2cl-lib:fref iord-%data% (1) ((1 *)) iord-%offset%) 0)
-      (f2cl-lib:fset (f2cl-lib:fref nnlog-%data% (1) ((1 *)) nnlog-%offset%) 0)
+      (setf (f2cl-lib:fref alist-%data% (1) ((1 *)) alist-%offset%) a)
+      (setf (f2cl-lib:fref blist-%data% (1) ((1 *)) blist-%offset%) b)
+      (setf (f2cl-lib:fref rlist-%data% (1) ((1 *)) rlist-%offset%) 0.0)
+      (setf (f2cl-lib:fref elist-%data% (1) ((1 *)) elist-%offset%) 0.0)
+      (setf (f2cl-lib:fref iord-%data% (1) ((1 *)) iord-%offset%) 0)
+      (setf (f2cl-lib:fref nnlog-%data% (1) ((1 *)) nnlog-%offset%) 0)
       (if
        (or (and (/= integr 1) (/= integr 2))
-           (and (<= epsabs 0.0) (< epsrel (max (* 50.0 epmach) 5.e-29)))
+           (and (<= epsabs 0.0) (< epsrel (max (* 50.0 epmach) 5.0e-29)))
            (< icall 1)
            (< maxp1 1))
        (setf ier 6))
       (if (= ier 6) (go label999))
-      (setf domega (coerce (abs omega) 'double-float))
+      (setf domega (abs omega))
       (setf nrmom 0)
       (if (> icall 1) (go label5))
       (setf momcom 0)
@@ -88,13 +85,11 @@
         (setf defabs var-11)
         (setf resabs var-12)
         (setf momcom var-13))
-      (setf dres (coerce (abs result) 'double-float))
+      (setf dres (abs result))
       (setf errbnd (max epsabs (* epsrel dres)))
-      (f2cl-lib:fset (f2cl-lib:fref rlist-%data% (1) ((1 *)) rlist-%offset%)
-                     result)
-      (f2cl-lib:fset (f2cl-lib:fref elist-%data% (1) ((1 *)) elist-%offset%)
-                     abserr)
-      (f2cl-lib:fset (f2cl-lib:fref iord-%data% (1) ((1 *)) iord-%offset%) 1)
+      (setf (f2cl-lib:fref rlist-%data% (1) ((1 *)) rlist-%offset%) result)
+      (setf (f2cl-lib:fref elist-%data% (1) ((1 *)) elist-%offset%) abserr)
+      (setf (f2cl-lib:fref iord-%data% (1) ((1 *)) iord-%offset%) 1)
       (if (and (<= abserr (* 100.0 epmach defabs)) (> abserr errbnd))
           (setf ier 2))
       (if (= limit 1) (setf ier 1))
@@ -121,7 +116,7 @@
       (if (> (* 0.5 (abs (- b a)) domega) 2.0) (go label10))
       (setf numrl2 1)
       (setf extall f2cl-lib:%true%)
-      (f2cl-lib:fset (f2cl-lib:fref rlist2 (1) ((1 52))) result)
+      (setf (f2cl-lib:fref rlist2 (1) ((1 52))) result)
      label10
       (if (<= (* 0.25 (abs (- b a)) domega) 2.0) (setf extall f2cl-lib:%true%))
       (setf ksgn -1)
@@ -196,7 +191,7 @@
              (abs
               (- (f2cl-lib:fref rlist-%data% (maxerr) ((1 *)) rlist-%offset%)
                  area12))
-             (* 1.e-5 (abs area12)))
+             (* 1.0e-5 (abs area12)))
             (< erro12 (* 0.99 errmax)))
            (go label20))
           (if extrap (setf iroff2 (f2cl-lib:int-add iroff2 1)))
@@ -205,18 +200,14 @@
           (if (and (> last$ 10) (> erro12 errmax))
               (setf iroff3 (f2cl-lib:int-add iroff3 1)))
          label25
-          (f2cl-lib:fset
-           (f2cl-lib:fref rlist-%data% (maxerr) ((1 *)) rlist-%offset%)
-           area1)
-          (f2cl-lib:fset
-           (f2cl-lib:fref rlist-%data% (last$) ((1 *)) rlist-%offset%)
-           area2)
-          (f2cl-lib:fset
-           (f2cl-lib:fref nnlog-%data% (maxerr) ((1 *)) nnlog-%offset%)
-           nrmom)
-          (f2cl-lib:fset
-           (f2cl-lib:fref nnlog-%data% (last$) ((1 *)) nnlog-%offset%)
-           nrmom)
+          (setf (f2cl-lib:fref rlist-%data% (maxerr) ((1 *)) rlist-%offset%)
+                  area1)
+          (setf (f2cl-lib:fref rlist-%data% (last$) ((1 *)) rlist-%offset%)
+                  area2)
+          (setf (f2cl-lib:fref nnlog-%data% (maxerr) ((1 *)) nnlog-%offset%)
+                  nrmom)
+          (setf (f2cl-lib:fref nnlog-%data% (last$) ((1 *)) nnlog-%offset%)
+                  nrmom)
           (setf errbnd (max epsabs (* epsrel (abs area))))
           (if (or (>= (f2cl-lib:int-add iroff1 iroff2) 10) (>= iroff3 20))
               (setf ier 2))
@@ -227,44 +218,28 @@
                (* (+ 1.0 (* 100.0 epmach)) (+ (abs a2) (* 1000.0 uflow))))
            (setf ier 4))
           (if (> error2 error1) (go label30))
-          (f2cl-lib:fset
-           (f2cl-lib:fref alist-%data% (last$) ((1 *)) alist-%offset%)
-           a2)
-          (f2cl-lib:fset
-           (f2cl-lib:fref blist-%data% (maxerr) ((1 *)) blist-%offset%)
-           b1)
-          (f2cl-lib:fset
-           (f2cl-lib:fref blist-%data% (last$) ((1 *)) blist-%offset%)
-           b2)
-          (f2cl-lib:fset
-           (f2cl-lib:fref elist-%data% (maxerr) ((1 *)) elist-%offset%)
-           error1)
-          (f2cl-lib:fset
-           (f2cl-lib:fref elist-%data% (last$) ((1 *)) elist-%offset%)
-           error2)
+          (setf (f2cl-lib:fref alist-%data% (last$) ((1 *)) alist-%offset%) a2)
+          (setf (f2cl-lib:fref blist-%data% (maxerr) ((1 *)) blist-%offset%)
+                  b1)
+          (setf (f2cl-lib:fref blist-%data% (last$) ((1 *)) blist-%offset%) b2)
+          (setf (f2cl-lib:fref elist-%data% (maxerr) ((1 *)) elist-%offset%)
+                  error1)
+          (setf (f2cl-lib:fref elist-%data% (last$) ((1 *)) elist-%offset%)
+                  error2)
           (go label40)
          label30
-          (f2cl-lib:fset
-           (f2cl-lib:fref alist-%data% (maxerr) ((1 *)) alist-%offset%)
-           a2)
-          (f2cl-lib:fset
-           (f2cl-lib:fref alist-%data% (last$) ((1 *)) alist-%offset%)
-           a1)
-          (f2cl-lib:fset
-           (f2cl-lib:fref blist-%data% (last$) ((1 *)) blist-%offset%)
-           b1)
-          (f2cl-lib:fset
-           (f2cl-lib:fref rlist-%data% (maxerr) ((1 *)) rlist-%offset%)
-           area2)
-          (f2cl-lib:fset
-           (f2cl-lib:fref rlist-%data% (last$) ((1 *)) rlist-%offset%)
-           area1)
-          (f2cl-lib:fset
-           (f2cl-lib:fref elist-%data% (maxerr) ((1 *)) elist-%offset%)
-           error2)
-          (f2cl-lib:fset
-           (f2cl-lib:fref elist-%data% (last$) ((1 *)) elist-%offset%)
-           error1)
+          (setf (f2cl-lib:fref alist-%data% (maxerr) ((1 *)) alist-%offset%)
+                  a2)
+          (setf (f2cl-lib:fref alist-%data% (last$) ((1 *)) alist-%offset%) a1)
+          (setf (f2cl-lib:fref blist-%data% (last$) ((1 *)) blist-%offset%) b1)
+          (setf (f2cl-lib:fref rlist-%data% (maxerr) ((1 *)) rlist-%offset%)
+                  area2)
+          (setf (f2cl-lib:fref rlist-%data% (last$) ((1 *)) rlist-%offset%)
+                  area1)
+          (setf (f2cl-lib:fref elist-%data% (maxerr) ((1 *)) elist-%offset%)
+                  error2)
+          (setf (f2cl-lib:fref elist-%data% (last$) ((1 *)) elist-%offset%)
+                  error1)
          label40
           (multiple-value-bind (var-0 var-1 var-2 var-3 var-4 var-5 var-6)
               (dqpsrt limit last$ maxerr errmax elist iord nrmax)
@@ -282,18 +257,16 @@
           (if extrap (go label70))
          label50
           (setf width
-                  (coerce
-                   (abs
-                    (-
-                     (f2cl-lib:fref blist-%data%
-                                    (maxerr)
-                                    ((1 *))
-                                    blist-%offset%)
-                     (f2cl-lib:fref alist-%data%
-                                    (maxerr)
-                                    ((1 *))
-                                    alist-%offset%)))
-                   'double-float))
+                  (abs
+                   (-
+                    (f2cl-lib:fref blist-%data%
+                                   (maxerr)
+                                   ((1 *))
+                                   blist-%offset%)
+                    (f2cl-lib:fref alist-%data%
+                                   (maxerr)
+                                   ((1 *))
+                                   alist-%offset%))))
           (if (> width small) (go label140))
           (if extall (go label60))
           (setf small (* small 0.5))
@@ -338,7 +311,7 @@
              label80))
          label90
           (setf numrl2 (f2cl-lib:int-add numrl2 1))
-          (f2cl-lib:fset (f2cl-lib:fref rlist2 (numrl2) ((1 52))) area)
+          (setf (f2cl-lib:fref rlist2 (numrl2) ((1 52))) area)
           (if (< numrl2 3) (go label110))
           (multiple-value-bind (var-0 var-1 var-2 var-3 var-4 var-5)
               (dqelg numrl2 rlist2 reseps abseps res3la nres)
@@ -371,7 +344,7 @@
          label120
           (setf small (* small 0.5))
           (setf numrl2 (f2cl-lib:int-add numrl2 1))
-          (f2cl-lib:fset (f2cl-lib:fref rlist2 (numrl2) ((1 52))) area)
+          (setf (f2cl-lib:fref rlist2 (numrl2) ((1 52))) area)
          label130
           (setf ertest errbnd)
           (setf erlarg errsum)
@@ -438,3 +411,29 @@
                momcom
                nil)))))
 
+(in-package #-gcl #:cl-user #+gcl "CL-USER")
+#+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
+(eval-when (:load-toplevel :compile-toplevel :execute)
+  (setf (gethash 'fortran-to-lisp::dqawoe
+                 fortran-to-lisp::*f2cl-function-info*)
+          (fortran-to-lisp::make-f2cl-finfo
+           :arg-types '(t (double-float) (double-float) (double-float)
+                        (fortran-to-lisp::integer4) (double-float)
+                        (double-float) (fortran-to-lisp::integer4)
+                        (fortran-to-lisp::integer4) (fortran-to-lisp::integer4)
+                        (double-float) (double-float)
+                        (fortran-to-lisp::integer4) (fortran-to-lisp::integer4)
+                        (fortran-to-lisp::integer4) (array double-float (*))
+                        (array double-float (*)) (array double-float (*))
+                        (array double-float (*))
+                        (array fortran-to-lisp::integer4 (*))
+                        (array fortran-to-lisp::integer4 (*))
+                        (fortran-to-lisp::integer4) (array double-float (*)))
+           :return-values '(nil nil nil nil fortran-to-lisp::integr nil nil nil
+                            nil nil fortran-to-lisp::result
+                            fortran-to-lisp::abserr fortran-to-lisp::neval
+                            fortran-to-lisp::ier fortran-to-lisp::last$ nil nil
+                            nil nil nil nil fortran-to-lisp::momcom nil)
+           :calls '(fortran-to-lisp::dqelg fortran-to-lisp::dqpsrt
+                    fortran-to-lisp::dqc25f fortran-to-lisp::d1mach))))
+
