@@ -1,5 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
-;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:18:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-12 (19D)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
@@ -21,9 +21,9 @@
   (declare (type (array double-float (11)) x))
   (defun dqc25s
          (f a b bl br alfa beta ri rj rg rh result abserr resasc integr nev)
-    (declare (type f2cl-lib:integer4 nev integr)
+    (declare (type (f2cl-lib:integer4) nev integr)
              (type (array double-float (*)) rh rg rj ri)
-             (type double-float resasc abserr result beta alfa br bl b a))
+             (type (double-float) resasc abserr result beta alfa br bl b a))
     (f2cl-lib:with-multi-array-data
         ((ri double-float ri-%data% ri-%offset%)
          (rj double-float rj-%data% rj-%offset%)
@@ -33,13 +33,12 @@
              (cheb24 (make-array 25 :element-type 'double-float))
              (fval (make-array 25 :element-type 'double-float)) (i 0) (isym 0)
              (centr 0.0) (dc 0.0) (factor 0.0) (fix 0.0) (hlgth 0.0)
-             (resabs 0.0) (res12 0.0) (res24 0.0) (u 0.0) (abs$ 0.0f0))
-        (declare (type single-float abs$)
-                 (type (array double-float (25)) fval cheb24)
+             (resabs 0.0) (res12 0.0) (res24 0.0) (u 0.0))
+        (declare (type (array double-float (25)) fval cheb24)
                  (type (array double-float (13)) cheb12)
-                 (type double-float u res24 res12 resabs hlgth fix factor dc
-                                    centr)
-                 (type f2cl-lib:integer4 isym i))
+                 (type (double-float) u res24 res12 resabs hlgth fix factor dc
+                                      centr)
+                 (type (f2cl-lib:integer4) isym i))
         (setf nev 25)
         (if (and (= bl a) (or (/= alfa 0.0) (= integr 2) (= integr 4)))
             (go label10))
@@ -66,23 +65,19 @@
         (setf hlgth (* 0.5 (- br bl)))
         (setf centr (* 0.5 (+ br bl)))
         (setf fix (- b centr))
-        (f2cl-lib:fset (f2cl-lib:fref fval (1) ((1 25)))
-                       (* 0.5
-                          (funcall f (+ hlgth centr))
-                          (expt (- fix hlgth) beta)))
-        (f2cl-lib:fset (f2cl-lib:fref fval (13) ((1 25)))
-                       (*
-                        (multiple-value-bind (ret-val var-0)
-                            (funcall f centr)
-                          (declare (ignore))
-                          (when var-0
-                            (setf centr var-0))
-                          ret-val)
-                        (expt fix beta)))
-        (f2cl-lib:fset (f2cl-lib:fref fval (25) ((1 25)))
-                       (* 0.5
-                          (funcall f (- centr hlgth))
-                          (expt (+ fix hlgth) beta)))
+        (setf (f2cl-lib:fref fval (1) ((1 25)))
+                (* 0.5 (funcall f (+ hlgth centr)) (expt (- fix hlgth) beta)))
+        (setf (f2cl-lib:fref fval (13) ((1 25)))
+                (*
+                 (multiple-value-bind (ret-val var-0)
+                     (funcall f centr)
+                   (declare (ignore))
+                   (when var-0
+                     (setf centr var-0))
+                   ret-val)
+                 (expt fix beta)))
+        (setf (f2cl-lib:fref fval (25) ((1 25)))
+                (* 0.5 (funcall f (- centr hlgth)) (expt (+ fix hlgth) beta)))
         (f2cl-lib:fdo (i 2 (f2cl-lib:int-add i 1))
                       ((> i 12) nil)
           (tagbody
@@ -90,10 +85,10 @@
                     (* hlgth
                        (f2cl-lib:fref x ((f2cl-lib:int-sub i 1)) ((1 11)))))
             (setf isym (f2cl-lib:int-sub 26 i))
-            (f2cl-lib:fset (f2cl-lib:fref fval (i) ((1 25)))
-                           (* (funcall f (+ u centr)) (expt (- fix u) beta)))
-            (f2cl-lib:fset (f2cl-lib:fref fval (isym) ((1 25)))
-                           (* (funcall f (- centr u)) (expt (+ fix u) beta)))
+            (setf (f2cl-lib:fref fval (i) ((1 25)))
+                    (* (funcall f (+ u centr)) (expt (- fix u) beta)))
+            (setf (f2cl-lib:fref fval (isym) ((1 25)))
+                    (* (funcall f (- centr u)) (expt (+ fix u) beta)))
            label20))
         (setf factor (expt hlgth (+ alfa 1.0)))
         (setf result 0.0)
@@ -125,7 +120,7 @@
         (if (= integr 1) (go label130))
         (setf dc (f2cl-lib:flog (- br bl)))
         (setf result (* res24 dc))
-        (setf abserr (coerce (abs (* (- res24 res12) dc)) 'double-float))
+        (setf abserr (abs (* (- res24 res12) dc)))
         (setf res12 0.0)
         (setf res24 0.0)
         (f2cl-lib:fdo (i 1 (f2cl-lib:int-add i 1))
@@ -150,15 +145,14 @@
            label60))
         (go label130)
        label70
-        (f2cl-lib:fset (f2cl-lib:fref fval (1) ((1 25)))
-                       (* (f2cl-lib:fref fval (1) ((1 25)))
-                          (f2cl-lib:flog (- fix hlgth))))
-        (f2cl-lib:fset (f2cl-lib:fref fval (13) ((1 25)))
-                       (* (f2cl-lib:fref fval (13) ((1 25)))
-                          (f2cl-lib:flog fix)))
-        (f2cl-lib:fset (f2cl-lib:fref fval (25) ((1 25)))
-                       (* (f2cl-lib:fref fval (25) ((1 25)))
-                          (f2cl-lib:flog (+ fix hlgth))))
+        (setf (f2cl-lib:fref fval (1) ((1 25)))
+                (* (f2cl-lib:fref fval (1) ((1 25)))
+                   (f2cl-lib:flog (- fix hlgth))))
+        (setf (f2cl-lib:fref fval (13) ((1 25)))
+                (* (f2cl-lib:fref fval (13) ((1 25))) (f2cl-lib:flog fix)))
+        (setf (f2cl-lib:fref fval (25) ((1 25)))
+                (* (f2cl-lib:fref fval (25) ((1 25)))
+                   (f2cl-lib:flog (+ fix hlgth))))
         (f2cl-lib:fdo (i 2 (f2cl-lib:int-add i 1))
                       ((> i 12) nil)
           (tagbody
@@ -166,12 +160,12 @@
                     (* hlgth
                        (f2cl-lib:fref x ((f2cl-lib:int-sub i 1)) ((1 11)))))
             (setf isym (f2cl-lib:int-sub 26 i))
-            (f2cl-lib:fset (f2cl-lib:fref fval (i) ((1 25)))
-                           (* (f2cl-lib:fref fval (i) ((1 25)))
-                              (f2cl-lib:flog (- fix u))))
-            (f2cl-lib:fset (f2cl-lib:fref fval (isym) ((1 25)))
-                           (* (f2cl-lib:fref fval (isym) ((1 25)))
-                              (f2cl-lib:flog (+ fix u))))
+            (setf (f2cl-lib:fref fval (i) ((1 25)))
+                    (* (f2cl-lib:fref fval (i) ((1 25)))
+                       (f2cl-lib:flog (- fix u))))
+            (setf (f2cl-lib:fref fval (isym) ((1 25)))
+                    (* (f2cl-lib:fref fval (isym) ((1 25)))
+                       (f2cl-lib:flog (+ fix u))))
            label80))
         (dqcheb x fval cheb12 cheb24)
         (f2cl-lib:fdo (i 1 (f2cl-lib:int-add i 1))
@@ -197,7 +191,7 @@
         (if (= integr 3) (go label130))
         (setf dc (f2cl-lib:flog (- br bl)))
         (setf result (* res24 dc))
-        (setf abserr (coerce (abs (* (- res24 res12) dc)) 'double-float))
+        (setf abserr (abs (* (- res24 res12) dc)))
         (setf res12 0.0)
         (setf res24 0.0)
         (f2cl-lib:fdo (i 1 (f2cl-lib:int-add i 1))
@@ -228,23 +222,19 @@
         (setf hlgth (* 0.5 (- br bl)))
         (setf centr (* 0.5 (+ br bl)))
         (setf fix (- centr a))
-        (f2cl-lib:fset (f2cl-lib:fref fval (1) ((1 25)))
-                       (* 0.5
-                          (funcall f (+ hlgth centr))
-                          (expt (+ fix hlgth) alfa)))
-        (f2cl-lib:fset (f2cl-lib:fref fval (13) ((1 25)))
-                       (*
-                        (multiple-value-bind (ret-val var-0)
-                            (funcall f centr)
-                          (declare (ignore))
-                          (when var-0
-                            (setf centr var-0))
-                          ret-val)
-                        (expt fix alfa)))
-        (f2cl-lib:fset (f2cl-lib:fref fval (25) ((1 25)))
-                       (* 0.5
-                          (funcall f (- centr hlgth))
-                          (expt (- fix hlgth) alfa)))
+        (setf (f2cl-lib:fref fval (1) ((1 25)))
+                (* 0.5 (funcall f (+ hlgth centr)) (expt (+ fix hlgth) alfa)))
+        (setf (f2cl-lib:fref fval (13) ((1 25)))
+                (*
+                 (multiple-value-bind (ret-val var-0)
+                     (funcall f centr)
+                   (declare (ignore))
+                   (when var-0
+                     (setf centr var-0))
+                   ret-val)
+                 (expt fix alfa)))
+        (setf (f2cl-lib:fref fval (25) ((1 25)))
+                (* 0.5 (funcall f (- centr hlgth)) (expt (- fix hlgth) alfa)))
         (f2cl-lib:fdo (i 2 (f2cl-lib:int-add i 1))
                       ((> i 12) nil)
           (tagbody
@@ -252,10 +242,10 @@
                     (* hlgth
                        (f2cl-lib:fref x ((f2cl-lib:int-sub i 1)) ((1 11)))))
             (setf isym (f2cl-lib:int-sub 26 i))
-            (f2cl-lib:fset (f2cl-lib:fref fval (i) ((1 25)))
-                           (* (funcall f (+ u centr)) (expt (+ fix u) alfa)))
-            (f2cl-lib:fset (f2cl-lib:fref fval (isym) ((1 25)))
-                           (* (funcall f (- centr u)) (expt (- fix u) alfa)))
+            (setf (f2cl-lib:fref fval (i) ((1 25)))
+                    (* (funcall f (+ u centr)) (expt (+ fix u) alfa)))
+            (setf (f2cl-lib:fref fval (isym) ((1 25)))
+                    (* (funcall f (- centr u)) (expt (- fix u) alfa)))
            label150))
         (setf factor (expt hlgth (+ beta 1.0)))
         (setf result 0.0)
@@ -287,7 +277,7 @@
         (if (= integr 1) (go label260))
         (setf dc (f2cl-lib:flog (- br bl)))
         (setf result (* res24 dc))
-        (setf abserr (coerce (abs (* (- res24 res12) dc)) 'double-float))
+        (setf abserr (abs (* (- res24 res12) dc)))
         (setf res12 0.0)
         (setf res24 0.0)
         (f2cl-lib:fdo (i 1 (f2cl-lib:int-add i 1))
@@ -312,15 +302,14 @@
            label190))
         (go label260)
        label200
-        (f2cl-lib:fset (f2cl-lib:fref fval (1) ((1 25)))
-                       (* (f2cl-lib:fref fval (1) ((1 25)))
-                          (f2cl-lib:flog (+ fix hlgth))))
-        (f2cl-lib:fset (f2cl-lib:fref fval (13) ((1 25)))
-                       (* (f2cl-lib:fref fval (13) ((1 25)))
-                          (f2cl-lib:flog fix)))
-        (f2cl-lib:fset (f2cl-lib:fref fval (25) ((1 25)))
-                       (* (f2cl-lib:fref fval (25) ((1 25)))
-                          (f2cl-lib:flog (- fix hlgth))))
+        (setf (f2cl-lib:fref fval (1) ((1 25)))
+                (* (f2cl-lib:fref fval (1) ((1 25)))
+                   (f2cl-lib:flog (+ fix hlgth))))
+        (setf (f2cl-lib:fref fval (13) ((1 25)))
+                (* (f2cl-lib:fref fval (13) ((1 25))) (f2cl-lib:flog fix)))
+        (setf (f2cl-lib:fref fval (25) ((1 25)))
+                (* (f2cl-lib:fref fval (25) ((1 25)))
+                   (f2cl-lib:flog (- fix hlgth))))
         (f2cl-lib:fdo (i 2 (f2cl-lib:int-add i 1))
                       ((> i 12) nil)
           (tagbody
@@ -328,12 +317,12 @@
                     (* hlgth
                        (f2cl-lib:fref x ((f2cl-lib:int-sub i 1)) ((1 11)))))
             (setf isym (f2cl-lib:int-sub 26 i))
-            (f2cl-lib:fset (f2cl-lib:fref fval (i) ((1 25)))
-                           (* (f2cl-lib:fref fval (i) ((1 25)))
-                              (f2cl-lib:flog (+ u fix))))
-            (f2cl-lib:fset (f2cl-lib:fref fval (isym) ((1 25)))
-                           (* (f2cl-lib:fref fval (isym) ((1 25)))
-                              (f2cl-lib:flog (- fix u))))
+            (setf (f2cl-lib:fref fval (i) ((1 25)))
+                    (* (f2cl-lib:fref fval (i) ((1 25)))
+                       (f2cl-lib:flog (+ u fix))))
+            (setf (f2cl-lib:fref fval (isym) ((1 25)))
+                    (* (f2cl-lib:fref fval (isym) ((1 25)))
+                       (f2cl-lib:flog (- fix u))))
            label210))
         (dqcheb x fval cheb12 cheb24)
         (f2cl-lib:fdo (i 1 (f2cl-lib:int-add i 1))
@@ -359,7 +348,7 @@
         (if (= integr 2) (go label260))
         (setf dc (f2cl-lib:flog (- br bl)))
         (setf result (* res24 dc))
-        (setf abserr (coerce (abs (* (- res24 res12) dc)) 'double-float))
+        (setf abserr (abs (* (- res24 res12) dc)))
         (setf res12 0.0)
         (setf res24 0.0)
         (f2cl-lib:fdo (i 1 (f2cl-lib:int-add i 1))
@@ -406,3 +395,23 @@
                  integr
                  nev))))))
 
+(in-package #-gcl #:cl-user #+gcl "CL-USER")
+#+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
+(eval-when (:load-toplevel :compile-toplevel :execute)
+  (setf (gethash 'fortran-to-lisp::dqc25s
+                 fortran-to-lisp::*f2cl-function-info*)
+          (fortran-to-lisp::make-f2cl-finfo
+           :arg-types '(t (double-float) (double-float) (double-float)
+                        (double-float) (double-float) (double-float)
+                        (array double-float (25)) (array double-float (25))
+                        (array double-float (25)) (array double-float (25))
+                        (double-float) (double-float) (double-float)
+                        (fortran-to-lisp::integer4)
+                        (fortran-to-lisp::integer4))
+           :return-values '(nil fortran-to-lisp::a fortran-to-lisp::b nil nil
+                            fortran-to-lisp::alfa fortran-to-lisp::beta nil nil
+                            nil nil fortran-to-lisp::result
+                            fortran-to-lisp::abserr fortran-to-lisp::resasc
+                            fortran-to-lisp::integr fortran-to-lisp::nev)
+           :calls '(fortran-to-lisp::dqcheb fortran-to-lisp::dqk15w))))
+
