@@ -1,5 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
-;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:18:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-12 (19D)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
@@ -10,11 +10,11 @@
 
 
 (defun initds (os nos eta)
-  (declare (type single-float eta)
-           (type f2cl-lib:integer4 nos)
+  (declare (type (single-float) eta)
+           (type (integer) nos)
            (type (simple-array double-float (*)) os))
-  (prog ((initds 0) (abs$ 0.0f0) (i 0) (ii 0) (err 0.0f0))
-    (declare (type single-float err abs$) (type f2cl-lib:integer4 ii i initds))
+  (prog ((initds 0) (i 0) (ii 0) (err 0.0f0))
+    (declare (type (single-float) err) (type (integer) ii i initds))
     (if (< nos 1)
         (xermsg "SLATEC" "INITDS" "Number of coefficients is less than 1" 2 1))
     (setf err 0.0f0)
@@ -35,3 +35,14 @@
    end_label
     (return (values initds nil nil nil))))
 
+(in-package #-gcl #:cl-user #+gcl "CL-USER")
+#+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
+(eval-when (:load-toplevel :compile-toplevel :execute)
+  (setf (gethash 'fortran-to-lisp::initds
+                 fortran-to-lisp::*f2cl-function-info*)
+          (fortran-to-lisp::make-f2cl-finfo
+           :arg-types '((simple-array double-float (*)) (integer)
+                        (single-float))
+           :return-values '(nil nil nil)
+           :calls '(fortran-to-lisp::xermsg))))
+
