@@ -1,5 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
-;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:18:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-12 (19D)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
@@ -15,11 +15,11 @@
       (zeroi 0.0)
       (coner 1.0)
       (conei 0.0))
-  (declare (type double-float conei coner zeroi zeror rtpi pi$))
+  (declare (type (double-float) conei coner zeroi zeror rtpi pi$))
   (defun zasyi (zr zi fnu kode n yr yi nz rl tol elim alim)
     (declare (type (simple-array double-float (*)) yi yr)
-             (type f2cl-lib:integer4 nz n kode)
-             (type double-float alim elim tol rl fnu zi zr))
+             (type (f2cl-lib:integer4) nz n kode)
+             (type (double-float) alim elim tol rl fnu zi zr))
     (prog ((i 0) (ib 0) (il 0) (inu 0) (j 0) (jl 0) (k 0) (koded 0) (m 0)
            (nn 0) (aa 0.0) (aez 0.0) (ak 0.0) (ak1i 0.0) (ak1r 0.0) (arg 0.0)
            (arm 0.0) (atol 0.0) (az 0.0) (bb 0.0) (bk 0.0) (cki 0.0) (ckr 0.0)
@@ -27,15 +27,14 @@
            (dfnu 0.0) (dki 0.0) (dkr 0.0) (dnu2 0.0) (ezi 0.0) (ezr 0.0)
            (fdn 0.0) (p1i 0.0) (p1r 0.0) (raz 0.0) (rtr1 0.0) (rzi 0.0)
            (rzr 0.0) (s 0.0) (sgn 0.0) (sqk 0.0) (sti 0.0) (str 0.0) (s2i 0.0)
-           (s2r 0.0) (tzi 0.0) (tzr 0.0) (abs$ 0.0f0))
-      (declare (type single-float abs$)
-               (type double-float tzr tzi s2r s2i str sti sqk sgn s rzr rzi
-                                  rtr1 raz p1r p1i fdn ezr ezi dnu2 dkr dki
-                                  dfnu czr czi cs2r cs2i cs1r cs1i ckr cki bk
-                                  bb az atol arm arg ak1r ak1i ak aez aa)
-               (type f2cl-lib:integer4 nn m koded k jl j inu il ib i))
+           (s2r 0.0) (tzi 0.0) (tzr 0.0))
+      (declare (type (double-float) tzr tzi s2r s2i str sti sqk sgn s rzr rzi
+                                    rtr1 raz p1r p1i fdn ezr ezi dnu2 dkr dki
+                                    dfnu czr czi cs2r cs2i cs1r cs1i ckr cki bk
+                                    bb az atol arm arg ak1r ak1i ak aez aa)
+               (type (f2cl-lib:integer4) nn m koded k jl j inu il ib i))
       (setf nz 0)
-      (setf az (zabs zr zi))
+      (setf az (coerce (realpart (zabs zr zi)) 'double-float))
       (setf arm (* 1000.0 (f2cl-lib:d1mach 1)))
       (setf rtr1 (f2cl-lib:fsqrt arm))
       (setf il (min (the f2cl-lib:integer4 2) (the f2cl-lib:integer4 n)))
@@ -46,7 +45,7 @@
       (setf ak1r (* rtpi str raz))
       (setf ak1i (* rtpi sti raz))
       (multiple-value-bind (var-0 var-1 var-2 var-3)
-          (zsqrt ak1r ak1i ak1r ak1i)
+          (f2cl-lib:zsqrt ak1r ak1i ak1r ak1i)
         (declare (ignore var-0 var-1))
         (setf ak1r var-2)
         (setf ak1i var-3))
@@ -163,10 +162,8 @@
           (setf p1r (- p1r))
           (setf p1i (- p1i))
           (setf m (f2cl-lib:int-add (f2cl-lib:int-sub n il) k))
-          (f2cl-lib:fset (f2cl-lib:fref yr (m) ((1 n)))
-                         (- (* s2r ak1r) (* s2i ak1i)))
-          (f2cl-lib:fset (f2cl-lib:fref yi (m) ((1 n)))
-                         (+ (* s2r ak1i) (* s2i ak1r)))
+          (setf (f2cl-lib:fref yr (m) ((1 n))) (- (* s2r ak1r) (* s2i ak1i)))
+          (setf (f2cl-lib:fref yi (m) ((1 n))) (+ (* s2r ak1i) (* s2i ak1r)))
          label70))
       (if (<= n 2) (go end_label))
       (setf nn n)
@@ -180,32 +177,28 @@
       (f2cl-lib:fdo (i ib (f2cl-lib:int-add i 1))
                     ((> i nn) nil)
         (tagbody
-          (f2cl-lib:fset (f2cl-lib:fref yr (k) ((1 n)))
-                         (+
-                          (* (+ ak fnu)
-                             (-
-                              (* rzr
-                                 (f2cl-lib:fref yr
-                                                ((f2cl-lib:int-add k 1))
-                                                ((1 n))))
-                              (* rzi
-                                 (f2cl-lib:fref yi
-                                                ((f2cl-lib:int-add k 1))
-                                                ((1 n))))))
-                          (f2cl-lib:fref yr ((f2cl-lib:int-add k 2)) ((1 n)))))
-          (f2cl-lib:fset (f2cl-lib:fref yi (k) ((1 n)))
-                         (+
-                          (* (+ ak fnu)
-                             (+
-                              (* rzr
-                                 (f2cl-lib:fref yi
-                                                ((f2cl-lib:int-add k 1))
-                                                ((1 n))))
-                              (* rzi
-                                 (f2cl-lib:fref yr
-                                                ((f2cl-lib:int-add k 1))
-                                                ((1 n))))))
-                          (f2cl-lib:fref yi ((f2cl-lib:int-add k 2)) ((1 n)))))
+          (setf (f2cl-lib:fref yr (k) ((1 n)))
+                  (+
+                   (* (+ ak fnu)
+                      (-
+                       (* rzr
+                          (f2cl-lib:fref yr ((f2cl-lib:int-add k 1)) ((1 n))))
+                       (* rzi
+                          (f2cl-lib:fref yi
+                                         ((f2cl-lib:int-add k 1))
+                                         ((1 n))))))
+                   (f2cl-lib:fref yr ((f2cl-lib:int-add k 2)) ((1 n)))))
+          (setf (f2cl-lib:fref yi (k) ((1 n)))
+                  (+
+                   (* (+ ak fnu)
+                      (+
+                       (* rzr
+                          (f2cl-lib:fref yi ((f2cl-lib:int-add k 1)) ((1 n))))
+                       (* rzi
+                          (f2cl-lib:fref yr
+                                         ((f2cl-lib:int-add k 1))
+                                         ((1 n))))))
+                   (f2cl-lib:fref yi ((f2cl-lib:int-add k 2)) ((1 n)))))
           (setf ak (- ak 1.0))
           (setf k (f2cl-lib:int-sub k 1))
          label80))
@@ -221,10 +214,10 @@
           (setf str
                   (- (* (f2cl-lib:fref yr (i) ((1 n))) ckr)
                      (* (f2cl-lib:fref yi (i) ((1 n))) cki)))
-          (f2cl-lib:fset (f2cl-lib:fref yi (i) ((1 n)))
-                         (+ (* (f2cl-lib:fref yr (i) ((1 n))) cki)
-                            (* (f2cl-lib:fref yi (i) ((1 n))) ckr)))
-          (f2cl-lib:fset (f2cl-lib:fref yr (i) ((1 n))) str)
+          (setf (f2cl-lib:fref yi (i) ((1 n)))
+                  (+ (* (f2cl-lib:fref yr (i) ((1 n))) cki)
+                     (* (f2cl-lib:fref yi (i) ((1 n))) ckr)))
+          (setf (f2cl-lib:fref yr (i) ((1 n))) str)
          label90))
       (go end_label)
      label100
@@ -236,3 +229,20 @@
      end_label
       (return (values nil nil nil nil nil nil nil nz nil nil nil nil)))))
 
+(in-package #-gcl #:cl-user #+gcl "CL-USER")
+#+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
+(eval-when (:load-toplevel :compile-toplevel :execute)
+  (setf (gethash 'fortran-to-lisp::zasyi fortran-to-lisp::*f2cl-function-info*)
+          (fortran-to-lisp::make-f2cl-finfo
+           :arg-types '((double-float) (double-float) (double-float)
+                        (fortran-to-lisp::integer4) (fortran-to-lisp::integer4)
+                        (simple-array double-float (*))
+                        (simple-array double-float (*))
+                        (fortran-to-lisp::integer4) (double-float)
+                        (double-float) (double-float) (double-float))
+           :return-values '(nil nil nil nil nil nil nil fortran-to-lisp::nz nil
+                            nil nil nil)
+           :calls '(fortran-to-lisp::zdiv fortran-to-lisp::zmlt
+                    fortran-to-lisp::zexp fortran-to-lisp::zsqrt
+                    fortran-to-lisp::d1mach fortran-to-lisp::zabs))))
+
