@@ -1,5 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
-;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:18:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-12 (19D)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
@@ -11,15 +11,14 @@
 
 (defun zbesk (zr zi fnu kode n cyr cyi nz ierr)
   (declare (type (simple-array double-float (*)) cyi cyr)
-           (type f2cl-lib:integer4 ierr nz n kode)
-           (type double-float fnu zi zr))
+           (type (f2cl-lib:integer4) ierr nz n kode)
+           (type (double-float) fnu zi zr))
   (prog ((k 0) (k1 0) (k2 0) (mr 0) (nn 0) (nuf 0) (nw 0) (aa 0.0) (alim 0.0)
          (aln 0.0) (arg 0.0) (az 0.0) (dig 0.0) (elim 0.0) (fn 0.0) (fnul 0.0)
-         (rl 0.0) (r1m5 0.0) (tol 0.0) (ufl 0.0) (bb 0.0) (abs$ 0.0f0))
-    (declare (type single-float abs$)
-             (type double-float bb ufl tol r1m5 rl fnul fn elim dig az arg aln
-                                alim aa)
-             (type f2cl-lib:integer4 nw nuf nn mr k2 k1 k))
+         (rl 0.0) (r1m5 0.0) (tol 0.0) (ufl 0.0) (bb 0.0))
+    (declare (type (double-float) bb ufl tol r1m5 rl fnul fn elim dig az arg
+                                  aln alim aa)
+             (type (f2cl-lib:integer4) nw nuf nn mr k2 k1 k))
     (setf ierr 0)
     (setf nz 0)
     (if (and (= zi 0.0f0) (= zr 0.0f0)) (setf ierr 1))
@@ -28,11 +27,13 @@
     (if (< n 1) (setf ierr 1))
     (if (/= ierr 0) (go end_label))
     (setf nn n)
-    (setf tol (max (f2cl-lib:d1mach 4) 1.e-18))
+    (setf tol (max (f2cl-lib:d1mach 4) 1.0e-18))
     (setf k1 (f2cl-lib:i1mach 15))
     (setf k2 (f2cl-lib:i1mach 16))
     (setf r1m5 (f2cl-lib:d1mach 5))
-    (setf k (f2cl-lib:int (min (abs k1) (abs k2))))
+    (setf k
+            (min (the f2cl-lib:integer4 (abs k1))
+                 (the f2cl-lib:integer4 (abs k2))))
     (setf elim (* 2.303 (- (* k r1m5) 3.0)))
     (setf k1 (f2cl-lib:int-sub (f2cl-lib:i1mach 14) 1))
     (setf aa (* r1m5 k1))
@@ -41,7 +42,7 @@
     (setf alim (+ elim (max (- aa) -41.45)))
     (setf fnul (+ 10.0 (* 6.0 (- dig 3.0))))
     (setf rl (+ (* 1.2 dig) 3.0))
-    (setf az (zabs zr zi))
+    (setf az (coerce (realpart (zabs zr zi)) 'double-float))
     (setf fn (+ fnu (f2cl-lib:int-sub nn 1)))
     (setf aa (/ 0.5 tol))
     (setf bb (* (f2cl-lib:i1mach 9) 0.5))
@@ -133,3 +134,21 @@
    end_label
     (return (values nil nil nil nil nil nil nil nz ierr))))
 
+(in-package #-gcl #:cl-user #+gcl "CL-USER")
+#+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
+(eval-when (:load-toplevel :compile-toplevel :execute)
+  (setf (gethash 'fortran-to-lisp::zbesk fortran-to-lisp::*f2cl-function-info*)
+          (fortran-to-lisp::make-f2cl-finfo
+           :arg-types '((double-float) (double-float) (double-float)
+                        (fortran-to-lisp::integer4) (fortran-to-lisp::integer4)
+                        (simple-array double-float (*))
+                        (simple-array double-float (*))
+                        (fortran-to-lisp::integer4)
+                        (fortran-to-lisp::integer4))
+           :return-values '(nil nil nil nil nil nil nil fortran-to-lisp::nz
+                            fortran-to-lisp::ierr)
+           :calls '(fortran-to-lisp::zbunk fortran-to-lisp::zacon
+                    fortran-to-lisp::zbknu fortran-to-lisp::zuoik
+                    fortran-to-lisp::zabs fortran-to-lisp::i1mach
+                    fortran-to-lisp::d1mach))))
+
