@@ -1,5 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
-;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:18:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-12 (19D)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
@@ -16,10 +16,10 @@
       (pi$ 3.141592653589793)
       (coner 1.0)
       (conei 0.0))
-  (declare (type double-float conei coner pi$ coef c2 c1 tth))
+  (declare (type (double-float) conei coner pi$ coef c2 c1 tth))
   (defun zbiry (zr zi id kode bir bii ierr)
-    (declare (type f2cl-lib:integer4 ierr kode id)
-             (type double-float bii bir zi zr))
+    (declare (type (f2cl-lib:integer4) ierr kode id)
+             (type (double-float) bii bir zi zr))
     (prog ((cyr (make-array 2 :element-type 'double-float))
            (cyi (make-array 2 :element-type 'double-float)) (k 0) (k1 0) (k2 0)
            (nz 0) (aa 0.0) (ad 0.0) (ak 0.0) (alim 0.0) (atrm 0.0) (az 0.0)
@@ -28,21 +28,20 @@
            (fmr 0.0) (fnu 0.0) (fnul 0.0) (rl 0.0) (r1m5 0.0) (sfac 0.0)
            (sti 0.0) (str 0.0) (s1i 0.0) (s1r 0.0) (s2i 0.0) (s2r 0.0)
            (tol 0.0) (trm1i 0.0) (trm1r 0.0) (trm2i 0.0) (trm2r 0.0) (ztai 0.0)
-           (ztar 0.0) (z3i 0.0) (z3r 0.0) (abs$ 0.0f0))
-      (declare (type single-float abs$)
-               (type (simple-array double-float (2)) cyr cyi)
-               (type double-float z3r z3i ztar ztai trm2r trm2i trm1r trm1i tol
-                                  s2r s2i s1r s1i str sti sfac r1m5 rl fnul fnu
-                                  fmr fid elim eaa d2 d1 dk dig csqr csqi ck cc
-                                  bk bb az3 az atrm alim ak ad aa)
-               (type f2cl-lib:integer4 nz k2 k1 k))
+           (ztar 0.0) (z3i 0.0) (z3r 0.0))
+      (declare (type (simple-array double-float (2)) cyr cyi)
+               (type (double-float) z3r z3i ztar ztai trm2r trm2i trm1r trm1i
+                                    tol s2r s2i s1r s1i str sti sfac r1m5 rl
+                                    fnul fnu fmr fid elim eaa d2 d1 dk dig csqr
+                                    csqi ck cc bk bb az3 az atrm alim ak ad aa)
+               (type (f2cl-lib:integer4) nz k2 k1 k))
       (setf ierr 0)
       (setf nz 0)
       (if (or (< id 0) (> id 1)) (setf ierr 1))
       (if (or (< kode 1) (> kode 2)) (setf ierr 1))
       (if (/= ierr 0) (go end_label))
-      (setf az (zabs zr zi))
-      (setf tol (max (f2cl-lib:d1mach 4) 1.e-18))
+      (setf az (coerce (realpart (zabs zr zi)) 'double-float))
+      (setf tol (max (f2cl-lib:d1mach 4) 1.0e-18))
       (setf fid (coerce (the f2cl-lib:integer4 id) 'double-float))
       (if (> az 1.0f0) (go label70))
       (setf s1r coner)
@@ -98,14 +97,14 @@
       (setf bii (+ (* c1 s1i) (* c2 (+ (* zr s2i) (* zi s2r)))))
       (if (= kode 1) (go end_label))
       (multiple-value-bind (var-0 var-1 var-2 var-3)
-          (zsqrt zr zi str sti)
+          (f2cl-lib:zsqrt zr zi str sti)
         (declare (ignore var-0 var-1))
         (setf str var-2)
         (setf sti var-3))
       (setf ztar (* tth (- (* zr str) (* zi sti))))
       (setf ztai (* tth (+ (* zr sti) (* zi str))))
       (setf aa ztar)
-      (setf aa (coerce (- (abs aa)) 'double-float))
+      (setf aa (- (abs aa)))
       (setf eaa (exp aa))
       (setf bir (* bir eaa))
       (setf bii (* bii eaa))
@@ -122,14 +121,14 @@
      label60
       (if (= kode 1) (go end_label))
       (multiple-value-bind (var-0 var-1 var-2 var-3)
-          (zsqrt zr zi str sti)
+          (f2cl-lib:zsqrt zr zi str sti)
         (declare (ignore var-0 var-1))
         (setf str var-2)
         (setf sti var-3))
       (setf ztar (* tth (- (* zr str) (* zi sti))))
       (setf ztai (* tth (+ (* zr sti) (* zi str))))
       (setf aa ztar)
-      (setf aa (coerce (- (abs aa)) 'double-float))
+      (setf aa (- (abs aa)))
       (setf eaa (exp aa))
       (setf bir (* bir eaa))
       (setf bii (* bii eaa))
@@ -139,7 +138,9 @@
       (setf k1 (f2cl-lib:i1mach 15))
       (setf k2 (f2cl-lib:i1mach 16))
       (setf r1m5 (f2cl-lib:d1mach 5))
-      (setf k (f2cl-lib:int (min (abs k1) (abs k2))))
+      (setf k
+              (min (the f2cl-lib:integer4 (abs k1))
+                   (the f2cl-lib:integer4 (abs k2))))
       (setf elim (* 2.303 (- (* k r1m5) 3.0)))
       (setf k1 (f2cl-lib:int-sub (f2cl-lib:i1mach 14) 1))
       (setf aa (* r1m5 k1))
@@ -156,7 +157,7 @@
       (setf aa (f2cl-lib:fsqrt aa))
       (if (> az aa) (setf ierr 3))
       (multiple-value-bind (var-0 var-1 var-2 var-3)
-          (zsqrt zr zi csqr csqi)
+          (f2cl-lib:zsqrt zr zi csqr csqi)
         (declare (ignore var-0 var-1))
         (setf csqr var-2)
         (setf csqi var-3))
@@ -166,7 +167,7 @@
       (setf ak ztai)
       (if (>= zr 0.0) (go label80))
       (setf bk ztar)
-      (setf ck (coerce (- (abs bk)) 'double-float))
+      (setf ck (- (abs bk)))
       (setf ztar ck)
       (setf ztai ak)
      label80
@@ -176,7 +177,7 @@
      label90
       (setf aa ztar)
       (if (= kode 2) (go label100))
-      (setf bb (coerce (abs aa) 'double-float))
+      (setf bb (abs aa))
       (if (< bb alim) (go label100))
       (setf bb (+ bb (* 0.25 (f2cl-lib:flog az))))
       (setf sfac tol)
@@ -219,14 +220,14 @@
         (declare (ignore var-0 var-1 var-2 var-3 var-4 var-5 var-6 var-8 var-9
                          var-10 var-11 var-12))
         (setf nz var-7))
-      (f2cl-lib:fset (f2cl-lib:fref cyr (1) ((1 2)))
-                     (* (f2cl-lib:fref cyr (1) ((1 2))) z3r))
-      (f2cl-lib:fset (f2cl-lib:fref cyi (1) ((1 2)))
-                     (* (f2cl-lib:fref cyi (1) ((1 2))) z3r))
-      (f2cl-lib:fset (f2cl-lib:fref cyr (2) ((1 2)))
-                     (* (f2cl-lib:fref cyr (2) ((1 2))) z3r))
-      (f2cl-lib:fset (f2cl-lib:fref cyi (2) ((1 2)))
-                     (* (f2cl-lib:fref cyi (2) ((1 2))) z3r))
+      (setf (f2cl-lib:fref cyr (1) ((1 2)))
+              (* (f2cl-lib:fref cyr (1) ((1 2))) z3r))
+      (setf (f2cl-lib:fref cyi (1) ((1 2)))
+              (* (f2cl-lib:fref cyi (1) ((1 2))) z3r))
+      (setf (f2cl-lib:fref cyr (2) ((1 2)))
+              (* (f2cl-lib:fref cyr (2) ((1 2))) z3r))
+      (setf (f2cl-lib:fref cyi (2) ((1 2)))
+              (* (f2cl-lib:fref cyi (2) ((1 2))) z3r))
       (multiple-value-bind (var-0 var-1 var-2 var-3 var-4 var-5)
           (zdiv (f2cl-lib:fref cyr (1) ((1 2))) (f2cl-lib:fref cyi (1) ((1 2)))
            ztar ztai str sti)
@@ -275,3 +276,18 @@
      end_label
       (return (values nil nil nil nil bir bii ierr)))))
 
+(in-package #-gcl #:cl-user #+gcl "CL-USER")
+#+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
+(eval-when (:load-toplevel :compile-toplevel :execute)
+  (setf (gethash 'fortran-to-lisp::zbiry fortran-to-lisp::*f2cl-function-info*)
+          (fortran-to-lisp::make-f2cl-finfo
+           :arg-types '((double-float) (double-float)
+                        (fortran-to-lisp::integer4) (fortran-to-lisp::integer4)
+                        (double-float) (double-float)
+                        (fortran-to-lisp::integer4))
+           :return-values '(nil nil nil nil fortran-to-lisp::bir
+                            fortran-to-lisp::bii fortran-to-lisp::ierr)
+           :calls '(fortran-to-lisp::zdiv fortran-to-lisp::zbinu
+                    fortran-to-lisp::i1mach fortran-to-lisp::zsqrt
+                    fortran-to-lisp::d1mach fortran-to-lisp::zabs))))
+
