@@ -1,5 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
-;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:18:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-12 (19D)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
@@ -10,11 +10,11 @@
 
 
 (let ((zeror 0.0) (zeroi 0.0))
-  (declare (type double-float zeroi zeror))
+  (declare (type (double-float) zeroi zeror))
   (defun zkscl (zrr zri fnu n yr yi nz rzr rzi ascle tol elim)
     (declare (type (simple-array double-float (*)) yi yr)
-             (type f2cl-lib:integer4 nz n)
-             (type double-float elim tol ascle rzi rzr fnu zri zrr))
+             (type (f2cl-lib:integer4) nz n)
+             (type (double-float) elim tol ascle rzi rzr fnu zri zrr))
     (prog ((cyr (make-array 2 :element-type 'double-float))
            (cyi (make-array 2 :element-type 'double-float)) (i 0) (ic 0)
            (idum 0) (kk 0) (nn 0) (nw 0) (acs 0.0) (as 0.0) (cki 0.0) (ckr 0.0)
@@ -22,9 +22,9 @@
            (s2r 0.0) (zdr 0.0) (zdi 0.0) (celmr 0.0) (elm 0.0) (helim 0.0)
            (alas 0.0))
       (declare (type (simple-array double-float (2)) cyr cyi)
-               (type double-float alas helim elm celmr zdi zdr s2r s2i s1r s1i
-                                  str fn csr csi ckr cki as acs)
-               (type f2cl-lib:integer4 nw nn kk idum ic i))
+               (type (double-float) alas helim elm celmr zdi zdr s2r s2i s1r
+                                    s1i str fn csr csi ckr cki as acs)
+               (type (f2cl-lib:integer4) nw nn kk idum ic i))
       (setf nz 0)
       (setf ic 0)
       (setf nn (min (the f2cl-lib:integer4 2) (the f2cl-lib:integer4 n)))
@@ -33,13 +33,13 @@
         (tagbody
           (setf s1r (f2cl-lib:fref yr (i) ((1 n))))
           (setf s1i (f2cl-lib:fref yi (i) ((1 n))))
-          (f2cl-lib:fset (f2cl-lib:fref cyr (i) ((1 2))) s1r)
-          (f2cl-lib:fset (f2cl-lib:fref cyi (i) ((1 2))) s1i)
-          (setf as (zabs s1r s1i))
+          (setf (f2cl-lib:fref cyr (i) ((1 2))) s1r)
+          (setf (f2cl-lib:fref cyi (i) ((1 2))) s1i)
+          (setf as (coerce (realpart (zabs s1r s1i)) 'double-float))
           (setf acs (- (f2cl-lib:flog as) zrr))
           (setf nz (f2cl-lib:int-add nz 1))
-          (f2cl-lib:fset (f2cl-lib:fref yr (i) ((1 n))) zeror)
-          (f2cl-lib:fset (f2cl-lib:fref yi (i) ((1 n))) zeroi)
+          (setf (f2cl-lib:fref yr (i) ((1 n))) zeror)
+          (setf (f2cl-lib:fref yi (i) ((1 n))) zeroi)
           (if (< acs (- elim)) (go label10))
           (multiple-value-bind (var-0 var-1 var-2 var-3 var-4)
               (zlog s1r s1i csr csi idum)
@@ -57,15 +57,15 @@
             (declare (ignore var-0 var-1 var-3 var-4))
             (setf nw var-2))
           (if (/= nw 0) (go label10))
-          (f2cl-lib:fset (f2cl-lib:fref yr (i) ((1 n))) csr)
-          (f2cl-lib:fset (f2cl-lib:fref yi (i) ((1 n))) csi)
+          (setf (f2cl-lib:fref yr (i) ((1 n))) csr)
+          (setf (f2cl-lib:fref yi (i) ((1 n))) csi)
           (setf ic i)
           (setf nz (f2cl-lib:int-sub nz 1))
          label10))
       (if (= n 1) (go end_label))
       (if (> ic 1) (go label20))
-      (f2cl-lib:fset (f2cl-lib:fref yr (1) ((1 n))) zeror)
-      (f2cl-lib:fset (f2cl-lib:fref yi (1) ((1 n))) zeroi)
+      (setf (f2cl-lib:fref yr (1) ((1 n))) zeror)
+      (setf (f2cl-lib:fref yi (1) ((1 n))) zeroi)
       (setf nz 2)
      label20
       (if (= n 2) (go end_label))
@@ -94,12 +94,12 @@
           (setf s1i csi)
           (setf ckr (+ ckr rzr))
           (setf cki (+ cki rzi))
-          (setf as (zabs s2r s2i))
+          (setf as (coerce (realpart (zabs s2r s2i)) 'double-float))
           (setf alas (f2cl-lib:flog as))
           (setf acs (- alas zdr))
           (setf nz (f2cl-lib:int-add nz 1))
-          (f2cl-lib:fset (f2cl-lib:fref yr (i) ((1 n))) zeror)
-          (f2cl-lib:fset (f2cl-lib:fref yi (i) ((1 n))) zeroi)
+          (setf (f2cl-lib:fref yr (i) ((1 n))) zeror)
+          (setf (f2cl-lib:fref yi (i) ((1 n))) zeroi)
           (if (< acs (- elim)) (go label25))
           (multiple-value-bind (var-0 var-1 var-2 var-3 var-4)
               (zlog s2r s2i csr csi idum)
@@ -117,8 +117,8 @@
             (declare (ignore var-0 var-1 var-3 var-4))
             (setf nw var-2))
           (if (/= nw 0) (go label25))
-          (f2cl-lib:fset (f2cl-lib:fref yr (i) ((1 n))) csr)
-          (f2cl-lib:fset (f2cl-lib:fref yi (i) ((1 n))) csi)
+          (setf (f2cl-lib:fref yr (i) ((1 n))) csr)
+          (setf (f2cl-lib:fref yi (i) ((1 n))) csi)
           (setf nz (f2cl-lib:int-sub nz 1))
           (if (= ic (f2cl-lib:int-sub kk 1)) (go label40))
           (setf ic kk)
@@ -140,10 +140,27 @@
       (f2cl-lib:fdo (i 1 (f2cl-lib:int-add i 1))
                     ((> i nz) nil)
         (tagbody
-          (f2cl-lib:fset (f2cl-lib:fref yr (i) ((1 n))) zeror)
-          (f2cl-lib:fset (f2cl-lib:fref yi (i) ((1 n))) zeroi)
+          (setf (f2cl-lib:fref yr (i) ((1 n))) zeror)
+          (setf (f2cl-lib:fref yi (i) ((1 n))) zeroi)
          label50))
       (go end_label)
      end_label
       (return (values nil nil nil nil nil nil nz nil nil nil nil nil)))))
 
+(in-package #-gcl #:cl-user #+gcl "CL-USER")
+#+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
+(eval-when (:load-toplevel :compile-toplevel :execute)
+  (setf (gethash 'fortran-to-lisp::zkscl fortran-to-lisp::*f2cl-function-info*)
+          (fortran-to-lisp::make-f2cl-finfo
+           :arg-types '((double-float) (double-float) (double-float)
+                        (fortran-to-lisp::integer4)
+                        (simple-array double-float (*))
+                        (simple-array double-float (*))
+                        (fortran-to-lisp::integer4) (double-float)
+                        (double-float) (double-float) (double-float)
+                        (double-float))
+           :return-values '(nil nil nil nil nil nil fortran-to-lisp::nz nil nil
+                            nil nil nil)
+           :calls '(fortran-to-lisp::zuchk fortran-to-lisp::zlog
+                    fortran-to-lisp::zabs))))
+
