@@ -1,5 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
-;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:18:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-12 (19D)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
@@ -10,11 +10,11 @@
 
 
 (let ((zeror 0.0) (zeroi 0.0) (coner 1.0) (pi$ 3.141592653589793))
-  (declare (type double-float pi$ coner zeroi zeror))
+  (declare (type (double-float) pi$ coner zeroi zeror))
   (defun zunk1 (zr zi fnu kode mr n yr yi nz tol elim alim)
     (declare (type (array double-float (*)) yi yr)
-             (type f2cl-lib:integer4 nz n mr kode)
-             (type double-float alim elim tol fnu zi zr))
+             (type (f2cl-lib:integer4) nz n mr kode)
+             (type (double-float) alim elim tol fnu zi zr))
     (f2cl-lib:with-multi-array-data
         ((yr double-float yr-%data% yr-%offset%)
          (yi double-float yi-%data% yi-%offset%))
@@ -42,36 +42,34 @@
              (fnf 0.0) (phidi 0.0) (phidr 0.0) (rast 0.0) (razr 0.0) (rs1 0.0)
              (rzi 0.0) (rzr 0.0) (sgn 0.0) (sti 0.0) (str 0.0) (sumdi 0.0)
              (sumdr 0.0) (s1i 0.0) (s1r 0.0) (s2i 0.0) (s2r 0.0) (zet1di 0.0)
-             (zet1dr 0.0) (zet2di 0.0) (zet2dr 0.0) (zri 0.0) (zrr 0.0)
-             (abs$ 0.0f0))
-        (declare (type single-float abs$)
-                 (type (array double-float (2)) zeta2r zeta2i zeta1r zeta1i
+             (zet1dr 0.0) (zet2di 0.0) (zet2dr 0.0) (zri 0.0) (zrr 0.0))
+        (declare (type (array double-float (2)) zeta2r zeta2i zeta1r zeta1i
                                                 sumr sumi phir phii cyr cyi)
                  (type (array double-float (48)) cwrkr cwrki)
                  (type (array double-float (3)) cssr csrr bry)
-                 (type double-float zrr zri zet2dr zet2di zet1dr zet1di s2r s2i
-                                    s1r s1i sumdr sumdi str sti sgn rzr rzi rs1
-                                    razr rast phidr phidi fnf fn fmr c2r c2m
-                                    c2i c1r c1i csr cspnr cspni csgni cscl crsc
-                                    ckr cki ascle asc aphi ang)
+                 (type (double-float) zrr zri zet2dr zet2di zet1dr zet1di s2r
+                                      s2i s1r s1i sumdr sumdi str sti sgn rzr
+                                      rzi rs1 razr rast phidr phidi fnf fn fmr
+                                      c2r c2m c2i c1r c1i csr cspnr cspni csgni
+                                      cscl crsc ckr cki ascle asc aphi ang)
                  (type (array f2cl-lib:integer4 (2)) init)
-                 (type f2cl-lib:integer4 m j ipard ic initd nw kk kflag kdflg k
-                                         iuf inu il ifn iflag ib i))
+                 (type (f2cl-lib:integer4) m j ipard ic initd nw kk kflag kdflg
+                                           k iuf inu il ifn iflag ib i))
         (setf kdflg 1)
         (setf nz 0)
         (setf cscl (/ 1.0 tol))
         (setf crsc tol)
-        (f2cl-lib:fset (f2cl-lib:fref cssr (1) ((1 3))) cscl)
-        (f2cl-lib:fset (f2cl-lib:fref cssr (2) ((1 3))) coner)
-        (f2cl-lib:fset (f2cl-lib:fref cssr (3) ((1 3))) crsc)
-        (f2cl-lib:fset (f2cl-lib:fref csrr (1) ((1 3))) crsc)
-        (f2cl-lib:fset (f2cl-lib:fref csrr (2) ((1 3))) coner)
-        (f2cl-lib:fset (f2cl-lib:fref csrr (3) ((1 3))) cscl)
-        (f2cl-lib:fset (f2cl-lib:fref bry (1) ((1 3)))
-                       (/ (* 1000.0 (f2cl-lib:d1mach 1)) tol))
-        (f2cl-lib:fset (f2cl-lib:fref bry (2) ((1 3)))
-                       (/ 1.0 (f2cl-lib:fref bry (1) ((1 3)))))
-        (f2cl-lib:fset (f2cl-lib:fref bry (3) ((1 3))) (f2cl-lib:d1mach 2))
+        (setf (f2cl-lib:fref cssr (1) ((1 3))) cscl)
+        (setf (f2cl-lib:fref cssr (2) ((1 3))) coner)
+        (setf (f2cl-lib:fref cssr (3) ((1 3))) crsc)
+        (setf (f2cl-lib:fref csrr (1) ((1 3))) crsc)
+        (setf (f2cl-lib:fref csrr (2) ((1 3))) coner)
+        (setf (f2cl-lib:fref csrr (3) ((1 3))) cscl)
+        (setf (f2cl-lib:fref bry (1) ((1 3)))
+                (/ (* 1000.0 (f2cl-lib:d1mach 1)) tol))
+        (setf (f2cl-lib:fref bry (2) ((1 3)))
+                (/ 1.0 (f2cl-lib:fref bry (1) ((1 3)))))
+        (setf (f2cl-lib:fref bry (3) ((1 3))) (f2cl-lib:d1mach 2))
         (setf zrr zr)
         (setf zri zi)
         (if (>= zr 0.0) (go label10))
@@ -84,7 +82,7 @@
           (tagbody
             (setf j (f2cl-lib:int-sub 3 j))
             (setf fn (+ fnu (f2cl-lib:int-sub i 1)))
-            (f2cl-lib:fset (f2cl-lib:fref init (j) ((1 2))) 0)
+            (setf (f2cl-lib:fref init (j) ((1 2))) 0)
             (multiple-value-bind
                   (var-0 var-1 var-2 var-3 var-4 var-5 var-6 var-7 var-8 var-9
                    var-10 var-11 var-12 var-13 var-14 var-15 var-16)
@@ -104,19 +102,19 @@
                                        ((1 16) (1 3))))
               (declare (ignore var-0 var-1 var-2 var-3 var-4 var-5 var-15
                                var-16))
-              (f2cl-lib:fset (f2cl-lib:fref init (j) ((1 2))) var-6)
-              (f2cl-lib:fset (f2cl-lib:fref phir (j) ((1 2))) var-7)
-              (f2cl-lib:fset (f2cl-lib:fref phii (j) ((1 2))) var-8)
-              (f2cl-lib:fset (f2cl-lib:fref zeta1r (j) ((1 2))) var-9)
-              (f2cl-lib:fset (f2cl-lib:fref zeta1i (j) ((1 2))) var-10)
-              (f2cl-lib:fset (f2cl-lib:fref zeta2r (j) ((1 2))) var-11)
-              (f2cl-lib:fset (f2cl-lib:fref zeta2i (j) ((1 2))) var-12)
-              (f2cl-lib:fset (f2cl-lib:fref sumr (j) ((1 2))) var-13)
-              (f2cl-lib:fset (f2cl-lib:fref sumi (j) ((1 2))) var-14))
+              (setf (f2cl-lib:fref init (j) ((1 2))) var-6)
+              (setf (f2cl-lib:fref phir (j) ((1 2))) var-7)
+              (setf (f2cl-lib:fref phii (j) ((1 2))) var-8)
+              (setf (f2cl-lib:fref zeta1r (j) ((1 2))) var-9)
+              (setf (f2cl-lib:fref zeta1i (j) ((1 2))) var-10)
+              (setf (f2cl-lib:fref zeta2r (j) ((1 2))) var-11)
+              (setf (f2cl-lib:fref zeta2i (j) ((1 2))) var-12)
+              (setf (f2cl-lib:fref sumr (j) ((1 2))) var-13)
+              (setf (f2cl-lib:fref sumi (j) ((1 2))) var-14))
             (if (= kode 1) (go label20))
             (setf str (+ zrr (f2cl-lib:fref zeta2r (j) ((1 2)))))
             (setf sti (+ zri (f2cl-lib:fref zeta2i (j) ((1 2)))))
-            (setf rast (/ fn (zabs str sti)))
+            (setf rast (coerce (realpart (/ fn (zabs str sti))) 'double-float))
             (setf str (* str rast rast))
             (setf sti (* (- sti) rast rast))
             (setf s1r (- (f2cl-lib:fref zeta1r (j) ((1 2))) str))
@@ -135,8 +133,11 @@
             (if (= kdflg 1) (setf kflag 2))
             (if (< (abs rs1) alim) (go label40))
             (setf aphi
-                    (zabs (f2cl-lib:fref phir (j) ((1 2)))
-                     (f2cl-lib:fref phii (j) ((1 2)))))
+                    (coerce
+                     (realpart
+                      (zabs (f2cl-lib:fref phir (j) ((1 2)))
+                       (f2cl-lib:fref phii (j) ((1 2)))))
+                     'double-float))
             (setf rs1 (+ rs1 (f2cl-lib:flog aphi)))
             (if (> (abs rs1) elim) (go label60))
             (if (= kdflg 1) (setf kflag 1))
@@ -168,12 +169,12 @@
               (setf nw var-2))
             (if (/= nw 0) (go label60))
            label50
-            (f2cl-lib:fset (f2cl-lib:fref cyr (kdflg) ((1 2))) s2r)
-            (f2cl-lib:fset (f2cl-lib:fref cyi (kdflg) ((1 2))) s2i)
-            (f2cl-lib:fset (f2cl-lib:fref yr-%data% (i) ((1 n)) yr-%offset%)
-                           (* s2r (f2cl-lib:fref csrr (kflag) ((1 3)))))
-            (f2cl-lib:fset (f2cl-lib:fref yi-%data% (i) ((1 n)) yi-%offset%)
-                           (* s2i (f2cl-lib:fref csrr (kflag) ((1 3)))))
+            (setf (f2cl-lib:fref cyr (kdflg) ((1 2))) s2r)
+            (setf (f2cl-lib:fref cyi (kdflg) ((1 2))) s2i)
+            (setf (f2cl-lib:fref yr-%data% (i) ((1 n)) yr-%offset%)
+                    (* s2r (f2cl-lib:fref csrr (kflag) ((1 3)))))
+            (setf (f2cl-lib:fref yi-%data% (i) ((1 n)) yi-%offset%)
+                    (* s2i (f2cl-lib:fref csrr (kflag) ((1 3)))))
             (if (= kdflg 2) (go label75))
             (setf kdflg 2)
             (go label70)
@@ -181,10 +182,8 @@
             (if (> rs1 0.0) (go label300))
             (if (< zr 0.0) (go label300))
             (setf kdflg 1)
-            (f2cl-lib:fset (f2cl-lib:fref yr-%data% (i) ((1 n)) yr-%offset%)
-                           zeror)
-            (f2cl-lib:fset (f2cl-lib:fref yi-%data% (i) ((1 n)) yi-%offset%)
-                           zeroi)
+            (setf (f2cl-lib:fref yr-%data% (i) ((1 n)) yr-%offset%) zeror)
+            (setf (f2cl-lib:fref yi-%data% (i) ((1 n)) yi-%offset%) zeroi)
             (setf nz (f2cl-lib:int-add nz 1))
             (if (= i 1) (go label70))
             (if
@@ -202,23 +201,21 @@
                               yi-%offset%)
                zeroi))
              (go label70))
-            (f2cl-lib:fset
-             (f2cl-lib:fref yr-%data%
-                            ((f2cl-lib:int-sub i 1))
-                            ((1 n))
-                            yr-%offset%)
-             zeror)
-            (f2cl-lib:fset
-             (f2cl-lib:fref yi-%data%
-                            ((f2cl-lib:int-sub i 1))
-                            ((1 n))
-                            yi-%offset%)
-             zeroi)
+            (setf (f2cl-lib:fref yr-%data%
+                                 ((f2cl-lib:int-sub i 1))
+                                 ((1 n))
+                                 yr-%offset%)
+                    zeror)
+            (setf (f2cl-lib:fref yi-%data%
+                                 ((f2cl-lib:int-sub i 1))
+                                 ((1 n))
+                                 yi-%offset%)
+                    zeroi)
             (setf nz (f2cl-lib:int-add nz 1))
            label70))
         (setf i n)
        label75
-        (setf razr (/ 1.0 (zabs zrr zri)))
+        (setf razr (coerce (realpart (/ 1.0 (zabs zrr zri))) 'double-float))
         (setf str (* zrr razr))
         (setf sti (* (- zri) razr))
         (setf rzr (* (+ str str) razr))
@@ -251,7 +248,7 @@
         (if (= kode 1) (go label80))
         (setf str (+ zrr zet2dr))
         (setf sti (+ zri zet2di))
-        (setf rast (/ fn (zabs str sti)))
+        (setf rast (coerce (realpart (/ fn (zabs str sti))) 'double-float))
         (setf str (* str rast rast))
         (setf sti (* (- sti) rast rast))
         (setf s1r (- zet1dr str))
@@ -264,7 +261,7 @@
         (setf rs1 s1r)
         (if (> (abs rs1) elim) (go label95))
         (if (< (abs rs1) alim) (go label100))
-        (setf aphi (zabs phidr phidi))
+        (setf aphi (coerce (realpart (zabs phidr phidi)) 'double-float))
         (setf rs1 (+ rs1 (f2cl-lib:flog aphi)))
         (if (< (abs rs1) elim) (go label100))
        label95
@@ -274,10 +271,8 @@
         (f2cl-lib:fdo (i 1 (f2cl-lib:int-add i 1))
                       ((> i n) nil)
           (tagbody
-            (f2cl-lib:fset (f2cl-lib:fref yr-%data% (i) ((1 n)) yr-%offset%)
-                           zeror)
-            (f2cl-lib:fset (f2cl-lib:fref yi-%data% (i) ((1 n)) yi-%offset%)
-                           zeroi)
+            (setf (f2cl-lib:fref yr-%data% (i) ((1 n)) yr-%offset%) zeror)
+            (setf (f2cl-lib:fref yi-%data% (i) ((1 n)) yi-%offset%) zeroi)
            label96))
         (go end_label)
        label100
@@ -300,13 +295,11 @@
             (setf cki (+ cki rzi))
             (setf c2r (* s2r c1r))
             (setf c2i (* s2i c1r))
-            (f2cl-lib:fset (f2cl-lib:fref yr-%data% (i) ((1 n)) yr-%offset%)
-                           c2r)
-            (f2cl-lib:fset (f2cl-lib:fref yi-%data% (i) ((1 n)) yi-%offset%)
-                           c2i)
+            (setf (f2cl-lib:fref yr-%data% (i) ((1 n)) yr-%offset%) c2r)
+            (setf (f2cl-lib:fref yi-%data% (i) ((1 n)) yi-%offset%) c2i)
             (if (>= kflag 3) (go label120))
-            (setf str (coerce (abs c2r) 'double-float))
-            (setf sti (coerce (abs c2i) 'double-float))
+            (setf str (abs c2r))
+            (setf sti (abs c2i))
             (setf c2m (max str sti))
             (if (<= c2m ascle) (go label120))
             (setf kflag (f2cl-lib:int-add kflag 1))
@@ -391,7 +384,7 @@
             (if (= kode 1) (go label200))
             (setf str (+ zrr zet2dr))
             (setf sti (+ zri zet2di))
-            (setf rast (/ fn (zabs str sti)))
+            (setf rast (coerce (realpart (/ fn (zabs str sti))) 'double-float))
             (setf str (* str rast rast))
             (setf sti (* (- sti) rast rast))
             (setf s1r (- str zet1dr))
@@ -405,7 +398,7 @@
             (if (> (abs rs1) elim) (go label260))
             (if (= kdflg 1) (setf iflag 2))
             (if (< (abs rs1) alim) (go label220))
-            (setf aphi (zabs phidr phidi))
+            (setf aphi (coerce (realpart (zabs phidr phidi)) 'double-float))
             (setf rs1 (+ rs1 (f2cl-lib:flog aphi)))
             (if (> (abs rs1) elim) (go label260))
             (if (= kdflg 1) (setf iflag 1))
@@ -431,8 +424,8 @@
             (setf s2r zeror)
             (setf s2i zeroi)
            label230
-            (f2cl-lib:fset (f2cl-lib:fref cyr (kdflg) ((1 2))) s2r)
-            (f2cl-lib:fset (f2cl-lib:fref cyi (kdflg) ((1 2))) s2i)
+            (setf (f2cl-lib:fref cyr (kdflg) ((1 2))) s2r)
+            (setf (f2cl-lib:fref cyi (kdflg) ((1 2))) s2i)
             (setf c2r s2r)
             (setf c2i s2i)
             (setf s2r (* s2r (f2cl-lib:fref csrr (iflag) ((1 3)))))
@@ -452,10 +445,10 @@
               (setf iuf var-9))
             (setf nz (f2cl-lib:int-add nz nw))
            label250
-            (f2cl-lib:fset (f2cl-lib:fref yr-%data% (kk) ((1 n)) yr-%offset%)
-                           (+ (- (* s1r cspnr) (* s1i cspni)) s2r))
-            (f2cl-lib:fset (f2cl-lib:fref yi-%data% (kk) ((1 n)) yi-%offset%)
-                           (+ (* cspnr s1i) (* cspni s1r) s2i))
+            (setf (f2cl-lib:fref yr-%data% (kk) ((1 n)) yr-%offset%)
+                    (+ (- (* s1r cspnr) (* s1i cspni)) s2r))
+            (setf (f2cl-lib:fref yi-%data% (kk) ((1 n)) yi-%offset%)
+                    (+ (* cspnr s1i) (* cspni s1r) s2i))
             (setf kk (f2cl-lib:int-sub kk 1))
             (setf cspnr (- cspnr))
             (setf cspni (- cspni))
@@ -514,16 +507,16 @@
               (setf iuf var-9))
             (setf nz (f2cl-lib:int-add nz nw))
            label280
-            (f2cl-lib:fset (f2cl-lib:fref yr-%data% (kk) ((1 n)) yr-%offset%)
-                           (+ (- (* c1r cspnr) (* c1i cspni)) c2r))
-            (f2cl-lib:fset (f2cl-lib:fref yi-%data% (kk) ((1 n)) yi-%offset%)
-                           (+ (* c1r cspni) (* c1i cspnr) c2i))
+            (setf (f2cl-lib:fref yr-%data% (kk) ((1 n)) yr-%offset%)
+                    (+ (- (* c1r cspnr) (* c1i cspni)) c2r))
+            (setf (f2cl-lib:fref yi-%data% (kk) ((1 n)) yi-%offset%)
+                    (+ (* c1r cspni) (* c1i cspnr) c2i))
             (setf kk (f2cl-lib:int-sub kk 1))
             (setf cspnr (- cspnr))
             (setf cspni (- cspni))
             (if (>= iflag 3) (go label290))
-            (setf c2r (coerce (abs ckr) 'double-float))
-            (setf c2i (coerce (abs cki) 'double-float))
+            (setf c2r (abs ckr))
+            (setf c2i (abs cki))
             (setf c2m (max c2r c2i))
             (if (<= c2m ascle) (go label290))
             (setf iflag (f2cl-lib:int-add iflag 1))
@@ -545,3 +538,19 @@
        end_label
         (return (values nil nil nil nil nil nil nil nil nz nil nil nil))))))
 
+(in-package #-gcl #:cl-user #+gcl "CL-USER")
+#+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
+(eval-when (:load-toplevel :compile-toplevel :execute)
+  (setf (gethash 'fortran-to-lisp::zunk1 fortran-to-lisp::*f2cl-function-info*)
+          (fortran-to-lisp::make-f2cl-finfo
+           :arg-types '((double-float) (double-float) (double-float)
+                        (fortran-to-lisp::integer4) (fortran-to-lisp::integer4)
+                        (fortran-to-lisp::integer4) (array double-float (*))
+                        (array double-float (*)) (fortran-to-lisp::integer4)
+                        (double-float) (double-float) (double-float))
+           :return-values '(nil nil nil nil nil nil nil nil fortran-to-lisp::nz
+                            nil nil nil)
+           :calls '(fortran-to-lisp::zs1s2 fortran-to-lisp::zuchk
+                    fortran-to-lisp::zabs fortran-to-lisp::zunik
+                    fortran-to-lisp::d1mach))))
+
