@@ -1,5 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
-;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:18:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-12 (19D)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
@@ -28,12 +28,12 @@
                    :element-type 'double-float
                    :initial-contents '(0.0 -1.0 0.0 1.0))))
   (declare (type (simple-array double-float (4)) cipi cipr)
-           (type double-float aic pi$ hpi cr2i cr2r cr1i cr1r coner zeroi
-                              zeror))
+           (type (double-float) aic pi$ hpi cr2i cr2r cr1i cr1r coner zeroi
+                                zeror))
   (defun zunk2 (zr zi fnu kode mr n yr yi nz tol elim alim)
     (declare (type (simple-array double-float (*)) yi yr)
-             (type f2cl-lib:integer4 nz n mr kode)
-             (type double-float alim elim tol fnu zi zr))
+             (type (f2cl-lib:integer4) nz n mr kode)
+             (type (double-float) alim elim tol fnu zi zr))
     (prog ((bry (make-array 3 :element-type 'double-float))
            (asumr (make-array 2 :element-type 'double-float))
            (asumi (make-array 2 :element-type 'double-float))
@@ -63,37 +63,36 @@
            (rs1 0.0) (rzi 0.0) (rzr 0.0) (sar 0.0) (sgn 0.0) (sti 0.0)
            (str 0.0) (s1i 0.0) (s1r 0.0) (s2i 0.0) (s2r 0.0) (yy 0.0) (zbi 0.0)
            (zbr 0.0) (zet1di 0.0) (zet1dr 0.0) (zet2di 0.0) (zet2dr 0.0)
-           (zni 0.0) (znr 0.0) (zri 0.0) (zrr 0.0) (abs$ 0.0f0))
-      (declare (type single-float abs$)
-               (type (simple-array double-float (3)) cssr csrr bry)
+           (zni 0.0) (znr 0.0) (zri 0.0) (zrr 0.0))
+      (declare (type (simple-array double-float (3)) cssr csrr bry)
                (type (simple-array double-float (2)) zeta2r zeta2i zeta1r
                                                      zeta1i phir phii cyr cyi
                                                      bsumr bsumi asumr asumi
                                                      argr argi)
-               (type double-float zrr zri znr zni zet2dr zet2di zet1dr zet1di
-                                  zbr zbi yy s2r s2i s1r s1i str sti sgn sar
-                                  rzr rzi rs1 razr rast ptr pti phidr phidi fnf
-                                  fn fmr dair daii c2r c2m c2i c1r c1i csr
-                                  cspnr cspni csi csgni cscl crsc ckr cki car$
-                                  bsumdr bsumdi asumdr asumdi ascle asc argdr
-                                  argdi aphi ang air aii aarg)
-               (type f2cl-lib:integer4 ic ipard j idum nw ndai nai kk kflag
-                                       kdflg k iuf inu in il ifn iflag ib i))
+               (type (double-float) zrr zri znr zni zet2dr zet2di zet1dr zet1di
+                                    zbr zbi yy s2r s2i s1r s1i str sti sgn sar
+                                    rzr rzi rs1 razr rast ptr pti phidr phidi
+                                    fnf fn fmr dair daii c2r c2m c2i c1r c1i
+                                    csr cspnr cspni csi csgni cscl crsc ckr cki
+                                    car$ bsumdr bsumdi asumdr asumdi ascle asc
+                                    argdr argdi aphi ang air aii aarg)
+               (type (f2cl-lib:integer4) ic ipard j idum nw ndai nai kk kflag
+                                         kdflg k iuf inu in il ifn iflag ib i))
       (setf kdflg 1)
       (setf nz 0)
       (setf cscl (/ 1.0 tol))
       (setf crsc tol)
-      (f2cl-lib:fset (f2cl-lib:fref cssr (1) ((1 3))) cscl)
-      (f2cl-lib:fset (f2cl-lib:fref cssr (2) ((1 3))) coner)
-      (f2cl-lib:fset (f2cl-lib:fref cssr (3) ((1 3))) crsc)
-      (f2cl-lib:fset (f2cl-lib:fref csrr (1) ((1 3))) crsc)
-      (f2cl-lib:fset (f2cl-lib:fref csrr (2) ((1 3))) coner)
-      (f2cl-lib:fset (f2cl-lib:fref csrr (3) ((1 3))) cscl)
-      (f2cl-lib:fset (f2cl-lib:fref bry (1) ((1 3)))
-                     (/ (* 1000.0 (f2cl-lib:d1mach 1)) tol))
-      (f2cl-lib:fset (f2cl-lib:fref bry (2) ((1 3)))
-                     (/ 1.0 (f2cl-lib:fref bry (1) ((1 3)))))
-      (f2cl-lib:fset (f2cl-lib:fref bry (3) ((1 3))) (f2cl-lib:d1mach 2))
+      (setf (f2cl-lib:fref cssr (1) ((1 3))) cscl)
+      (setf (f2cl-lib:fref cssr (2) ((1 3))) coner)
+      (setf (f2cl-lib:fref cssr (3) ((1 3))) crsc)
+      (setf (f2cl-lib:fref csrr (1) ((1 3))) crsc)
+      (setf (f2cl-lib:fref csrr (2) ((1 3))) coner)
+      (setf (f2cl-lib:fref csrr (3) ((1 3))) cscl)
+      (setf (f2cl-lib:fref bry (1) ((1 3)))
+              (/ (* 1000.0 (f2cl-lib:d1mach 1)) tol))
+      (setf (f2cl-lib:fref bry (2) ((1 3)))
+              (/ 1.0 (f2cl-lib:fref bry (1) ((1 3)))))
+      (setf (f2cl-lib:fref bry (3) ((1 3))) (f2cl-lib:d1mach 2))
       (setf zrr zr)
       (setf zri zi)
       (if (>= zr 0.0) (go label10))
@@ -147,22 +146,22 @@
                (f2cl-lib:fref bsumr (j) ((1 2)))
                (f2cl-lib:fref bsumi (j) ((1 2))))
             (declare (ignore var-0 var-1 var-2 var-3 var-4))
-            (f2cl-lib:fset (f2cl-lib:fref phir (j) ((1 2))) var-5)
-            (f2cl-lib:fset (f2cl-lib:fref phii (j) ((1 2))) var-6)
-            (f2cl-lib:fset (f2cl-lib:fref argr (j) ((1 2))) var-7)
-            (f2cl-lib:fset (f2cl-lib:fref argi (j) ((1 2))) var-8)
-            (f2cl-lib:fset (f2cl-lib:fref zeta1r (j) ((1 2))) var-9)
-            (f2cl-lib:fset (f2cl-lib:fref zeta1i (j) ((1 2))) var-10)
-            (f2cl-lib:fset (f2cl-lib:fref zeta2r (j) ((1 2))) var-11)
-            (f2cl-lib:fset (f2cl-lib:fref zeta2i (j) ((1 2))) var-12)
-            (f2cl-lib:fset (f2cl-lib:fref asumr (j) ((1 2))) var-13)
-            (f2cl-lib:fset (f2cl-lib:fref asumi (j) ((1 2))) var-14)
-            (f2cl-lib:fset (f2cl-lib:fref bsumr (j) ((1 2))) var-15)
-            (f2cl-lib:fset (f2cl-lib:fref bsumi (j) ((1 2))) var-16))
+            (setf (f2cl-lib:fref phir (j) ((1 2))) var-5)
+            (setf (f2cl-lib:fref phii (j) ((1 2))) var-6)
+            (setf (f2cl-lib:fref argr (j) ((1 2))) var-7)
+            (setf (f2cl-lib:fref argi (j) ((1 2))) var-8)
+            (setf (f2cl-lib:fref zeta1r (j) ((1 2))) var-9)
+            (setf (f2cl-lib:fref zeta1i (j) ((1 2))) var-10)
+            (setf (f2cl-lib:fref zeta2r (j) ((1 2))) var-11)
+            (setf (f2cl-lib:fref zeta2i (j) ((1 2))) var-12)
+            (setf (f2cl-lib:fref asumr (j) ((1 2))) var-13)
+            (setf (f2cl-lib:fref asumi (j) ((1 2))) var-14)
+            (setf (f2cl-lib:fref bsumr (j) ((1 2))) var-15)
+            (setf (f2cl-lib:fref bsumi (j) ((1 2))) var-16))
           (if (= kode 1) (go label30))
           (setf str (+ zbr (f2cl-lib:fref zeta2r (j) ((1 2)))))
           (setf sti (+ zbi (f2cl-lib:fref zeta2i (j) ((1 2)))))
-          (setf rast (/ fn (zabs str sti)))
+          (setf rast (coerce (realpart (/ fn (zabs str sti))) 'double-float))
           (setf str (* str rast rast))
           (setf sti (* (- sti) rast rast))
           (setf s1r (- (f2cl-lib:fref zeta1r (j) ((1 2))) str))
@@ -181,11 +180,17 @@
           (if (= kdflg 1) (setf kflag 2))
           (if (< (abs rs1) alim) (go label50))
           (setf aphi
-                  (zabs (f2cl-lib:fref phir (j) ((1 2)))
-                   (f2cl-lib:fref phii (j) ((1 2)))))
+                  (coerce
+                   (realpart
+                    (zabs (f2cl-lib:fref phir (j) ((1 2)))
+                     (f2cl-lib:fref phii (j) ((1 2)))))
+                   'double-float))
           (setf aarg
-                  (zabs (f2cl-lib:fref argr (j) ((1 2)))
-                   (f2cl-lib:fref argi (j) ((1 2)))))
+                  (coerce
+                   (realpart
+                    (zabs (f2cl-lib:fref argr (j) ((1 2)))
+                     (f2cl-lib:fref argi (j) ((1 2)))))
+                   'double-float))
           (setf rs1
                   (- (+ rs1 (f2cl-lib:flog aphi))
                      (* 0.25 (f2cl-lib:flog aarg))
@@ -255,12 +260,12 @@
           (if (/= nw 0) (go label70))
          label60
           (if (<= yy 0.0) (setf s2i (- s2i)))
-          (f2cl-lib:fset (f2cl-lib:fref cyr (kdflg) ((1 2))) s2r)
-          (f2cl-lib:fset (f2cl-lib:fref cyi (kdflg) ((1 2))) s2i)
-          (f2cl-lib:fset (f2cl-lib:fref yr (i) ((1 n)))
-                         (* s2r (f2cl-lib:fref csrr (kflag) ((1 3)))))
-          (f2cl-lib:fset (f2cl-lib:fref yi (i) ((1 n)))
-                         (* s2i (f2cl-lib:fref csrr (kflag) ((1 3)))))
+          (setf (f2cl-lib:fref cyr (kdflg) ((1 2))) s2r)
+          (setf (f2cl-lib:fref cyi (kdflg) ((1 2))) s2i)
+          (setf (f2cl-lib:fref yr (i) ((1 n)))
+                  (* s2r (f2cl-lib:fref csrr (kflag) ((1 3)))))
+          (setf (f2cl-lib:fref yi (i) ((1 n)))
+                  (* s2i (f2cl-lib:fref csrr (kflag) ((1 3)))))
           (setf str csi)
           (setf csi (- csr))
           (setf csr str)
@@ -271,8 +276,8 @@
           (if (> rs1 0.0) (go label320))
           (if (< zr 0.0) (go label320))
           (setf kdflg 1)
-          (f2cl-lib:fset (f2cl-lib:fref yr (i) ((1 n))) zeror)
-          (f2cl-lib:fset (f2cl-lib:fref yi (i) ((1 n))) zeroi)
+          (setf (f2cl-lib:fref yr (i) ((1 n))) zeror)
+          (setf (f2cl-lib:fref yi (i) ((1 n))) zeroi)
           (setf nz (f2cl-lib:int-add nz 1))
           (setf str csi)
           (setf csi (- csr))
@@ -282,15 +287,13 @@
            (and (= (f2cl-lib:fref yr ((f2cl-lib:int-sub i 1)) ((1 n))) zeror)
                 (= (f2cl-lib:fref yi ((f2cl-lib:int-sub i 1)) ((1 n))) zeroi))
            (go label80))
-          (f2cl-lib:fset (f2cl-lib:fref yr ((f2cl-lib:int-sub i 1)) ((1 n)))
-                         zeror)
-          (f2cl-lib:fset (f2cl-lib:fref yi ((f2cl-lib:int-sub i 1)) ((1 n)))
-                         zeroi)
+          (setf (f2cl-lib:fref yr ((f2cl-lib:int-sub i 1)) ((1 n))) zeror)
+          (setf (f2cl-lib:fref yi ((f2cl-lib:int-sub i 1)) ((1 n))) zeroi)
           (setf nz (f2cl-lib:int-add nz 1))
          label80))
       (setf i n)
      label85
-      (setf razr (/ 1.0 (zabs zrr zri)))
+      (setf razr (coerce (realpart (/ 1.0 (zabs zrr zri))) 'double-float))
       (setf str (* zrr razr))
       (setf sti (* (- zri) razr))
       (setf rzr (* (+ str str) razr))
@@ -323,7 +326,7 @@
       (if (= kode 1) (go label90))
       (setf str (+ zbr zet2dr))
       (setf sti (+ zbi zet2di))
-      (setf rast (/ fn (zabs str sti)))
+      (setf rast (coerce (realpart (/ fn (zabs str sti))) 'double-float))
       (setf str (* str rast rast))
       (setf sti (* (- sti) rast rast))
       (setf s1r (- zet1dr str))
@@ -336,7 +339,7 @@
       (setf rs1 s1r)
       (if (> (abs rs1) elim) (go label105))
       (if (< (abs rs1) alim) (go label120))
-      (setf aphi (zabs phidr phidi))
+      (setf aphi (coerce (realpart (zabs phidr phidi)) 'double-float))
       (setf rs1 (+ rs1 (f2cl-lib:flog aphi)))
       (if (< (abs rs1) elim) (go label120))
      label105
@@ -346,8 +349,8 @@
       (f2cl-lib:fdo (i 1 (f2cl-lib:int-add i 1))
                     ((> i n) nil)
         (tagbody
-          (f2cl-lib:fset (f2cl-lib:fref yr (i) ((1 n))) zeror)
-          (f2cl-lib:fset (f2cl-lib:fref yi (i) ((1 n))) zeroi)
+          (setf (f2cl-lib:fref yr (i) ((1 n))) zeror)
+          (setf (f2cl-lib:fref yi (i) ((1 n))) zeroi)
          label106))
       (go end_label)
      label120
@@ -370,11 +373,11 @@
           (setf cki (+ cki rzi))
           (setf c2r (* s2r c1r))
           (setf c2i (* s2i c1r))
-          (f2cl-lib:fset (f2cl-lib:fref yr (i) ((1 n))) c2r)
-          (f2cl-lib:fset (f2cl-lib:fref yi (i) ((1 n))) c2i)
+          (setf (f2cl-lib:fref yr (i) ((1 n))) c2r)
+          (setf (f2cl-lib:fref yi (i) ((1 n))) c2i)
           (if (>= kflag 3) (go label130))
-          (setf str (coerce (abs c2r) 'double-float))
-          (setf sti (coerce (abs c2i) 'double-float))
+          (setf str (abs c2r))
+          (setf sti (abs c2i))
           (setf c2m (max str sti))
           (if (<= c2m ascle) (go label130))
           (setf kflag (f2cl-lib:int-add kflag 1))
@@ -463,7 +466,7 @@
           (if (= kode 1) (go label220))
           (setf str (+ zbr zet2dr))
           (setf sti (+ zbi zet2di))
-          (setf rast (/ fn (zabs str sti)))
+          (setf rast (coerce (realpart (/ fn (zabs str sti))) 'double-float))
           (setf str (* str rast rast))
           (setf sti (* (- sti) rast rast))
           (setf s1r (- str zet1dr))
@@ -477,8 +480,8 @@
           (if (> (abs rs1) elim) (go label280))
           (if (= kdflg 1) (setf iflag 2))
           (if (< (abs rs1) alim) (go label240))
-          (setf aphi (zabs phidr phidi))
-          (setf aarg (zabs argdr argdi))
+          (setf aphi (coerce (realpart (zabs phidr phidi)) 'double-float))
+          (setf aarg (coerce (realpart (zabs argdr argdi)) 'double-float))
           (setf rs1
                   (- (+ rs1 (f2cl-lib:flog aphi))
                      (* 0.25 (f2cl-lib:flog aarg))
@@ -528,8 +531,8 @@
           (setf s2i zeroi)
          label250
           (if (<= yy 0.0) (setf s2i (- s2i)))
-          (f2cl-lib:fset (f2cl-lib:fref cyr (kdflg) ((1 2))) s2r)
-          (f2cl-lib:fset (f2cl-lib:fref cyi (kdflg) ((1 2))) s2i)
+          (setf (f2cl-lib:fref cyr (kdflg) ((1 2))) s2r)
+          (setf (f2cl-lib:fref cyi (kdflg) ((1 2))) s2i)
           (setf c2r s2r)
           (setf c2i s2i)
           (setf s2r (* s2r (f2cl-lib:fref csrr (iflag) ((1 3)))))
@@ -549,10 +552,10 @@
             (setf iuf var-9))
           (setf nz (f2cl-lib:int-add nz nw))
          label270
-          (f2cl-lib:fset (f2cl-lib:fref yr (kk) ((1 n)))
-                         (+ (- (* s1r cspnr) (* s1i cspni)) s2r))
-          (f2cl-lib:fset (f2cl-lib:fref yi (kk) ((1 n)))
-                         (+ (* s1r cspni) (* s1i cspnr) s2i))
+          (setf (f2cl-lib:fref yr (kk) ((1 n)))
+                  (+ (- (* s1r cspnr) (* s1i cspni)) s2r))
+          (setf (f2cl-lib:fref yi (kk) ((1 n)))
+                  (+ (* s1r cspni) (* s1i cspnr) s2i))
           (setf kk (f2cl-lib:int-sub kk 1))
           (setf cspnr (- cspnr))
           (setf cspni (- cspni))
@@ -614,16 +617,16 @@
             (setf iuf var-9))
           (setf nz (f2cl-lib:int-add nz nw))
          label300
-          (f2cl-lib:fset (f2cl-lib:fref yr (kk) ((1 n)))
-                         (+ (- (* c1r cspnr) (* c1i cspni)) c2r))
-          (f2cl-lib:fset (f2cl-lib:fref yi (kk) ((1 n)))
-                         (+ (* c1r cspni) (* c1i cspnr) c2i))
+          (setf (f2cl-lib:fref yr (kk) ((1 n)))
+                  (+ (- (* c1r cspnr) (* c1i cspni)) c2r))
+          (setf (f2cl-lib:fref yi (kk) ((1 n)))
+                  (+ (* c1r cspni) (* c1i cspnr) c2i))
           (setf kk (f2cl-lib:int-sub kk 1))
           (setf cspnr (- cspnr))
           (setf cspni (- cspni))
           (if (>= iflag 3) (go label310))
-          (setf c2r (coerce (abs ckr) 'double-float))
-          (setf c2i (coerce (abs cki) 'double-float))
+          (setf c2r (abs ckr))
+          (setf c2i (abs cki))
           (setf c2m (max c2r c2i))
           (if (<= c2m ascle) (go label310))
           (setf iflag (f2cl-lib:int-add iflag 1))
@@ -645,3 +648,21 @@
      end_label
       (return (values nil nil nil nil nil nil nil nil nz nil nil nil)))))
 
+(in-package #-gcl #:cl-user #+gcl "CL-USER")
+#+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
+(eval-when (:load-toplevel :compile-toplevel :execute)
+  (setf (gethash 'fortran-to-lisp::zunk2 fortran-to-lisp::*f2cl-function-info*)
+          (fortran-to-lisp::make-f2cl-finfo
+           :arg-types '((double-float) (double-float) (double-float)
+                        (fortran-to-lisp::integer4) (fortran-to-lisp::integer4)
+                        (fortran-to-lisp::integer4)
+                        (simple-array double-float (*))
+                        (simple-array double-float (*))
+                        (fortran-to-lisp::integer4) (double-float)
+                        (double-float) (double-float))
+           :return-values '(nil nil nil nil nil nil nil nil fortran-to-lisp::nz
+                            nil nil nil)
+           :calls '(fortran-to-lisp::zs1s2 fortran-to-lisp::zuchk
+                    fortran-to-lisp::zairy fortran-to-lisp::zabs
+                    fortran-to-lisp::zunhj fortran-to-lisp::d1mach))))
+
