@@ -9,6 +9,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (in-package :maxima)
+
 (macsyma-module trpred)
 (transl-module trpred)
 
@@ -22,10 +23,6 @@
   (let ((wrap-an-is 'maybe-boole-check))
     (cons '$any (translate-predicate (cadr form)))))
 
-(def%tr mnot (form) (cons '$boolean (translate-predicate form)))
-(def-same%tr mand mnot)
-(def-same%tr mor mnot)
-
 ;;; these don't have an imperitive predicate semantics outside of
 ;;; being used in MNOT, MAND, MOR, MCOND, $IS.
 
@@ -39,7 +36,7 @@
 (def-same%tr mlessp    mnotequal)
 (def-same%tr mleqp     mnotequal)
 
-
+
 ;;; It looks like it was copied from MRG;COMPAR > with 
 ;;; TRP- substituted for MEVALP. What a crockish way to dispatch,
 ;;; and in a system with a limited address space too!
@@ -78,7 +75,6 @@
 	 (destructuring-let (((mode . tform) (translate form)))
 	   (boolean-convert mode tform form)))))
 
-
 (defun boolean-convert (mode exp form)
   (if (eq mode '$boolean)
       exp
@@ -92,22 +88,22 @@
 	(t (list 'not form))))
 
 (defun trp-mand (form) 
-  (setq form (mapcar 'translate-predicate (cdr form)))
+  (setq form (mapcar #'translate-predicate (cdr form)))
   (do ((l form (cdr l)) (nl))
       ((null l) (cons 'and (nreverse nl)))
     (cond ((car l) (setq nl (cons (car l) nl)))
 	  (t (return (cons 'and (nreverse (cons nil nl))))))))
 
 (defun trp-mor (form) 
-  (setq form (mapcar 'translate-predicate (cdr form)))
+  (setq form (mapcar #'translate-predicate (cdr form)))
   (do ((l form (cdr l)) (nl))
       ((null l) (cond (nl (cond ((null (cdr nl))(car nl))
 				(t (cons 'or (nreverse nl)))))))
     (cond ((car l) (setq nl (cons (car l) nl))))))
-
 
-(defun wrap-an-is (exp ignore-form) ignore-form
-       (list wrap-an-is exp))
+(defun wrap-an-is (exp ignore-form)
+  (declare (ignore ignore-form))
+  (list wrap-an-is exp))
 
 (defvar *number-types* '($float $number $fixnum ))
 
@@ -116,11 +112,10 @@
     (setq arg1 (translate (cadr form)) arg2 (translate (caddr form))
 	  mode (*union-mode (car arg1) (car arg2)))
     (cond ((or (eq '$fixnum mode) (eq '$float mode)
-	       #+cl
-	       (and (memq (car arg1) *number-types*)
-		    (memq (car arg2) *number-types*)))
+	       (and (member (car arg1) *number-types* :test #'eq)
+		    (member (car arg2) *number-types* :test #'eq)))
 	   `(> ,(dconv arg1 mode) ,(dconv arg2 mode)))
-	  ((eq '$number mode) `(greaterp ,(cdr arg1) ,(cdr arg2)))
+	  ((eq '$number mode) `(> ,(cdr arg1) ,(cdr arg2)))
 	  ('else
 	   (wrap-an-is `(mgrp ,(dconvx arg1) ,(dconvx arg2))
 		       form)))))
@@ -130,11 +125,10 @@
     (setq arg1 (translate (cadr form)) arg2 (translate (caddr form))
 	  mode (*union-mode (car arg1) (car arg2)))
     (cond ((or (eq '$fixnum mode) (eq '$float mode)
-	       #+cl
-	       (and (memq (car arg1) *number-types*)
-		    (memq (car arg2) *number-types*)))
+	       (and (member (car arg1) *number-types* :test #'eq)
+		    (member (car arg2) *number-types* :test #'eq)))
 	   `(< ,(dconv arg1 mode) ,(dconv arg2 mode)))
-	  ((eq '$number mode) `(lessp ,(cdr arg1) ,(cdr arg2)))
+	  ((eq '$number mode) `(< ,(cdr arg1) ,(cdr arg2)))
 	  ('else
 	   (wrap-an-is `(mlsp ,(dconvx arg1) ,(dconvx arg2))
 		       form)))))
@@ -144,7 +138,6 @@
     (setq arg1 (translate (cadr form)) arg2 (translate (caddr form))
 	  mode (*union-mode (car arg1) (car arg2)))
     (cond
-      #+cl
       ((or (eq '$fixnum mode)
 	   (eq '$float mode))
        `(eql ,(dconv arg1 mode) ,(dconv arg2 mode)))
@@ -159,25 +152,23 @@
 	   `(= ,(dconv arg1 mode) ,(dconv arg2 mode)))
 	  ((eq '$number mode) `(meqp ,(cdr arg1) ,(cdr arg2)))
 	  ('else
-	   (wrap-an-is `(meqp ,(dconvx arg1) ,(dconvx arg2))
-		       form)))))
+	   (wrap-an-is `(meqp ,(dconvx arg1) ,(dconvx arg2)) form)))))
 
 ;; Logical not for predicates.  Do the expected thing, except return
 (defun trp-not (val)
   (case val
-    ((t)
-     nil)
-    ((nil)
-     t)
-    (otherwise
-     val)))
+    ((t) nil)
+    ((nil) t)
+    (otherwise val)))
       
-(defun trp-mnotequal (form) (list 'trp-not (trp-mequal form)))
+(defun trp-mnotequal (form)
+  (list 'trp-not (trp-mequal form)))
 
-(defun trp-mgeqp (form) (list 'trp-not (trp-mlessp form)))
-
-(defun trp-mleqp (form) (list 'trp-not (trp-mgreaterp form)))
+(defun trp-mgeqp (form)
+  (list 'trp-not (trp-mlessp form)))
 
+(defun trp-mleqp (form)
+  (list 'trp-not (trp-mgreaterp form)))
 
 ;;; sigh, i have to copy a lot of the $assume function too.
 
