@@ -9,17 +9,21 @@
       '((mlist simp)
 	"rtestnset" "rtest1" "rtest1a" "rtest2" "rtest4"  "rtest5"
 	"rtest6" "rtest6a" "rtest6b" "rtest7" "rtest9"
-	"rtest9a" "rtest10" "rtest11" "rtest13" "rtest13s"
+	"rtest9a"
+    ((mlist) "rtest10" 24 25)
+    "rtest11" "rtest13" "rtest13s"
 	((mlist simp) "rtest14" 57 63)
 	((mlist simp) "rtest15")
 	((mlist simp) "rtest16" 5)
 	"rtestode" "rtestode_zp"
-	"rtest3" "rtest8" "rtest12" "rexamples"
+	"rtest3" "rtest8"
+    ((mlist) "rtest12" 76 78)
+    "rexamples"
 	"rtesthyp"
 	"rtestmt19937"
     "rtest_allnummod"
     "rtestconjugate"
-    ((mlist) "rtestsum" 3 4 5 18 44)
+    ((mlist) "rtestsum" 3 4 18)
     "rtest_trig"
     "rtest_zeta"
     "rtest_diff_invtrig"
@@ -27,4 +31,10 @@
     "rtest_everysome"
     "rtestint"
     "rtestifactor"
+    "rtest_equal"
+    ((mlist) "rtest_abs" 42 43)
+    ((mlist) "rtest_taylor" 66 67 72 88 89 90 91 94 96 99 104 110 112 113 118 119 120 121 122 123 124)
+    ((mlist) "rtest_dot")
+    "rtest_mset"
+    "rtest_boolean"
     ))
